#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error Meh...
#endif

GO(gtk_about_dialog_add_credit_section, vFppp)
GO(gtk_about_dialog_get_artists, pFp)
GO(gtk_about_dialog_get_authors, pFp)
GO(gtk_about_dialog_get_comments, pFp)
GO(gtk_about_dialog_get_copyright, pFp)
GO(gtk_about_dialog_get_documenters, pFp)
GO(gtk_about_dialog_get_license, pFp)
GO(gtk_about_dialog_get_license_type, uFp)
GO(gtk_about_dialog_get_logo, pFp)
GO(gtk_about_dialog_get_logo_icon_name, pFp)
GO(gtk_about_dialog_get_program_name, pFp)
GO(gtk_about_dialog_get_translator_credits, pFp)
GO(gtk_about_dialog_get_type, LFv)
GO(gtk_about_dialog_get_version, pFp)
GO(gtk_about_dialog_get_website, pFp)
GO(gtk_about_dialog_get_website_label, pFp)
GO(gtk_about_dialog_get_wrap_license, iFp)
GO(gtk_about_dialog_new, pFv)
GO(gtk_about_dialog_set_artists, vFpp)
GO(gtk_about_dialog_set_authors, vFpp)
GO(gtk_about_dialog_set_comments, vFpp)
GO(gtk_about_dialog_set_copyright, vFpp)
GO(gtk_about_dialog_set_documenters, vFpp)
GO(gtk_about_dialog_set_license, vFpp)
GO(gtk_about_dialog_set_license_type, vFpu)
GO(gtk_about_dialog_set_logo, vFpp)
GO(gtk_about_dialog_set_logo_icon_name, vFpp)
GO(gtk_about_dialog_set_program_name, vFpp)
GO(gtk_about_dialog_set_translator_credits, vFpp)
GO(gtk_about_dialog_set_version, vFpp)
GO(gtk_about_dialog_set_website, vFpp)
GO(gtk_about_dialog_set_website_label, vFpp)
GO(gtk_about_dialog_set_wrap_license, vFpi)
GO(gtk_accelerator_get_default_mod_mask, uFv)
GO(gtk_accelerator_get_label, pFuu)
GO(gtk_accelerator_get_label_with_keycode, pFpuuu)
GO(gtk_accelerator_name, pFuu)
GO(gtk_accelerator_name_with_keycode, pFpuuu)
GO(gtk_accelerator_parse, vFppp)
GO(gtk_accelerator_parse_with_keycode, vFpppp)
GO(gtk_accelerator_set_default_mod_mask, vFu)
GO(gtk_accelerator_valid, iFuu)
GO(gtk_accel_flags_get_type, LFv)
GO(gtk_accel_group_activate, iFpupuu)
GO(gtk_accel_group_connect, vFpuuup)  // Closure probably needs wrapping when not null
GO(gtk_accel_group_connect_by_path, vFppp)  // Closure probably needs wrapping when not null
GO(gtk_accel_group_disconnect, iFpp)    // Closure probably needs wrapping when not null
GO(gtk_accel_group_disconnect_key, iFpuu)
//GOM(gtk_accel_group_find, pFEppp)
GO(gtk_accel_group_from_accel_closure, pFp)
GO(gtk_accel_group_get_is_locked, iFp)  // Closure probably needs wrapping when not null
GO(gtk_accel_group_get_modifier_mask, uFp)
GO(gtk_accel_group_get_type, LFv)
GO(gtk_accel_group_lock, vFp)
GO(gtk_accel_group_new, pFv)
GO(gtk_accel_group_query, pFpuup)
GO(gtk_accel_groups_activate, iFpuu)
GO(gtk_accel_groups_from_object, pFp)
GO(gtk_accel_group_unlock, vFp)
GO(gtk_accel_label_get_accel, vFppp)
GO(gtk_accel_label_get_accel_widget, pFp)
GO(gtk_accel_label_get_accel_width, uFp)
GO(gtk_accel_label_get_type, LFv)
GO(gtk_accel_label_new, pFp)
GO(gtk_accel_label_refetch, iFp)
GO(gtk_accel_label_set_accel, vFpuu)
//GOM(gtk_accel_label_set_accel_closure, vFpp)
GO(gtk_accel_label_set_accel_widget, vFpp)
GO(gtk_accel_map_add_entry, vFpuu)
GO(gtk_accel_map_add_filter, vFp)
GO(gtk_accel_map_change_entry, iFpuui)
//GOM(gtk_accel_map_foreach, vFpp)
//GOM(gtk_accel_map_foreach_unfiltered, vFpp)
GO(gtk_accel_map_get, pFv)
GO(gtk_accel_map_get_type, LFv)
GO(gtk_accel_map_load, vFp)
GO(gtk_accel_map_load_fd, vFi)
//GOM(gtk_accel_map_load_scanner, vFp)
GO(gtk_accel_map_lock_path, vFp)
GO(gtk_accel_map_lookup_entry, iFpp)
GO(gtk_accel_map_save, vFp)
GO(gtk_accel_map_save_fd, vFi)
GO(gtk_accel_map_unlock_path, vFp)
GO(gtk_accessible_connect_widget_destroyed, vFp)
GO(gtk_accessible_get_type, LFv)
GO(gtk_accessible_get_widget, pFp)
GO(gtk_accessible_set_widget, vFpp)
GO(gtk_actionable_get_action_name, pFp)
GO(gtk_actionable_get_action_target_value, pFp)
GO(gtk_actionable_get_type, LFv)
GO(gtk_actionable_set_action_name, vFpp)
//GOM(gtk_actionable_set_action_target, vFppV)
GO(gtk_actionable_set_action_target_value, vFpp)
GO(gtk_actionable_set_detailed_action_name, vFpp)
GO(gtk_action_activate, vFp)
GO(gtk_action_bar_get_center_widget, pFp)
GO(gtk_action_bar_get_type, LFv)
GO(gtk_action_bar_new, pFv)
GO(gtk_action_bar_pack_end, vFpp)
GO(gtk_action_bar_pack_start, vFpp)
GO(gtk_action_bar_set_center_widget, vFpp)
GO(gtk_action_block_activate, vFp)
GO(gtk_action_connect_accelerator, vFp)
GO(gtk_action_create_icon, pFpu)
GO(gtk_action_create_menu, pFp)
GO(gtk_action_create_menu_item, pFp)
GO(gtk_action_create_tool_item, pFp)
GO(gtk_action_disconnect_accelerator, vFp)
//GOM(gtk_action_get_accel_closure, pFp)
GO(gtk_action_get_accel_path, pFp)
GO(gtk_action_get_always_show_image, iFp)
GO(gtk_action_get_gicon, pFp)
GO(gtk_action_get_icon_name, pFp)
GO(gtk_action_get_is_important, iFp)
GO(gtk_action_get_label, pFp)
GO(gtk_action_get_name, pFp)
GO(gtk_action_get_proxies, pFp)
GO(gtk_action_get_sensitive, iFp)
GO(gtk_action_get_short_label, pFp)
GO(gtk_action_get_stock_id, pFp)
GO(gtk_action_get_tooltip, pFp)
GO(gtk_action_get_type, LFv)
GO(gtk_action_get_visible, iFp)
GO(gtk_action_get_visible_horizontal, iFp)
GO(gtk_action_get_visible_vertical, iFp)
GO(gtk_action_group_add_action, vFpp)
//GOM(gtk_action_group_add_actions, vFppup)
//GOM(gtk_action_group_add_actions_full, vFppupp)
GO(gtk_action_group_add_action_with_accel, vFppp)
//GOM(gtk_action_group_add_radio_actions, vFppuipp)
//GOM(gtk_action_group_add_radio_actions_full, vFppuippp)
//GOM(gtk_action_group_add_toggle_actions, vFppup)
//GOM(gtk_action_group_add_toggle_actions_full, vFppupp)
GO(gtk_action_group_get_accel_group, pFp)
GO(gtk_action_group_get_action, pFpp)
GO(gtk_action_group_get_name, pFp)
GO(gtk_action_group_get_sensitive, iFp)
GO(gtk_action_group_get_type, LFv)
GO(gtk_action_group_get_visible, iFp)
GO(gtk_action_group_list_actions, pFp)
GO(gtk_action_group_new, pFp)
GO(gtk_action_group_remove_action, vFpp)
GO(gtk_action_group_set_accel_group, vFpp)
GO(gtk_action_group_set_sensitive, vFpi)
//GOM(gtk_action_group_set_translate_func, vFpppp)
GO(gtk_action_group_set_translation_domain, vFpp)
GO(gtk_action_group_set_visible, vFpi)
GO(gtk_action_group_translate_string, pFpp)
GO(gtk_action_is_sensitive, iFp)
GO(gtk_action_is_visible, iFp)
GO(gtk_action_new, pFpppp)
GO(gtk_action_set_accel_group, vFpp)
GO(gtk_action_set_accel_path, vFpp)
GO(gtk_action_set_always_show_image, vFpi)
GO(gtk_action_set_gicon, vFpp)
GO(gtk_action_set_icon_name, vFpp)
GO(gtk_action_set_is_important, vFpi)
GO(gtk_action_set_label, vFpp)
GO(gtk_action_set_sensitive, vFpi)
GO(gtk_action_set_short_label, vFpp)
GO(gtk_action_set_stock_id, vFpp)
GO(gtk_action_set_tooltip, vFpp)
GO(gtk_action_set_visible, vFpi)
GO(gtk_action_set_visible_horizontal, vFpi)
GO(gtk_action_set_visible_vertical, vFpi)
GO(gtk_action_unblock_activate, vFp)
GO(gtk_activatable_do_set_related_action, vFpp)
GO(gtk_activatable_get_related_action, pFp)
GO(gtk_activatable_get_type, LFv)
GO(gtk_activatable_get_use_action_appearance, iFp)
GO(gtk_activatable_set_related_action, vFpp)
GO(gtk_activatable_set_use_action_appearance, vFpi)
GO(gtk_activatable_sync_action_properties, vFpp)
GO(gtk_adjustment_changed, vFp)
GO(gtk_adjustment_clamp_page, vFpdd)
GO(gtk_adjustment_configure, vFpdddddd)
GO(gtk_adjustment_get_lower, dFp)
GO(gtk_adjustment_get_minimum_increment, dFp)
GO(gtk_adjustment_get_page_increment, dFp)
GO(gtk_adjustment_get_page_size, dFp)
GO(gtk_adjustment_get_step_increment, dFp)
GO(gtk_adjustment_get_type, LFv)
GO(gtk_adjustment_get_upper, dFp)
GO(gtk_adjustment_get_value, dFp)
GO(gtk_adjustment_new, pFdddddd)
GO(gtk_adjustment_set_lower, vFpd)
GO(gtk_adjustment_set_page_increment, vFpd)
GO(gtk_adjustment_set_page_size, vFpd)
GO(gtk_adjustment_set_step_increment, vFpd)
GO(gtk_adjustment_set_upper, vFpd)
GO(gtk_adjustment_set_value, vFpd)
GO(gtk_adjustment_value_changed, vFp)
GO(gtk_align_get_type, LFv)
GO(gtk_alignment_get_padding, vFppppp)
GO(gtk_alignment_get_type, LFv)
GO(gtk_alignment_new, pFffff)
GO(gtk_alignment_set, vFpffff)
GO(gtk_alignment_set_padding, vFpuuuu)
GO(gtk_alternative_dialog_button_order, iFp)
GO(gtk_app_chooser_button_append_custom_item, vFpppp)
GO(gtk_app_chooser_button_append_separator, vFp)
GO(gtk_app_chooser_button_get_heading, pFp)
GO(gtk_app_chooser_button_get_show_default_item, iFp)
GO(gtk_app_chooser_button_get_show_dialog_item, iFp)
GO(gtk_app_chooser_button_get_type, LFv)
GO(gtk_app_chooser_button_new, pFp)
GO(gtk_app_chooser_button_set_active_custom_item, vFpp)
GO(gtk_app_chooser_button_set_heading, vFpp)
GO(gtk_app_chooser_button_set_show_default_item, vFpi)
GO(gtk_app_chooser_button_set_show_dialog_item, vFpi)
GO(gtk_app_chooser_dialog_get_heading, pFp)
GO(gtk_app_chooser_dialog_get_type, LFv)
GO(gtk_app_chooser_dialog_get_widget, pFp)
GO(gtk_app_chooser_dialog_new, pFpup)
GO(gtk_app_chooser_dialog_new_for_content_type, pFpup)
GO(gtk_app_chooser_dialog_set_heading, vFpp)
GO(gtk_app_chooser_get_app_info, pFp)
GO(gtk_app_chooser_get_content_type, pFp)
GO(gtk_app_chooser_get_type, LFv)
GO(gtk_app_chooser_refresh, vFp)
GO(gtk_app_chooser_widget_get_default_text, pFp)
GO(gtk_app_chooser_widget_get_show_all, iFp)
GO(gtk_app_chooser_widget_get_show_default, iFp)
GO(gtk_app_chooser_widget_get_show_fallback, iFp)
GO(gtk_app_chooser_widget_get_show_other, iFp)
GO(gtk_app_chooser_widget_get_show_recommended, iFp)
GO(gtk_app_chooser_widget_get_type, LFv)
GO(gtk_app_chooser_widget_new, pFp)
GO(gtk_app_chooser_widget_set_default_text, vFpp)
GO(gtk_app_chooser_widget_set_show_all, vFpi)
GO(gtk_app_chooser_widget_set_show_default, vFpi)
GO(gtk_app_chooser_widget_set_show_fallback, vFpi)
GO(gtk_app_chooser_widget_set_show_other, vFpi)
GO(gtk_app_chooser_widget_set_show_recommended, vFpi)
GO(gtk_application_add_accelerator, vFpppp)
GO(gtk_application_add_window, vFpp)
GO(gtk_application_get_accels_for_action, pFpp)
GO(gtk_application_get_actions_for_accel, pFpp)
GO(gtk_application_get_active_window, pFp)
GO(gtk_application_get_app_menu, pFp)
GO(gtk_application_get_menubar, pFp)
GO(gtk_application_get_menu_by_id, pFpp)
GO(gtk_application_get_type, LFv)
GO(gtk_application_get_window_by_id, pFpu)
GO(gtk_application_get_windows, pFp)
GO(gtk_application_inhibit, uFppup)
GO(gtk_application_inhibit_flags_get_type, LFv)
GO(gtk_application_is_inhibited, iFpu)
GO(gtk_application_list_action_descriptions, pFp)
GO(gtk_application_new, pFpu)
GO(gtk_application_prefers_app_menu, iFp)
GO(gtk_application_remove_accelerator, vFppp)
GO(gtk_application_remove_window, vFpp)
GO(gtk_application_set_accels_for_action, vFppp)
GO(gtk_application_set_app_menu, vFpp)
GO(gtk_application_set_menubar, vFpp)
GO(gtk_application_uninhibit, vFpu)
GO(gtk_application_window_get_help_overlay, pFp)
GO(gtk_application_window_get_id, uFp)
GO(gtk_application_window_get_show_menubar, iFp)
GO(gtk_application_window_get_type, LFv)
GO(gtk_application_window_new, pFp)
GO(gtk_application_window_set_help_overlay, vFpp)
GO(gtk_application_window_set_show_menubar, vFpi)
GO(gtk_arrow_accessible_get_type, LFv)
GO(gtk_arrow_get_type, LFv)
GO(gtk_arrow_new, pFuu)
GO(gtk_arrow_placement_get_type, LFv)
GO(gtk_arrow_set, vFpuu)
GO(gtk_arrow_type_get_type, LFv)
GO(gtk_aspect_frame_get_type, LFv)
GO(gtk_aspect_frame_new, pFpfffi)
GO(gtk_aspect_frame_set, vFpfffi)
GO(gtk_assistant_add_action_widget, vFpp)
GO(gtk_assistant_append_page, iFpp)
GO(gtk_assistant_commit, vFp)
GO(gtk_assistant_get_current_page, iFp)
GO(gtk_assistant_get_n_pages, iFp)
GO(gtk_assistant_get_nth_page, pFpi)
GO(gtk_assistant_get_page_complete, iFpp)
GO(gtk_assistant_get_page_has_padding, iFpp)
GO(gtk_assistant_get_page_header_image, pFpp)
GO(gtk_assistant_get_page_side_image, pFpp)
GO(gtk_assistant_get_page_title, pFpp)
GO(gtk_assistant_get_page_type, uFpp)
GO(gtk_assistant_get_type, LFv)
GO(gtk_assistant_insert_page, iFppi)
GO(gtk_assistant_new, pFv)
GO(gtk_assistant_next_page, vFp)
GO(gtk_assistant_page_type_get_type, LFv)
GO(gtk_assistant_prepend_page, iFpp)
GO(gtk_assistant_previous_page, vFp)
GO(gtk_assistant_remove_action_widget, vFpp)
GO(gtk_assistant_remove_page, vFpi)
GO(gtk_assistant_set_current_page, vFpi)
//GOM(gtk_assistant_set_forward_page_func, vFpppp)
GO(gtk_assistant_set_page_complete, vFppi)
GO(gtk_assistant_set_page_has_padding, vFppi)
GO(gtk_assistant_set_page_header_image, vFppp)
GO(gtk_assistant_set_page_side_image, vFppp)
GO(gtk_assistant_set_page_title, vFppp)
GO(gtk_assistant_set_page_type, vFppu)
GO(gtk_assistant_update_buttons_state, vFp)
GO(gtk_attach_options_get_type, LFv)
GO(gtk_baseline_position_get_type, LFv)
//GOM(gtk_binding_entry_add_signal, vFpuupuV)
GO(gtk_binding_entry_add_signal_from_string, uFpp)
GO(gtk_binding_entry_add_signall, vFpuupp)
GO(gtk_binding_entry_remove, vFpuu)
GO(gtk_binding_entry_skip, vFpuu)
GO(gtk_bindings_activate, iFpuu)
GO(gtk_bindings_activate_event, iFpp)
GO(gtk_binding_set_activate, iFpuup)
GO(gtk_binding_set_add_path, vFpupu)
GO(gtk_binding_set_by_class, pFp)
GO(gtk_binding_set_find, pFp)
GO(gtk_binding_set_new, pFp)
GO(gtk_bin_get_child, pFp)
GO(gtk_bin_get_type, LFv)
GO(gtk_boolean_cell_accessible_get_type, LFv)
GO(gtk_border_copy, pFp)
GO(gtk_border_free, vFp)
GO(gtk_border_get_type, LFv)
GO(gtk_border_new, pFv)
GO(gtk_border_style_get_type, LFv)
GO(gtk_box_get_baseline_position, uFp)
GO(gtk_box_get_center_widget, pFp)
GO(gtk_box_get_homogeneous, iFp)
GO(gtk_box_get_spacing, iFp)
GO(gtk_box_get_type, LFv)
GO(gtk_box_new, pFui)
GO(gtk_box_pack_end, vFppiiu)
GO(gtk_box_pack_start, vFppiiu)
GO(gtk_box_query_child_packing, vFpppppp)
GO(gtk_box_reorder_child, vFppi)
GO(gtk_box_set_baseline_position, vFpu)
GO(gtk_box_set_center_widget, vFpp)
GO(gtk_box_set_child_packing, vFppiiuu)
GO(gtk_box_set_homogeneous, vFpi)
GO(gtk_box_set_spacing, vFpi)
GO(gtk_buildable_add_child, vFpppp)
GO(gtk_buildable_construct_child, pFppp)
GO(gtk_buildable_custom_finished, vFppppp)
GO(gtk_buildable_custom_tag_end, vFppppp)
GO(gtk_buildable_custom_tag_start, iFpppppp)    // Something to wrap?
GO(gtk_buildable_get_internal_child, pFppp)
GO(gtk_buildable_get_name, pFp)
GO(gtk_buildable_get_type, LFv)
GO(gtk_buildable_parser_finished, vFpp)
GO(gtk_buildable_set_buildable_property, vFpppp)
GO(gtk_buildable_set_name, vFpp)
//GOM(gtk_builder_add_callback_symbol, vFppp)
//GOM(gtk_builder_add_callback_symbols, vFpppV)
GO(gtk_builder_add_from_file, uFppp)
GO(gtk_builder_add_from_resource, uFppp)
GO(gtk_builder_add_from_string, uFppLp)
GO(gtk_builder_add_objects_from_file, uFpppp)
GO(gtk_builder_add_objects_from_resource, uFpppp)
GO(gtk_builder_add_objects_from_string, uFppLpp)
GOM(gtk_builder_connect_signals, vFEpp)
GOM(gtk_builder_connect_signals_full, vFEppp)
GO(gtk_builder_error_get_type, LFv)
GO(gtk_builder_error_quark, uFv)
GO(gtk_builder_expose_object, vFppp)
GO(gtk_builder_extend_with_template, uFppLpLp)
GO(gtk_builder_get_application, pFp)
GO(gtk_builder_get_object, pFpp)
GO(gtk_builder_get_objects, pFp)
GO(gtk_builder_get_translation_domain, pFp)
GO(gtk_builder_get_type, LFv)
GO(gtk_builder_get_type_from_name, LFpp)
//GOM(gtk_builder_lookup_callback_symbol, pFpp)
GO(gtk_builder_new, pFv)
GO(gtk_builder_new_from_file, pFp)
GO(gtk_builder_new_from_resource, pFp)
GO(gtk_builder_new_from_string, pFpl)
GO(gtk_builder_set_application, vFpp)
GO(gtk_builder_set_translation_domain, vFpp)
GO(gtk_builder_value_from_string, iFppppp)
GO(gtk_builder_value_from_string_type, iFpLppp)
GO(gtk_button_accessible_get_type, LFv)
GO(gtk_button_box_get_child_non_homogeneous, iFpp)
GO(gtk_button_box_get_child_secondary, iFpp)
GO(gtk_button_box_get_layout, uFp)
GO(gtk_button_box_get_type, LFv)
GO(gtk_button_box_new, pFu)
GO(gtk_button_box_set_child_non_homogeneous, vFppi)
GO(gtk_button_box_set_child_secondary, vFppi)
GO(gtk_button_box_set_layout, vFpu)
GO(gtk_button_box_style_get_type, LFv)
GO(gtk_button_clicked, vFp)
GO(gtk_button_enter, vFp)
GO(gtk_button_get_alignment, vFppp)
GO(gtk_button_get_always_show_image, iFp)
GO(gtk_button_get_event_window, pFp)
GO(gtk_button_get_focus_on_click, iFp)
GO(gtk_button_get_image, pFp)
GO(gtk_button_get_image_position, uFp)
GO(gtk_button_get_label, pFp)
GO(gtk_button_get_relief, uFp)
GO(gtk_button_get_type, LFv)
GO(gtk_button_get_use_stock, iFp)
GO(gtk_button_get_use_underline, iFp)
GO(gtk_button_leave, vFp)
GO(gtk_button_new, pFv)
GO(gtk_button_new_from_icon_name, pFpu)
GO(gtk_button_new_from_stock, pFp)
GO(gtk_button_new_with_label, pFp)
GO(gtk_button_new_with_mnemonic, pFp)
GO(gtk_button_pressed, vFp)
GO(gtk_button_released, vFp)
GO(gtk_button_role_get_type, LFv)
GO(gtk_button_set_alignment, vFpff)
GO(gtk_button_set_always_show_image, vFpi)
GO(gtk_button_set_focus_on_click, vFpi)
GO(gtk_button_set_image, vFpp)
GO(gtk_button_set_image_position, vFpu)
GO(gtk_button_set_label, vFpp)
GO(gtk_button_set_relief, vFpu)
GO(gtk_button_set_use_stock, vFpi)
GO(gtk_button_set_use_underline, vFpi)
GO(gtk_buttons_type_get_type, LFv)
GO(gtk_cairo_should_draw_window, iFpp)
GO(gtk_cairo_transform_to_window, vFppp)
GO(gtk_calendar_clear_marks, vFp)
GO(gtk_calendar_display_options_get_type, LFv)
GO(gtk_calendar_get_date, vFpppp)
GO(gtk_calendar_get_day_is_marked, iFpu)
GO(gtk_calendar_get_detail_height_rows, iFp)
GO(gtk_calendar_get_detail_width_chars, iFp)
GO(gtk_calendar_get_display_options, uFp)
GO(gtk_calendar_get_type, LFv)
GO(gtk_calendar_mark_day, vFpu)
GO(gtk_calendar_new, pFv)
GO(gtk_calendar_select_day, vFpu)
GO(gtk_calendar_select_month, vFpuu)
//GOM(gtk_calendar_set_detail_func, vFpppp)
GO(gtk_calendar_set_detail_height_rows, vFpi)
GO(gtk_calendar_set_detail_width_chars, vFpi)
GO(gtk_calendar_set_display_options, vFpu)
GO(gtk_calendar_unmark_day, vFpu)
GO(gtk_cell_accessible_get_type, LFv)
GO(gtk_cell_accessible_parent_activate, vFpp)
GO(gtk_cell_accessible_parent_edit, vFpp)
GO(gtk_cell_accessible_parent_expand_collapse, vFpp)
GO(gtk_cell_accessible_parent_get_cell_area, vFppp)
GO(gtk_cell_accessible_parent_get_cell_extents, vFppppppu)
GO(gtk_cell_accessible_parent_get_cell_position, vFpppp)
GO(gtk_cell_accessible_parent_get_child_index, iFpp)
GO(gtk_cell_accessible_parent_get_column_header_cells, pFpp)
GO(gtk_cell_accessible_parent_get_renderer_state, uFpp)
GO(gtk_cell_accessible_parent_get_row_header_cells, pFpp)
GO(gtk_cell_accessible_parent_get_type, LFv)
GO(gtk_cell_accessible_parent_grab_focus, iFpp)
GO(gtk_cell_accessible_parent_update_relationset, vFppp)
GO(gtk_cell_area_activate, iFppppui)
GO(gtk_cell_area_activate_cell, iFpppppu)
GO(gtk_cell_area_add, vFpp)
GO(gtk_cell_area_add_focus_sibling, vFppp)
//GOM(gtk_cell_area_add_with_properties, vFpppV)
GO(gtk_cell_area_apply_attributes, vFpppii)
GO(gtk_cell_area_attribute_connect, vFpppi)
GO(gtk_cell_area_attribute_disconnect, vFppp)
GO(gtk_cell_area_attribute_get_column, iFppp)
GO(gtk_cell_area_box_get_spacing, iFp)
GO(gtk_cell_area_box_get_type, LFv)
GO(gtk_cell_area_box_new, pFv)
GO(gtk_cell_area_box_pack_end, vFppiii)
GO(gtk_cell_area_box_pack_start, vFppiii)
GO(gtk_cell_area_box_set_spacing, vFpi)
//GOM(gtk_cell_area_cell_get, vFpppV)
GO(gtk_cell_area_cell_get_property, vFpppp)
//GOM(gtk_cell_area_cell_get_valist, vFpppA)
//GOM(gtk_cell_area_cell_set, vFpppV)
GO(gtk_cell_area_cell_set_property, vFpppp)
//GOM(gtk_cell_area_cell_set_valist, vFpppA)
//GOM(gtk_cell_area_class_find_cell_property, pFpp)
//GOM(gtk_cell_area_class_install_cell_property, vFpup)
//GOM(gtk_cell_area_class_list_cell_properties, pFpp)
GO(gtk_cell_area_context_allocate, vFpii)
GO(gtk_cell_area_context_get_allocation, vFppp)
GO(gtk_cell_area_context_get_area, pFp)
GO(gtk_cell_area_context_get_preferred_height, vFppp)
GO(gtk_cell_area_context_get_preferred_height_for_width, vFpipp)
GO(gtk_cell_area_context_get_preferred_width, vFppp)
GO(gtk_cell_area_context_get_preferred_width_for_height, vFpipp)
GO(gtk_cell_area_context_get_type, LFv)
GO(gtk_cell_area_context_push_preferred_height, vFpii)
GO(gtk_cell_area_context_push_preferred_width, vFpii)
GO(gtk_cell_area_context_reset, vFp)
GO(gtk_cell_area_copy_context, pFpp)
GO(gtk_cell_area_create_context, pFp)
GO(gtk_cell_area_event, iFpppppu)
GO(gtk_cell_area_focus, iFpu)
//GOM(gtk_cell_area_foreach, vFppp)
//GOM(gtk_cell_area_foreach_alloc, vFppppppp)
GO(gtk_cell_area_get_cell_allocation, vFpppppp)
GO(gtk_cell_area_get_cell_at_position, pFppppiip)
GO(gtk_cell_area_get_current_path_string, pFp)
GO(gtk_cell_area_get_edited_cell, pFp)
GO(gtk_cell_area_get_edit_widget, pFp)
GO(gtk_cell_area_get_focus_cell, pFp)
GO(gtk_cell_area_get_focus_from_sibling, pFpp)
GO(gtk_cell_area_get_focus_siblings, pFpp)
GO(gtk_cell_area_get_preferred_height, vFppppp)
GO(gtk_cell_area_get_preferred_height_for_width, vFpppipp)
GO(gtk_cell_area_get_preferred_width, vFppppp)
GO(gtk_cell_area_get_preferred_width_for_height, vFpppipp)
GO(gtk_cell_area_get_request_mode, uFp)
GO(gtk_cell_area_get_type, LFv)
GO(gtk_cell_area_has_renderer, iFpp)
GO(gtk_cell_area_inner_cell_area, vFpppp)
GO(gtk_cell_area_is_activatable, iFp)
GO(gtk_cell_area_is_focus_sibling, iFppp)
GO(gtk_cell_area_remove, vFpp)
GO(gtk_cell_area_remove_focus_sibling, vFppp)
GO(gtk_cell_area_render, vFppppppui)
GO(gtk_cell_area_request_renderer, vFppupipp)
GO(gtk_cell_area_set_focus_cell, vFpp)
GO(gtk_cell_area_stop_editing, vFpi)
GO(gtk_cell_editable_editing_done, vFp)
GO(gtk_cell_editable_get_type, LFv)
GO(gtk_cell_editable_remove_widget, vFp)
GO(gtk_cell_editable_start_editing, vFpp)
GO(gtk_cell_layout_add_attribute, vFpppi)
GO(gtk_cell_layout_clear, vFp)
GO(gtk_cell_layout_clear_attributes, vFpp)
GO(gtk_cell_layout_get_area, pFp)
GO(gtk_cell_layout_get_cells, pFp)
GO(gtk_cell_layout_get_type, LFv)
GO(gtk_cell_layout_pack_end, vFppi)
GO(gtk_cell_layout_pack_start, vFppi)
GO(gtk_cell_layout_reorder, vFppi)
GO(gtk_cell_layout_set_attributes, vFpppppppppp)  // vaarg
//GOM(gtk_cell_layout_set_cell_data_func, vFEppppp)
GO(gtk_cell_renderer_accel_get_type, LFv)
GO(gtk_cell_renderer_accel_mode_get_type, LFv)
GO(gtk_cell_renderer_accel_new, pFv)
GO(gtk_cell_renderer_activate, iFppppppu)
//GOM(gtk_cell_renderer_class_set_accessible_type, vFpL)
GO(gtk_cell_renderer_combo_get_type, LFv)
GO(gtk_cell_renderer_combo_new, pFv)
GO(gtk_cell_renderer_get_aligned_area, vFppupp)
GO(gtk_cell_renderer_get_alignment, vFppp)
GO(gtk_cell_renderer_get_fixed_size, vFppp)
GO(gtk_cell_renderer_get_padding, vFppp)
GO(gtk_cell_renderer_get_preferred_height, vFpppp)
GO(gtk_cell_renderer_get_preferred_height_for_width, vFppipp)
GO(gtk_cell_renderer_get_preferred_size, vFpppp)
GO(gtk_cell_renderer_get_preferred_width, vFpppp)
GO(gtk_cell_renderer_get_preferred_width_for_height, vFppipp)
GO(gtk_cell_renderer_get_request_mode, uFp)
GO(gtk_cell_renderer_get_sensitive, iFp)
GO(gtk_cell_renderer_get_size, vFppppppp)
GO(gtk_cell_renderer_get_state, uFppu)
GO(gtk_cell_renderer_get_type, LFv)
GO(gtk_cell_renderer_get_visible, iFp)
//GO(gtk_cell_renderer_graph_get_type, 
//GO(gtk_cell_renderer_graph_new, 
GO(gtk_cell_renderer_is_activatable, iFp)
GO(gtk_cell_renderer_mode_get_type, LFv)
GO(gtk_cell_renderer_pixbuf_get_type, LFv)
GO(gtk_cell_renderer_pixbuf_new, pFv)
GO(gtk_cell_renderer_progress_get_type, LFv)
GO(gtk_cell_renderer_progress_new, pFv)
GO(gtk_cell_renderer_render, vFpppppu)
GO(gtk_cell_renderer_set_alignment, vFpff)
GO(gtk_cell_renderer_set_fixed_size, vFpii)
GO(gtk_cell_renderer_set_padding, vFpii)
GO(gtk_cell_renderer_set_sensitive, vFpi)
GO(gtk_cell_renderer_set_visible, vFpi)
GO(gtk_cell_renderer_spin_get_type, LFv)
GO(gtk_cell_renderer_spinner_get_type, LFv)
GO(gtk_cell_renderer_spinner_new, pFv)
GO(gtk_cell_renderer_spin_new, pFv)
GO(gtk_cell_renderer_start_editing, pFppppppu)
GO(gtk_cell_renderer_state_get_type, LFv)
GO(gtk_cell_renderer_stop_editing, vFpi)
GO(gtk_cell_renderer_text_get_type, LFv)
GO(gtk_cell_renderer_text_new, pFv)
GO(gtk_cell_renderer_text_set_fixed_height_from_font, vFpi)
GO(gtk_cell_renderer_toggle_get_activatable, iFp)
GO(gtk_cell_renderer_toggle_get_active, iFp)
GO(gtk_cell_renderer_toggle_get_radio, iFp)
GO(gtk_cell_renderer_toggle_get_type, LFv)
GO(gtk_cell_renderer_toggle_new, pFv)
GO(gtk_cell_renderer_toggle_set_activatable, vFpi)
GO(gtk_cell_renderer_toggle_set_active, vFpi)
GO(gtk_cell_renderer_toggle_set_radio, vFpi)
GO(gtk_cell_view_get_displayed_row, pFp)
GO(gtk_cell_view_get_draw_sensitive, iFp)
GO(gtk_cell_view_get_fit_model, iFp)
GO(gtk_cell_view_get_model, pFp)
GO(gtk_cell_view_get_size_of_row, iFppp)
GO(gtk_cell_view_get_type, LFv)
GO(gtk_cell_view_new, pFv)
GO(gtk_cell_view_new_with_context, pFpp)
GO(gtk_cell_view_new_with_markup, pFp)
GO(gtk_cell_view_new_with_pixbuf, pFp)
GO(gtk_cell_view_new_with_text, pFp)
GO(gtk_cell_view_set_background_color, vFpp)
GO(gtk_cell_view_set_background_rgba, vFpp)
GO(gtk_cell_view_set_displayed_row, vFpp)
GO(gtk_cell_view_set_draw_sensitive, vFpi)
GO(gtk_cell_view_set_fit_model, vFpi)
GO(gtk_cell_view_set_model, vFpp)
GO(gtk_check_button_get_type, LFv)
GO(gtk_check_button_new, pFv)
GO(gtk_check_button_new_with_label, pFp)
GO(gtk_check_button_new_with_mnemonic, pFp)
GO(gtk_check_menu_item_accessible_get_type, LFv)
GO(gtk_check_menu_item_get_active, iFp)
GO(gtk_check_menu_item_get_draw_as_radio, iFp)
GO(gtk_check_menu_item_get_inconsistent, iFp)
GO(gtk_check_menu_item_get_type, LFv)
GO(gtk_check_menu_item_new, pFv)
GO(gtk_check_menu_item_new_with_label, pFp)
GO(gtk_check_menu_item_new_with_mnemonic, pFp)
GO(gtk_check_menu_item_set_active, vFpi)
GO(gtk_check_menu_item_set_draw_as_radio, vFpi)
GO(gtk_check_menu_item_set_inconsistent, vFpi)
GO(gtk_check_menu_item_toggled, vFp)
GO(gtk_check_version, pFuuu)
GO(gtk_clipboard_clear, vFp)
GO(gtk_clipboard_get, pFp)
GO(gtk_clipboard_get_default, pFp)
GO(gtk_clipboard_get_display, pFp)
GO(gtk_clipboard_get_for_display, pFpp)
GO(gtk_clipboard_get_owner, pFp)
GO(gtk_clipboard_get_selection, pFp)
GO(gtk_clipboard_get_type, LFv)
//GOM(gtk_clipboard_request_contents, vFEpppp)
//GOM(gtk_clipboard_request_image, vFEppp)
//GOM(gtk_clipboard_request_rich_text, vFEpppp)
//GOM(gtk_clipboard_request_targets, vFEppp)
GOM(gtk_clipboard_request_text, vFEppp)
//GOM(gtk_clipboard_request_uris, vFEppp)
GO(gtk_clipboard_set_can_store, vFppi)
GO(gtk_clipboard_set_image, vFpp)
GO(gtk_clipboard_set_text, vFppi)
GOM(gtk_clipboard_set_with_data, iFEppuppp)
GOM(gtk_clipboard_set_with_owner, iFEppuppp)
GO(gtk_clipboard_store, vFp)
GO(gtk_clipboard_wait_for_contents, pFpp)
GO(gtk_clipboard_wait_for_image, pFp)
GO(gtk_clipboard_wait_for_rich_text, pFpppp)
GO(gtk_clipboard_wait_for_targets, iFppp)
GO(gtk_clipboard_wait_for_text, pFp)
GO(gtk_clipboard_wait_for_uris, pFp)
GO(gtk_clipboard_wait_is_image_available, iFp)
GO(gtk_clipboard_wait_is_rich_text_available, iFpp)
GO(gtk_clipboard_wait_is_target_available, iFpp)
GO(gtk_clipboard_wait_is_text_available, iFp)
GO(gtk_clipboard_wait_is_uris_available, iFp)
GO(gtk_color_button_get_alpha, WFp)
GO(gtk_color_button_get_color, vFpp)
GO(gtk_color_button_get_rgba, vFpp)
GO(gtk_color_button_get_title, pFp)
GO(gtk_color_button_get_type, LFv)
GO(gtk_color_button_get_use_alpha, iFp)
GO(gtk_color_button_new, pFv)
GO(gtk_color_button_new_with_color, pFp)
GO(gtk_color_button_new_with_rgba, pFp)
GO(gtk_color_button_set_alpha, vFpW)
GO(gtk_color_button_set_color, vFpp)
GO(gtk_color_button_set_rgba, vFpp)
GO(gtk_color_button_set_title, vFpp)
GO(gtk_color_button_set_use_alpha, vFpi)
GO(gtk_color_chooser_add_palette, vFpuiip)
GO(gtk_color_chooser_dialog_get_type, LFv)
GO(gtk_color_chooser_dialog_new, pFpp)
GO(gtk_color_chooser_get_rgba, vFpp)
GO(gtk_color_chooser_get_type, LFv)
GO(gtk_color_chooser_get_use_alpha, iFp)
GO(gtk_color_chooser_set_rgba, vFpp)
GO(gtk_color_chooser_set_use_alpha, vFpi)
GO(gtk_color_chooser_widget_get_type, LFv)
GO(gtk_color_chooser_widget_new, pFv)
//GO(gtk_color_picker_get_type, 
//GO(gtk_color_picker_kwin_new, 
//GO(gtk_color_picker_new, 
//GO(gtk_color_picker_pick, 
//GO(gtk_color_picker_pick_finish, 
//GO(gtk_color_picker_portal_new, 
//GO(gtk_color_picker_shell_new, 
GO(gtk_color_selection_dialog_get_color_selection, pFp)
GO(gtk_color_selection_dialog_get_type, LFv)
GO(gtk_color_selection_dialog_new, pFp)
GO(gtk_color_selection_get_current_alpha, WFp)
GO(gtk_color_selection_get_current_color, vFpp)
GO(gtk_color_selection_get_current_rgba, vFpp)
GO(gtk_color_selection_get_has_opacity_control, iFp)
GO(gtk_color_selection_get_has_palette, iFp)
GO(gtk_color_selection_get_previous_alpha, WFp)
GO(gtk_color_selection_get_previous_color, vFpp)
GO(gtk_color_selection_get_previous_rgba, vFpp)
GO(gtk_color_selection_get_type, LFv)
GO(gtk_color_selection_is_adjusting, iFp)
GO(gtk_color_selection_new, pFv)
GO(gtk_color_selection_palette_from_string, iFppp)
GO(gtk_color_selection_palette_to_string, pFpi)
//GOM(gtk_color_selection_set_change_palette_with_screen_hook, pFEp)
GO(gtk_color_selection_set_current_alpha, vFpW)
GO(gtk_color_selection_set_current_color, vFpp)
GO(gtk_color_selection_set_current_rgba, vFpp)
GO(gtk_color_selection_set_has_opacity_control, vFpi)
GO(gtk_color_selection_set_has_palette, vFpi)
GO(gtk_color_selection_set_previous_alpha, vFpW)
GO(gtk_color_selection_set_previous_color, vFpp)
GO(gtk_color_selection_set_previous_rgba, vFpp)
GO(gtk_combo_box_accessible_get_type, LFv)
GO(gtk_combo_box_get_active, iFp)
GO(gtk_combo_box_get_active_id, pFp)
GO(gtk_combo_box_get_active_iter, iFpp)
GO(gtk_combo_box_get_add_tearoffs, iFp)
GO(gtk_combo_box_get_button_sensitivity, uFp)
GO(gtk_combo_box_get_column_span_column, iFp)
GO(gtk_combo_box_get_entry_text_column, iFp)
GO(gtk_combo_box_get_focus_on_click, iFp)
GO(gtk_combo_box_get_has_entry, iFp)
GO(gtk_combo_box_get_id_column, iFp)
GO(gtk_combo_box_get_model, pFp)
GO(gtk_combo_box_get_popup_accessible, pFp)
GO(gtk_combo_box_get_popup_fixed_width, iFp)
//GOM(gtk_combo_box_get_row_separator_func, pFEp)
GO(gtk_combo_box_get_row_span_column, iFp)
GO(gtk_combo_box_get_title, pFp)
GO(gtk_combo_box_get_type, LFv)
GO(gtk_combo_box_get_wrap_width, iFp)
GO(gtk_combo_box_new, pFv)
GO(gtk_combo_box_new_with_area, pFp)
GO(gtk_combo_box_new_with_area_and_entry, pFp)
GO(gtk_combo_box_new_with_entry, pFv)
GO(gtk_combo_box_new_with_model, pFp)
GO(gtk_combo_box_new_with_model_and_entry, pFp)
GO(gtk_combo_box_popdown, vFp)
GO(gtk_combo_box_popup, vFp)
GO(gtk_combo_box_popup_for_device, vFpp)
GO(gtk_combo_box_set_active, vFpi)
GO(gtk_combo_box_set_active_id, iFpp)
GO(gtk_combo_box_set_active_iter, vFpp)
GO(gtk_combo_box_set_add_tearoffs, vFpi)
GO(gtk_combo_box_set_button_sensitivity, vFpu)
GO(gtk_combo_box_set_column_span_column, vFpi)
GO(gtk_combo_box_set_entry_text_column, vFpi)
GO(gtk_combo_box_set_focus_on_click, vFpi)
GO(gtk_combo_box_set_id_column, vFpi)
GO(gtk_combo_box_set_model, vFpp)
GO(gtk_combo_box_set_popup_fixed_width, vFpi)
//GOM(gtk_combo_box_set_row_separator_func, vFEpppp)
GO(gtk_combo_box_set_row_span_column, vFpi)
GO(gtk_combo_box_set_title, vFpp)
GO(gtk_combo_box_set_wrap_width, vFpi)
GO(gtk_combo_box_text_append, vFppp)
GO(gtk_combo_box_text_append_text, vFpp)
GO(gtk_combo_box_text_get_active_text, pFp)
GO(gtk_combo_box_text_get_type, LFv)
GO(gtk_combo_box_text_insert, vFpipp)
GO(gtk_combo_box_text_insert_text, vFpip)
GO(gtk_combo_box_text_new, pFv)
GO(gtk_combo_box_text_new_with_entry, pFv)
GO(gtk_combo_box_text_prepend, vFppp)
GO(gtk_combo_box_text_prepend_text, vFpp)
GO(gtk_combo_box_text_remove, vFpi)
GO(gtk_combo_box_text_remove_all, vFp)
GO(gtk_container_accessible_get_type, LFv)
GO(gtk_container_add, vFpp)
GO(gtk_container_add_with_properties, vFpppppppppppp)    //vaarg
GO(gtk_container_cell_accessible_add_child, vFpp)
GO(gtk_container_cell_accessible_get_children, pFp)
GO(gtk_container_cell_accessible_get_type, LFv)
GO(gtk_container_cell_accessible_new, pFv)
GO(gtk_container_cell_accessible_remove_child, vFpp)
GO(gtk_container_check_resize, vFp)
//GOM(gtk_container_child_get, vFpppV)
GO(gtk_container_child_get_property, vFpppp)
//GOM(gtk_container_child_get_valist, vFpppA)
GO(gtk_container_child_notify, vFppp)
GO(gtk_container_child_notify_by_pspec, vFppp)
//GOM(gtk_container_child_set, vFpppV)
GO(gtk_container_child_set_property, vFpppp)
//GOM(gtk_container_child_set_valist, vFpppA)
GO(gtk_container_child_type, LFp)
GO(gtk_container_class_find_child_property, pFpp)   // Something to wrap?
GO(gtk_container_class_install_child_property, vFpup)
GO(gtk_container_class_list_child_properties, pFpp)
GOM(gtk_container_forall, vFEppp)
GOM(gtk_container_foreach, vFEppp)
//GOM(gtk_container_foreach_full, vFEppppp)
GO(gtk_container_get_border_width, uFp)
GO(gtk_container_get_children, pFp)
GO(gtk_container_get_focus_chain, iFpp)
GO(gtk_container_get_focus_child, pFp)
GO(gtk_container_get_focus_hadjustment, pFp)
GO(gtk_container_get_focus_vadjustment, pFp)
GO(gtk_container_get_path_for_child, pFpp)
GO(gtk_container_get_resize_mode, uFp)
GO(gtk_container_get_type, LFv)
GO(gtk_container_propagate_draw, vFppp)
GO(gtk_container_remove, vFpp)
GO(gtk_container_resize_children, vFp)
GO(gtk_container_set_border_width, vFpu)
GO(gtk_container_set_focus_chain, vFpp)
GO(gtk_container_set_focus_child, vFpp)
GO(gtk_container_set_focus_hadjustment, vFpp)
GO(gtk_container_set_focus_vadjustment, vFpp)
GO(gtk_container_set_reallocate_redraws, vFpi)
GO(gtk_container_set_resize_mode, vFpu)
GO(gtk_container_unset_focus_chain, vFp)
GO(gtk_corner_type_get_type, LFv)
GO(gtk_css_provider_error_get_type, LFv)
GO(gtk_css_provider_error_quark, uFv)
GO(gtk_css_provider_get_default, pFv)
GO(gtk_css_provider_get_named, pFpp)
GO(gtk_css_provider_get_type, LFv)
GO(gtk_css_provider_load_from_data, iFpplp)
GO(gtk_css_provider_load_from_file, iFppp)
GO(gtk_css_provider_load_from_path, iFppp)
GO(gtk_css_provider_load_from_resource, vFpp)
GO(gtk_css_provider_new, pFv)
GO(gtk_css_provider_to_string, pFp)
GO(gtk_css_section_get_end_line, uFp)
GO(gtk_css_section_get_end_position, uFp)
GO(gtk_css_section_get_file, pFp)
GO(gtk_css_section_get_parent, pFp)
GO(gtk_css_section_get_section_type, uFp)
GO(gtk_css_section_get_start_line, uFp)
GO(gtk_css_section_get_start_position, uFp)
GO(gtk_css_section_get_type, LFv)
GO(gtk_css_section_ref, pFp)
GO(gtk_css_section_type_get_type, LFv)
GO(gtk_css_section_unref, vFp)
GO(gtk_custom_paper_unix_dialog_get_type, LFv)
GO(gtk_debug_flag_get_type, LFv)
GO(gtk_delete_type_get_type, LFv)
GO(gtk_dest_defaults_get_type, LFv)
GO(gtk_device_grab_add, vFppi)
GO(gtk_device_grab_remove, vFpp)
GO(gtk_dialog_add_action_widget, vFppi)
GO(gtk_dialog_add_button, pFppi)
GOM(gtk_dialog_add_buttons, vFEppV)
GO(gtk_dialog_flags_get_type, LFv)
GO(gtk_dialog_get_action_area, pFp)
GO(gtk_dialog_get_content_area, pFp)
GO(gtk_dialog_get_header_bar, pFp)
GO(gtk_dialog_get_response_for_widget, iFpp)
GO(gtk_dialog_get_type, LFv)
GO(gtk_dialog_get_widget_for_response, pFpi)
GO(gtk_dialog_new, pFv)
GO(gtk_dialog_new_with_buttons, pFppupppppppppppp)    //vaarg
GO(gtk_dialog_response, vFpi)
GO(gtk_dialog_run, iFp)
GO(gtk_dialog_set_alternative_button_order, vFpiiiiiiiiiiiiiiiiii)  // vaarg, should wrap using gtk_dialog_set_alternative_button_order_from_array
GO(gtk_dialog_set_alternative_button_order_from_array, vFpip)
GO(gtk_dialog_set_default_response, vFpi)
GO(gtk_dialog_set_response_sensitive, vFpii)
GO(gtk_direction_type_get_type, LFv)
GO(gtk_disable_setlocale, vFv)
GO(gtk_distribute_natural_allocation, iFiup)
GO(gtk_drag_begin, pFppuip)
GO(gtk_drag_begin_with_coordinates, pFppuipii)
GO(gtk_drag_cancel, vFp)
GO(gtk_drag_check_threshold, iFpiiii)
GO(gtk_drag_dest_add_image_targets, vFp)
GO(gtk_drag_dest_add_text_targets, vFp)
GO(gtk_drag_dest_add_uri_targets, vFp)
GO(gtk_drag_dest_find_target, pFppp)
GO(gtk_drag_dest_get_target_list, pFp)
GO(gtk_drag_dest_get_track_motion, iFp)
GO(gtk_drag_dest_set, vFpupiu)
GO(gtk_drag_dest_set_proxy, vFppui)
GO(gtk_drag_dest_set_target_list, vFpp)
GO(gtk_drag_dest_set_track_motion, vFpi)
GO(gtk_drag_dest_unset, vFp)
GO(gtk_drag_finish, vFpiiu)
GO(gtk_drag_get_data, vFpppu)
GO(gtk_drag_get_source_widget, pFp)
GO(gtk_drag_highlight, vFp)
GO(gtk_drag_result_get_type, LFv)
GO(gtk_drag_set_icon_default, vFp)
GO(gtk_drag_set_icon_gicon, vFppii)
GO(gtk_drag_set_icon_name, vFppii)
GO(gtk_drag_set_icon_pixbuf, vFppii)
GO(gtk_drag_set_icon_stock, vFppii)
GO(gtk_drag_set_icon_surface, vFpp)
GO(gtk_drag_set_icon_widget, vFppii)
GO(gtk_drag_source_add_image_targets, vFp)
GO(gtk_drag_source_add_text_targets, vFp)
GO(gtk_drag_source_add_uri_targets, vFp)
GO(gtk_drag_source_get_target_list, pFp)
GO(gtk_drag_source_set, vFpupiu)
GO(gtk_drag_source_set_icon_gicon, vFpp)
GO(gtk_drag_source_set_icon_name, vFpp)
GO(gtk_drag_source_set_icon_pixbuf, vFpp)
GO(gtk_drag_source_set_icon_stock, vFpp)
GO(gtk_drag_source_set_target_list, vFpp)
GO(gtk_drag_source_unset, vFp)
GO(gtk_drag_unhighlight, vFp)
GO(gtk_drawing_area_get_type, LFv)
GO(gtk_drawing_area_new, pFv)
GO(gtk_draw_insertion_cursor, vFpppiui)
GO(gtk_editable_copy_clipboard, vFp)
GO(gtk_editable_cut_clipboard, vFp)
GO(gtk_editable_delete_selection, vFp)
GO(gtk_editable_delete_text, vFpii)
GO(gtk_editable_get_chars, pFpii)
GO(gtk_editable_get_editable, iFp)
GO(gtk_editable_get_position, iFp)
GO(gtk_editable_get_selection_bounds, iFppp)
GO(gtk_editable_get_type, LFv)
GO(gtk_editable_insert_text, vFppip)
GO(gtk_editable_paste_clipboard, vFp)
GO(gtk_editable_select_region, vFpii)
GO(gtk_editable_set_editable, vFpi)
GO(gtk_editable_set_position, vFpi)
GO(gtk_entry_accessible_get_type, LFv)
GO(gtk_entry_buffer_delete_text, uFpui)
GO(gtk_entry_buffer_emit_deleted_text, vFpuu)
GO(gtk_entry_buffer_emit_inserted_text, vFpupu)
GO(gtk_entry_buffer_get_bytes, LFp)
GO(gtk_entry_buffer_get_length, uFp)
GO(gtk_entry_buffer_get_max_length, iFp)
GO(gtk_entry_buffer_get_text, pFp)
GO(gtk_entry_buffer_get_type, LFv)
GO(gtk_entry_buffer_insert_text, uFpupi)
GO(gtk_entry_buffer_new, pFpi)
GO(gtk_entry_buffer_set_max_length, vFpi)
GO(gtk_entry_buffer_set_text, vFppi)
GO(gtk_entry_completion_complete, vFp)
GO(gtk_entry_completion_compute_prefix, pFpp)
GO(gtk_entry_completion_delete_action, vFpi)
GO(gtk_entry_completion_get_completion_prefix, pFp)
GO(gtk_entry_completion_get_entry, pFp)
GO(gtk_entry_completion_get_inline_completion, iFp)
GO(gtk_entry_completion_get_inline_selection, iFp)
GO(gtk_entry_completion_get_minimum_key_length, iFp)
GO(gtk_entry_completion_get_model, pFp)
GO(gtk_entry_completion_get_popup_completion, iFp)
GO(gtk_entry_completion_get_popup_set_width, iFp)
GO(gtk_entry_completion_get_popup_single_match, iFp)
GO(gtk_entry_completion_get_text_column, iFp)
GO(gtk_entry_completion_get_type, LFv)
GO(gtk_entry_completion_insert_action_markup, vFpip)
GO(gtk_entry_completion_insert_action_text, vFpip)
GO(gtk_entry_completion_insert_prefix, vFp)
GO(gtk_entry_completion_new, pFv)
GO(gtk_entry_completion_new_with_area, pFp)
GO(gtk_entry_completion_set_inline_completion, vFpi)
GO(gtk_entry_completion_set_inline_selection, vFpi)
//GOM(gtk_entry_completion_set_match_func, vFpppp)
GO(gtk_entry_completion_set_minimum_key_length, vFpi)
GO(gtk_entry_completion_set_model, vFpp)
GO(gtk_entry_completion_set_popup_completion, vFpi)
GO(gtk_entry_completion_set_popup_set_width, vFpi)
GO(gtk_entry_completion_set_popup_single_match, vFpi)
GO(gtk_entry_completion_set_text_column, vFpi)
GO(gtk_entry_get_activates_default, iFp)
GO(gtk_entry_get_alignment, fFp)
GO(gtk_entry_get_attributes, pFp)
GO(gtk_entry_get_buffer, pFp)
GO(gtk_entry_get_completion, pFp)
GO(gtk_entry_get_current_icon_drag_source, iFp)
GO(gtk_entry_get_cursor_hadjustment, pFp)
GO(gtk_entry_get_has_frame, iFp)
GO(gtk_entry_get_icon_activatable, iFpu)
GO(gtk_entry_get_icon_area, vFpup)
GO(gtk_entry_get_icon_at_pos, iFpii)
GO(gtk_entry_get_icon_gicon, pFpu)
GO(gtk_entry_get_icon_name, pFpu)
GO(gtk_entry_get_icon_pixbuf, pFpu)
GO(gtk_entry_get_icon_sensitive, iFpu)
GO(gtk_entry_get_icon_stock, pFpu)
GO(gtk_entry_get_icon_storage_type, uFpu)
GO(gtk_entry_get_icon_tooltip_markup, pFpu)
GO(gtk_entry_get_icon_tooltip_text, pFpu)
GO(gtk_entry_get_inner_border, pFp)
GO(gtk_entry_get_input_hints, uFp)
GO(gtk_entry_get_input_purpose, uFp)
GO(gtk_entry_get_invisible_char, uFp)
GO(gtk_entry_get_layout, pFp)
GO(gtk_entry_get_layout_offsets, vFppp)
GO(gtk_entry_get_max_length, iFp)
GO(gtk_entry_get_max_width_chars, iFp)
GO(gtk_entry_get_overwrite_mode, iFp)
GO(gtk_entry_get_placeholder_text, pFp)
GO(gtk_entry_get_progress_fraction, dFp)
GO(gtk_entry_get_progress_pulse_step, dFp)
GO(gtk_entry_get_tabs, pFp)
GO(gtk_entry_get_text, pFp)
GO(gtk_entry_get_text_area, vFpp)
GO(gtk_entry_get_text_length, WFp)
GO(gtk_entry_get_type, LFv)
GO(gtk_entry_get_visibility, iFp)
GO(gtk_entry_get_width_chars, iFp)
GO(gtk_entry_grab_focus_without_selecting, vFp)
GO(gtk_entry_icon_accessible_get_type, LFv)
GO(gtk_entry_icon_position_get_type, LFv)
GO(gtk_entry_im_context_filter_keypress, iFpp)
GO(gtk_entry_layout_index_to_text_index, iFpi)
GO(gtk_entry_new, pFv)
GO(gtk_entry_new_with_buffer, pFp)
GO(gtk_entry_progress_pulse, vFp)
GO(gtk_entry_reset_im_context, vFp)
GO(gtk_entry_set_activates_default, vFpi)
GO(gtk_entry_set_alignment, vFpf)
GO(gtk_entry_set_attributes, vFpp)
GO(gtk_entry_set_buffer, vFpp)
GO(gtk_entry_set_completion, vFpp)
GO(gtk_entry_set_cursor_hadjustment, vFpp)
GO(gtk_entry_set_has_frame, vFpi)
GO(gtk_entry_set_icon_activatable, vFpui)
GO(gtk_entry_set_icon_drag_source, vFpupu)
GO(gtk_entry_set_icon_from_gicon, vFpup)
GO(gtk_entry_set_icon_from_icon_name, vFpup)
GO(gtk_entry_set_icon_from_pixbuf, vFpup)
GO(gtk_entry_set_icon_from_stock, vFpup)
GO(gtk_entry_set_icon_sensitive, vFpui)
GO(gtk_entry_set_icon_tooltip_markup, vFpup)
GO(gtk_entry_set_icon_tooltip_text, vFpup)
GO(gtk_entry_set_inner_border, vFpp)
GO(gtk_entry_set_input_hints, vFpu)
GO(gtk_entry_set_input_purpose, vFpu)
GO(gtk_entry_set_invisible_char, vFpu)
GO(gtk_entry_set_max_length, vFpi)
GO(gtk_entry_set_max_width_chars, vFpi)
GO(gtk_entry_set_overwrite_mode, vFpi)
GO(gtk_entry_set_placeholder_text, vFpp)
GO(gtk_entry_set_progress_fraction, vFpd)
GO(gtk_entry_set_progress_pulse_step, vFpd)
GO(gtk_entry_set_tabs, vFpp)
GO(gtk_entry_set_text, vFpp)
GO(gtk_entry_set_visibility, vFpi)
GO(gtk_entry_set_width_chars, vFpi)
GO(gtk_entry_text_index_to_layout_index, iFpi)
GO(gtk_entry_unset_invisible_char, vFp)
GOM(gtk_enumerate_printers, vFEpppi)
GO(gtk_event_box_get_above_child, iFp)
GO(gtk_event_box_get_type, LFv)
GO(gtk_event_box_get_visible_window, iFp)
GO(gtk_event_box_new, pFv)
GO(gtk_event_box_set_above_child, vFpi)
GO(gtk_event_box_set_visible_window, vFpi)
GO(gtk_event_controller_get_propagation_phase, uFp)
GO(gtk_event_controller_get_type, LFv)
GO(gtk_event_controller_get_widget, pFp)
GO(gtk_event_controller_handle_event, iFpp)
GO(gtk_event_controller_key_forward, iFpp)
GO(gtk_event_controller_key_get_group, uFp)
GO(gtk_event_controller_key_get_im_context, pFp)
GO(gtk_event_controller_key_get_type, LFv)
GO(gtk_event_controller_key_new, pFp)
GO(gtk_event_controller_key_set_im_context, vFpp)
GO(gtk_event_controller_motion_get_type, LFv)
GO(gtk_event_controller_motion_new, pFp)
GO(gtk_event_controller_reset, vFp)
GO(gtk_event_controller_scroll_flags_get_type, LFv)
GO(gtk_event_controller_scroll_get_flags, uFp)
GO(gtk_event_controller_scroll_get_type, LFv)
GO(gtk_event_controller_scroll_new, pFpu)
GO(gtk_event_controller_scroll_set_flags, vFpu)
GO(gtk_event_controller_set_propagation_phase, vFpu)
GO(gtk_event_sequence_state_get_type, LFv)
GO(gtk_events_pending, iFv)
GO(gtk_expander_accessible_get_type, LFv)
GO(gtk_expander_get_expanded, iFp)
GO(gtk_expander_get_label, pFp)
GO(gtk_expander_get_label_fill, iFp)
GO(gtk_expander_get_label_widget, pFp)
GO(gtk_expander_get_resize_toplevel, iFp)
GO(gtk_expander_get_spacing, iFp)
GO(gtk_expander_get_type, LFv)
GO(gtk_expander_get_use_markup, iFp)
GO(gtk_expander_get_use_underline, iFp)
GO(gtk_expander_new, pFp)
GO(gtk_expander_new_with_mnemonic, pFp)
GO(gtk_expander_set_expanded, vFpi)
GO(gtk_expander_set_label, vFpp)
GO(gtk_expander_set_label_fill, vFpi)
GO(gtk_expander_set_label_widget, vFpp)
GO(gtk_expander_set_resize_toplevel, vFpi)
GO(gtk_expander_set_spacing, vFpi)
GO(gtk_expander_set_use_markup, vFpi)
GO(gtk_expander_set_use_underline, vFpi)
GO(gtk_expander_style_get_type, LFv)
GO(gtk_false, iFv)
GO(gtk_file_chooser_action_get_type, LFv)
GO(gtk_file_chooser_add_choice, vFppppp)
GO(gtk_file_chooser_add_filter, vFpp)
GO(gtk_file_chooser_add_shortcut_folder, iFppp)
GO(gtk_file_chooser_add_shortcut_folder_uri, iFppp)
GO(gtk_file_chooser_button_get_focus_on_click, iFp)
GO(gtk_file_chooser_button_get_title, pFp)
GO(gtk_file_chooser_button_get_type, LFv)
GO(gtk_file_chooser_button_get_width_chars, iFp)
GO(gtk_file_chooser_button_new, pFpu)
GO(gtk_file_chooser_button_new_with_dialog, pFp)
GO(gtk_file_chooser_button_set_focus_on_click, vFpi)
GO(gtk_file_chooser_button_set_title, vFpp)
GO(gtk_file_chooser_button_set_width_chars, vFpi)
GO(gtk_file_chooser_confirmation_get_type, LFv)
GO(gtk_file_chooser_dialog_get_type, LFv)
GO(gtk_file_chooser_dialog_new, pFppupupupupupupup)  // vaargs (so pFppupV) with additionnal buttons, end with a NULL
GO(gtk_file_chooser_error_get_type, LFv)
GO(gtk_file_chooser_error_quark, uFv)
GO(gtk_file_chooser_get_action, uFp)
GO(gtk_file_chooser_get_choice, pFpp)
GO(gtk_file_chooser_get_create_folders, iFp)
GO(gtk_file_chooser_get_current_folder, pFp)
GO(gtk_file_chooser_get_current_folder_file, pFp)
GO(gtk_file_chooser_get_current_folder_uri, pFp)
GO(gtk_file_chooser_get_current_name, pFp)
GO(gtk_file_chooser_get_do_overwrite_confirmation, iFp)
GO(gtk_file_chooser_get_extra_widget, pFp)
GO(gtk_file_chooser_get_file, pFp)
GO(gtk_file_chooser_get_filename, pFp)
GO(gtk_file_chooser_get_filenames, pFp)
GO(gtk_file_chooser_get_files, pFp)
GO(gtk_file_chooser_get_filter, pFp)
GO(gtk_file_chooser_get_filters, pFp)
GO(gtk_file_chooser_get_local_only, iFp)
GO(gtk_file_chooser_get_preview_file, pFp)
GO(gtk_file_chooser_get_preview_filename, pFp)
GO(gtk_file_chooser_get_preview_uri, pFp)
GO(gtk_file_chooser_get_preview_widget, pFp)
GO(gtk_file_chooser_get_preview_widget_active, iFp)
GO(gtk_file_chooser_get_select_multiple, iFp)
GO(gtk_file_chooser_get_show_hidden, iFp)
GO(gtk_file_chooser_get_type, LFv)
GO(gtk_file_chooser_get_uri, pFp)
GO(gtk_file_chooser_get_uris, pFp)
GO(gtk_file_chooser_get_use_preview_label, iFp)
GO(gtk_file_chooser_list_filters, pFp)
GO(gtk_file_chooser_list_shortcut_folders, pFp)
GO(gtk_file_chooser_list_shortcut_folder_uris, pFp)
GO(gtk_file_chooser_native_get_accept_label, pFp)
GO(gtk_file_chooser_native_get_cancel_label, pFp)
GO(gtk_file_chooser_native_get_type, LFv)
GO(gtk_file_chooser_native_new, pFppupp)
GO(gtk_file_chooser_native_set_accept_label, vFpp)
GO(gtk_file_chooser_native_set_cancel_label, vFpp)
GO(gtk_file_chooser_remove_choice, vFpp)
GO(gtk_file_chooser_remove_filter, vFpp)
GO(gtk_file_chooser_remove_shortcut_folder, iFppp)
GO(gtk_file_chooser_remove_shortcut_folder_uri, iFppp)
GO(gtk_file_chooser_select_all, vFp)
GO(gtk_file_chooser_select_file, iFppp)
GO(gtk_file_chooser_select_filename, iFpp)
GO(gtk_file_chooser_select_uri, iFpp)
GO(gtk_file_chooser_set_action, vFpu)
GO(gtk_file_chooser_set_choice, vFppp)
GO(gtk_file_chooser_set_create_folders, vFpi)
GO(gtk_file_chooser_set_current_folder, iFpp)
GO(gtk_file_chooser_set_current_folder_file, iFppp)
GO(gtk_file_chooser_set_current_folder_uri, iFpp)
GO(gtk_file_chooser_set_current_name, vFpp)
GO(gtk_file_chooser_set_do_overwrite_confirmation, vFpi)
GO(gtk_file_chooser_set_extra_widget, vFpp)
GO(gtk_file_chooser_set_file, iFppp)
GO(gtk_file_chooser_set_filename, iFpp)
GO(gtk_file_chooser_set_filter, vFpp)
GO(gtk_file_chooser_set_local_only, vFpi)
GO(gtk_file_chooser_set_preview_widget, vFpp)
GO(gtk_file_chooser_set_preview_widget_active, vFpi)
GO(gtk_file_chooser_set_select_multiple, vFpi)
GO(gtk_file_chooser_set_show_hidden, vFpi)
GO(gtk_file_chooser_set_uri, iFpp)
GO(gtk_file_chooser_set_use_preview_label, vFpi)
GO(gtk_file_chooser_unselect_all, vFp)
GO(gtk_file_chooser_unselect_file, vFpp)
GO(gtk_file_chooser_unselect_filename, vFpp)
GO(gtk_file_chooser_unselect_uri, vFpp)
//GO(gtk_file_chooser_widget_accessible_get_type, 
GO(gtk_file_chooser_widget_get_type, LFv)
GO(gtk_file_chooser_widget_new, pFu)
GOM(gtk_file_filter_add_custom, vFEpuppp)
GO(gtk_file_filter_add_mime_type, vFpp)
GO(gtk_file_filter_add_pattern, vFpp)
GO(gtk_file_filter_add_pixbuf_formats, vFp)
GO(gtk_file_filter_filter, iFpp)
GO(gtk_file_filter_flags_get_type, LFv)
GO(gtk_file_filter_get_name, pFp)
GO(gtk_file_filter_get_needed, uFp)
GO(gtk_file_filter_get_type, LFv)
GO(gtk_file_filter_new, pFv)
GO(gtk_file_filter_new_from_gvariant, pFp)
GO(gtk_file_filter_set_name, vFpp)
GO(gtk_file_filter_to_gvariant, pFp)
GO(gtk_fixed_get_type, LFv)
GO(gtk_fixed_move, vFppii)
GO(gtk_fixed_new, pFv)
GO(gtk_fixed_put, vFppii)
GO(gtk_flow_box_accessible_get_type, LFv)
//GOM(gtk_flow_box_bind_model, vFppppp)
GO(gtk_flow_box_child_accessible_get_type, LFv)
GO(gtk_flow_box_child_changed, vFp)
GO(gtk_flow_box_child_get_index, iFp)
GO(gtk_flow_box_child_get_type, LFv)
GO(gtk_flow_box_child_is_selected, iFp)
GO(gtk_flow_box_child_new, pFv)
GO(gtk_flow_box_get_activate_on_single_click, iFp)
GO(gtk_flow_box_get_child_at_index, pFpi)
GO(gtk_flow_box_get_child_at_pos, pFpii)
GO(gtk_flow_box_get_column_spacing, uFp)
GO(gtk_flow_box_get_homogeneous, iFp)
GO(gtk_flow_box_get_max_children_per_line, uFp)
GO(gtk_flow_box_get_min_children_per_line, uFp)
GO(gtk_flow_box_get_row_spacing, uFp)
GO(gtk_flow_box_get_selected_children, pFp)
GO(gtk_flow_box_get_selection_mode, uFp)
GO(gtk_flow_box_get_type, LFv)
GO(gtk_flow_box_insert, vFppi)
GO(gtk_flow_box_invalidate_filter, vFp)
GO(gtk_flow_box_invalidate_sort, vFp)
GO(gtk_flow_box_new, pFv)
GO(gtk_flow_box_select_all, vFp)
GO(gtk_flow_box_select_child, vFpp)
//GOM(gtk_flow_box_selected_foreach, vFppp)
GO(gtk_flow_box_set_activate_on_single_click, vFpi)
GO(gtk_flow_box_set_column_spacing, vFpu)
//GOM(gtk_flow_box_set_filter_func, vFpppp)
GO(gtk_flow_box_set_hadjustment, vFpp)
GO(gtk_flow_box_set_homogeneous, vFpi)
GO(gtk_flow_box_set_max_children_per_line, vFpu)
GO(gtk_flow_box_set_min_children_per_line, vFpu)
GO(gtk_flow_box_set_row_spacing, vFpu)
GO(gtk_flow_box_set_selection_mode, vFpu)
//GOM(gtk_flow_box_set_sort_func, vFpppp)
GO(gtk_flow_box_set_vadjustment, vFpp)
GO(gtk_flow_box_unselect_all, vFp)
GO(gtk_flow_box_unselect_child, vFpp)
GO(gtk_font_button_get_font_name, pFp)
GO(gtk_font_button_get_show_size, iFp)
GO(gtk_font_button_get_show_style, iFp)
GO(gtk_font_button_get_title, pFp)
GO(gtk_font_button_get_type, LFv)
GO(gtk_font_button_get_use_font, iFp)
GO(gtk_font_button_get_use_size, iFp)
GO(gtk_font_button_new, pFv)
GO(gtk_font_button_new_with_font, pFp)
GO(gtk_font_button_set_font_name, iFpp)
GO(gtk_font_button_set_show_size, vFpi)
GO(gtk_font_button_set_show_style, vFpi)
GO(gtk_font_button_set_title, vFpp)
GO(gtk_font_button_set_use_font, vFpi)
GO(gtk_font_button_set_use_size, vFpi)
GO(gtk_font_chooser_dialog_get_type, LFv)
GO(gtk_font_chooser_dialog_new, pFpp)
GO(gtk_font_chooser_get_font, pFp)
GO(gtk_font_chooser_get_font_desc, pFp)
GO(gtk_font_chooser_get_font_face, pFp)
GO(gtk_font_chooser_get_font_family, pFp)
GO(gtk_font_chooser_get_font_features, pFp)
GO(gtk_font_chooser_get_font_map, pFp)
GO(gtk_font_chooser_get_font_size, iFp)
GO(gtk_font_chooser_get_language, pFp)
GO(gtk_font_chooser_get_level, uFp)
GO(gtk_font_chooser_get_preview_text, pFp)
GO(gtk_font_chooser_get_show_preview_entry, iFp)
GO(gtk_font_chooser_get_type, LFv)
GO(gtk_font_chooser_level_get_type, LFv)
//GOM(gtk_font_chooser_set_filter_func, vFpppp)
GO(gtk_font_chooser_set_font, vFpp)
GO(gtk_font_chooser_set_font_desc, vFpp)
GO(gtk_font_chooser_set_font_map, vFpp)
GO(gtk_font_chooser_set_language, vFpp)
GO(gtk_font_chooser_set_level, vFpu)
GO(gtk_font_chooser_set_preview_text, vFpp)
GO(gtk_font_chooser_set_show_preview_entry, vFpi)
GO(gtk_font_chooser_widget_get_type, LFv)
GO(gtk_font_chooser_widget_new, pFv)
GO(gtk_font_selection_dialog_get_cancel_button, pFp)
GO(gtk_font_selection_dialog_get_font_name, pFp)
GO(gtk_font_selection_dialog_get_font_selection, pFp)
GO(gtk_font_selection_dialog_get_ok_button, pFp)
GO(gtk_font_selection_dialog_get_preview_text, pFp)
GO(gtk_font_selection_dialog_get_type, LFv)
GO(gtk_font_selection_dialog_new, pFp)
GO(gtk_font_selection_dialog_set_font_name, iFpp)
GO(gtk_font_selection_dialog_set_preview_text, vFpp)
GO(gtk_font_selection_get_face, pFp)
GO(gtk_font_selection_get_face_list, pFp)
GO(gtk_font_selection_get_family, pFp)
GO(gtk_font_selection_get_family_list, pFp)
GO(gtk_font_selection_get_font_name, pFp)
GO(gtk_font_selection_get_preview_entry, pFp)
GO(gtk_font_selection_get_preview_text, pFp)
GO(gtk_font_selection_get_size, iFp)
GO(gtk_font_selection_get_size_entry, pFp)
GO(gtk_font_selection_get_size_list, pFp)
GO(gtk_font_selection_get_type, LFv)
GO(gtk_font_selection_new, pFv)
GO(gtk_font_selection_set_font_name, iFpp)
GO(gtk_font_selection_set_preview_text, vFpp)
GO(gtk_frame_accessible_get_type, LFv)
GO(gtk_frame_get_label, pFp)
GO(gtk_frame_get_label_align, vFppp)
GO(gtk_frame_get_label_widget, pFp)
GO(gtk_frame_get_shadow_type, uFp)
GO(gtk_frame_get_type, LFv)
GO(gtk_frame_new, pFp)
GO(gtk_frame_set_label, vFpp)
GO(gtk_frame_set_label_align, vFpff)
GO(gtk_frame_set_label_widget, vFpp)
GO(gtk_frame_set_shadow_type, vFpu)
GO(gtk_gesture_drag_get_offset, iFppp)
GO(gtk_gesture_drag_get_start_point, iFppp)
GO(gtk_gesture_drag_get_type, LFv)
GO(gtk_gesture_drag_new, pFp)
GO(gtk_gesture_get_bounding_box, iFpp)
GO(gtk_gesture_get_bounding_box_center, iFppp)
GO(gtk_gesture_get_device, pFp)
GO(gtk_gesture_get_group, pFp)
GO(gtk_gesture_get_last_event, pFpp)
GO(gtk_gesture_get_last_updated_sequence, pFp)
GO(gtk_gesture_get_point, iFpppp)
GO(gtk_gesture_get_sequences, pFp)
GO(gtk_gesture_get_sequence_state, uFpp)
GO(gtk_gesture_get_type, LFv)
GO(gtk_gesture_get_window, pFp)
GO(gtk_gesture_group, vFpp)
GO(gtk_gesture_handles_sequence, iFpp)
GO(gtk_gesture_is_active, iFp)
GO(gtk_gesture_is_grouped_with, iFpp)
GO(gtk_gesture_is_recognized, iFp)
GO(gtk_gesture_long_press_get_type, LFv)
GO(gtk_gesture_long_press_new, pFp)
GO(gtk_gesture_multi_press_get_area, iFpp)
GO(gtk_gesture_multi_press_get_type, LFv)
GO(gtk_gesture_multi_press_new, pFp)
GO(gtk_gesture_multi_press_set_area, vFpp)
GO(gtk_gesture_pan_get_orientation, uFp)
GO(gtk_gesture_pan_get_type, LFv)
GO(gtk_gesture_pan_new, pFpu)
GO(gtk_gesture_pan_set_orientation, vFpu)
GO(gtk_gesture_rotate_get_angle_delta, dFp)
GO(gtk_gesture_rotate_get_type, LFv)
GO(gtk_gesture_rotate_new, pFp)
GO(gtk_gesture_set_sequence_state, iFppu)
GO(gtk_gesture_set_state, iFpu)
GO(gtk_gesture_set_window, vFpp)
GO(gtk_gesture_single_get_button, uFp)
GO(gtk_gesture_single_get_current_button, uFp)
GO(gtk_gesture_single_get_current_sequence, pFp)
GO(gtk_gesture_single_get_exclusive, iFp)
GO(gtk_gesture_single_get_touch_only, iFp)
GO(gtk_gesture_single_get_type, LFv)
GO(gtk_gesture_single_set_button, vFpu)
GO(gtk_gesture_single_set_exclusive, vFpi)
GO(gtk_gesture_single_set_touch_only, vFpi)
GO(gtk_gesture_stylus_get_axes, iFppp)
GO(gtk_gesture_stylus_get_axis, iFpup)
GO(gtk_gesture_stylus_get_device_tool, pFp)
GO(gtk_gesture_stylus_get_type, LFv)
GO(gtk_gesture_stylus_new, pFp)
GO(gtk_gesture_swipe_get_type, LFv)
GO(gtk_gesture_swipe_get_velocity, iFppp)
GO(gtk_gesture_swipe_new, pFp)
GO(gtk_gesture_ungroup, vFp)
GO(gtk_gesture_zoom_get_scale_delta, dFp)
GO(gtk_gesture_zoom_get_type, LFv)
GO(gtk_gesture_zoom_new, pFp)
GO(gtk_get_binary_age, uFv)
GO(gtk_get_current_event, pFv)
GO(gtk_get_current_event_device, pFv)
GO(gtk_get_current_event_state, iFp)
GO(gtk_get_current_event_time, uFv)
GO(gtk_get_debug_flags, uFv)
GO(gtk_get_default_language, pFv)
GO(gtk_get_event_widget, pFp)
GO(gtk_get_interface_age, uFv)
GO(gtk_get_locale_direction, uFv)
GO(gtk_get_major_version, uFv)
GO(gtk_get_micro_version, uFv)
GO(gtk_get_minor_version, uFv)
GO(gtk_get_option_group, pFi)
//GO(gtk_glade_catalog_init, 
GO(gtk_gl_area_attach_buffers, vFp)
GO(gtk_gl_area_get_auto_render, iFp)
GO(gtk_gl_area_get_context, pFp)
GO(gtk_gl_area_get_error, pFp)
GO(gtk_gl_area_get_has_alpha, iFp)
GO(gtk_gl_area_get_has_depth_buffer, iFp)
GO(gtk_gl_area_get_has_stencil_buffer, iFp)
GO(gtk_gl_area_get_required_version, vFppp)
GO(gtk_gl_area_get_type, LFv)
GO(gtk_gl_area_get_use_es, iFp)
GO(gtk_gl_area_make_current, vFp)
GO(gtk_gl_area_new, pFv)
GO(gtk_gl_area_queue_render, vFp)
GO(gtk_gl_area_set_auto_render, vFpi)
GO(gtk_gl_area_set_error, vFpp)
GO(gtk_gl_area_set_has_alpha, vFpi)
GO(gtk_gl_area_set_has_depth_buffer, vFpi)
GO(gtk_gl_area_set_has_stencil_buffer, vFpi)
GO(gtk_gl_area_set_required_version, vFpii)
GO(gtk_gl_area_set_use_es, vFpi)
GO(gtk_grab_add, vFp)
GO(gtk_grab_get_current, pFv)
GO(gtk_grab_remove, vFp)
GO(gtk_gradient_add_color_stop, vFpdp)
GO(gtk_gradient_get_type, LFv)
GO(gtk_gradient_new_linear, pFdddd)
GO(gtk_gradient_new_radial, pFdddddd)
GO(gtk_gradient_ref, pFp)
GO(gtk_gradient_resolve, iFppp)
GO(gtk_gradient_resolve_for_context, pFpp)
GO(gtk_gradient_to_string, pFp)
GO(gtk_gradient_unref, vFp)
GO(gtk_grid_attach, vFppiiii)
GO(gtk_grid_attach_next_to, vFpppuii)
GO(gtk_grid_get_baseline_row, iFp)
GO(gtk_grid_get_child_at, pFpii)
GO(gtk_grid_get_column_homogeneous, iFp)
GO(gtk_grid_get_column_spacing, uFp)
GO(gtk_grid_get_row_baseline_position, uFpi)
GO(gtk_grid_get_row_homogeneous, iFp)
GO(gtk_grid_get_row_spacing, uFp)
GO(gtk_grid_get_type, LFv)
GO(gtk_grid_insert_column, vFpi)
GO(gtk_grid_insert_next_to, vFppu)
GO(gtk_grid_insert_row, vFpi)
GO(gtk_grid_new, pFv)
GO(gtk_grid_remove_column, vFpi)
GO(gtk_grid_remove_row, vFpi)
GO(gtk_grid_set_baseline_row, vFpi)
GO(gtk_grid_set_column_homogeneous, vFpi)
GO(gtk_grid_set_column_spacing, vFpu)
GO(gtk_grid_set_row_baseline_position, vFpiu)
GO(gtk_grid_set_row_homogeneous, vFpi)
GO(gtk_grid_set_row_spacing, vFpu)
GO(gtk_handle_box_get_child_detached, iFp)
GO(gtk_handle_box_get_handle_position, uFp)
GO(gtk_handle_box_get_shadow_type, uFp)
GO(gtk_handle_box_get_snap_edge, uFp)
GO(gtk_handle_box_get_type, LFv)
GO(gtk_handle_box_new, pFv)
GO(gtk_handle_box_set_handle_position, vFpu)
GO(gtk_handle_box_set_shadow_type, vFpu)
GO(gtk_handle_box_set_snap_edge, vFpu)
GO(gtk_hbox_get_type, LFv)
GO(gtk_hbox_new, pFii)
GO(gtk_hbutton_box_get_type, LFv)
GO(gtk_hbutton_box_new, pFv)
//GO(gtk_header_bar_accessible_get_type, 
GO(gtk_header_bar_get_custom_title, pFp)
GO(gtk_header_bar_get_decoration_layout, pFp)
GO(gtk_header_bar_get_has_subtitle, iFp)
GO(gtk_header_bar_get_show_close_button, iFp)
GO(gtk_header_bar_get_subtitle, pFp)
GO(gtk_header_bar_get_title, pFp)
GO(gtk_header_bar_get_type, LFv)
GO(gtk_header_bar_new, pFv)
GO(gtk_header_bar_pack_end, vFpp)
GO(gtk_header_bar_pack_start, vFpp)
GO(gtk_header_bar_set_custom_title, vFpp)
GO(gtk_header_bar_set_decoration_layout, vFpp)
GO(gtk_header_bar_set_has_subtitle, vFpi)
GO(gtk_header_bar_set_show_close_button, vFpi)
GO(gtk_header_bar_set_subtitle, vFpp)
GO(gtk_header_bar_set_title, vFpp)
GO(gtk_hpaned_get_type, LFv)
GO(gtk_hpaned_new, pFv)
GO(gtk_hscale_get_type, LFv)
GO(gtk_hscale_new, pFp)
GO(gtk_hscale_new_with_range, pFddd)
GO(gtk_hscrollbar_get_type, LFv)
GO(gtk_hscrollbar_new, pFp)
GO(gtk_hseparator_get_type, LFv)
GO(gtk_hseparator_new, pFv)
GO(gtk_hsv_get_color, vFpppp)
GO(gtk_hsv_get_metrics, vFppp)
GO(gtk_hsv_get_type, LFv)
GO(gtk_hsv_is_adjusting, iFp)
GO(gtk_hsv_new, pFv)
GO(gtk_hsv_set_color, vFpddd)
GO(gtk_hsv_set_metrics, vFpii)
GO(gtk_hsv_to_rgb, vFdddppp)
GO(gtk_icon_factory_add, vFppp)
GO(gtk_icon_factory_add_default, vFp)
GO(gtk_icon_factory_get_type, LFv)
GO(gtk_icon_factory_lookup, pFpp)
GO(gtk_icon_factory_lookup_default, pFp)
GO(gtk_icon_factory_new, pFv)
GO(gtk_icon_factory_remove_default, vFp)
GO(gtk_icon_info_copy, pFp)
GO(gtk_icon_info_free, vFp)
GO(gtk_icon_info_get_attach_points, iFppp)
GO(gtk_icon_info_get_base_scale, iFp)
GO(gtk_icon_info_get_base_size, iFp)
GO(gtk_icon_info_get_builtin_pixbuf, pFp)
GO(gtk_icon_info_get_display_name, pFp)
GO(gtk_icon_info_get_embedded_rect, iFpp)
GO(gtk_icon_info_get_filename, pFp)
GO(gtk_icon_info_get_type, LFv)
GO(gtk_icon_info_is_symbolic, iFp)
GO(gtk_icon_info_load_icon, pFpp)
//GOM(gtk_icon_info_load_icon_async, vFpppp)
GO(gtk_icon_info_load_icon_finish, pFppp)
GO(gtk_icon_info_load_surface, pFppp)
GO(gtk_icon_info_load_symbolic, pFppppppp)
//GOM(gtk_icon_info_load_symbolic_async, vFpppppppp)
GO(gtk_icon_info_load_symbolic_finish, pFpppp)
GO(gtk_icon_info_load_symbolic_for_context, pFpppp)
//GOM(gtk_icon_info_load_symbolic_for_context_async, vFppppp)
GO(gtk_icon_info_load_symbolic_for_context_finish, pFpppp)
GO(gtk_icon_info_load_symbolic_for_style, pFppupp)
GO(gtk_icon_info_new_for_pixbuf, pFpp)
GO(gtk_icon_info_set_raw_coordinates, vFpi)
GO(gtk_icon_lookup_flags_get_type, LFv)
GO(gtk_icon_set_add_source, vFpp)
GO(gtk_icon_set_copy, pFp)
GO(gtk_icon_set_get_sizes, vFppp)
GO(gtk_icon_set_get_type, LFv)
GO(gtk_icon_set_new, pFv)
GO(gtk_icon_set_new_from_pixbuf, pFp)
GO(gtk_icon_set_ref, pFp)
GO(gtk_icon_set_render_icon, pFppuuupp)
GO(gtk_icon_set_render_icon_pixbuf, pFppu)
GO(gtk_icon_set_render_icon_surface, pFppuip)
GO(gtk_icon_set_unref, vFp)
GO(gtk_icon_size_from_name, uFp)
GO(gtk_icon_size_get_name, pFu)
GO(gtk_icon_size_get_type, LFv)
GO(gtk_icon_size_lookup, iFupp)
GO(gtk_icon_size_lookup_for_settings, iFpupp)
GO(gtk_icon_size_register, uFpii)
GO(gtk_icon_size_register_alias, vFpu)
GO(gtk_icon_source_copy, pFp)
GO(gtk_icon_source_free, vFp)
GO(gtk_icon_source_get_direction, uFp)
GO(gtk_icon_source_get_direction_wildcarded, iFp)
GO(gtk_icon_source_get_filename, pFp)
GO(gtk_icon_source_get_icon_name, pFp)
GO(gtk_icon_source_get_pixbuf, pFp)
GO(gtk_icon_source_get_size, uFp)
GO(gtk_icon_source_get_size_wildcarded, iFp)
GO(gtk_icon_source_get_state, uFp)
GO(gtk_icon_source_get_state_wildcarded, iFp)
GO(gtk_icon_source_get_type, LFv)
GO(gtk_icon_source_new, pFv)
GO(gtk_icon_source_set_direction, vFpu)
GO(gtk_icon_source_set_direction_wildcarded, vFpi)
GO(gtk_icon_source_set_filename, vFpp)
GO(gtk_icon_source_set_icon_name, vFpp)
GO(gtk_icon_source_set_pixbuf, vFpp)
GO(gtk_icon_source_set_size, vFpu)
GO(gtk_icon_source_set_size_wildcarded, vFpi)
GO(gtk_icon_source_set_state, vFpu)
GO(gtk_icon_source_set_state_wildcarded, vFpi)
GO(gtk_icon_theme_add_builtin_icon, vFpip)
GO(gtk_icon_theme_add_resource_path, vFpp)
GO(gtk_icon_theme_append_search_path, vFpp)
GO(gtk_icon_theme_choose_icon, pFppiu)
GO(gtk_icon_theme_choose_icon_for_scale, pFppiiu)
GO(gtk_icon_theme_error_get_type, LFv)
GO(gtk_icon_theme_error_quark, uFv)
GO(gtk_icon_theme_get_default, pFv)
GO(gtk_icon_theme_get_example_icon_name, pFp)
GO(gtk_icon_theme_get_for_display, pFp)
GO(gtk_icon_theme_get_for_screen, pFp)
GO(gtk_icon_theme_get_icon_sizes, pFpp)
GO(gtk_icon_theme_get_search_path, vFppp)
GO(gtk_icon_theme_get_type, LFv)
GO(gtk_icon_theme_has_icon, iFpp)
GO(gtk_icon_theme_list_contexts, pFp)
GO(gtk_icon_theme_list_icons, pFpp)
GO(gtk_icon_theme_load_icon, pFppiup)
GO(gtk_icon_theme_load_icon_for_scale, pFppiiup)
GO(gtk_icon_theme_load_surface, pFppiipup)
GO(gtk_icon_theme_lookup_by_gicon, pFppiu)
GO(gtk_icon_theme_lookup_by_gicon_for_scale, pFppiiu)
GO(gtk_icon_theme_lookup_icon, pFppiu)
GO(gtk_icon_theme_lookup_icon_for_scale, pFppiiu)
GO(gtk_icon_theme_new, pFv)
GO(gtk_icon_theme_prepend_search_path, vFpp)
GO(gtk_icon_theme_rescan_if_needed, iFp)
GO(gtk_icon_theme_set_custom_theme, vFpp)
GO(gtk_icon_theme_set_screen, vFpp)
GO(gtk_icon_theme_set_search_path, vFppi)
GO(gtk_icon_view_accessible_get_type, LFv)
GO(gtk_icon_view_convert_widget_to_bin_window_coords, vFpiipp)
GO(gtk_icon_view_create_drag_icon, pFpp)
GO(gtk_icon_view_drop_position_get_type, LFv)
GO(gtk_icon_view_enable_model_drag_dest, vFppiu)
GO(gtk_icon_view_enable_model_drag_source, vFpupiu)
GO(gtk_icon_view_get_activate_on_single_click, iFp)
GO(gtk_icon_view_get_cell_rect, iFpppp)
GO(gtk_icon_view_get_columns, iFp)
GO(gtk_icon_view_get_column_spacing, iFp)
GO(gtk_icon_view_get_cursor, iFppp)
GO(gtk_icon_view_get_dest_item_at_pos, iFpiipp)
GO(gtk_icon_view_get_drag_dest_item, vFppp)
GO(gtk_icon_view_get_item_at_pos, iFpiipp)
GO(gtk_icon_view_get_item_column, iFpp)
GO(gtk_icon_view_get_item_orientation, uFp)
GO(gtk_icon_view_get_item_padding, iFp)
GO(gtk_icon_view_get_item_row, iFpp)
GO(gtk_icon_view_get_item_width, iFp)
GO(gtk_icon_view_get_margin, iFp)
GO(gtk_icon_view_get_markup_column, iFp)
GO(gtk_icon_view_get_model, pFp)
GO(gtk_icon_view_get_path_at_pos, pFpii)
GO(gtk_icon_view_get_pixbuf_column, iFp)
GO(gtk_icon_view_get_reorderable, iFp)
GO(gtk_icon_view_get_row_spacing, iFp)
GO(gtk_icon_view_get_selected_items, pFp)
GO(gtk_icon_view_get_selection_mode, uFp)
GO(gtk_icon_view_get_spacing, iFp)
GO(gtk_icon_view_get_text_column, iFp)
GO(gtk_icon_view_get_tooltip_column, iFp)
GO(gtk_icon_view_get_tooltip_context, iFpppippp)
GO(gtk_icon_view_get_type, LFv)
GO(gtk_icon_view_get_visible_range, iFppp)
GO(gtk_icon_view_item_activated, vFpp)
GO(gtk_icon_view_new, pFv)
GO(gtk_icon_view_new_with_area, pFp)
GO(gtk_icon_view_new_with_model, pFp)
GO(gtk_icon_view_path_is_selected, iFpp)
GO(gtk_icon_view_scroll_to_path, vFppiff)
GO(gtk_icon_view_select_all, vFp)
//GOM(gtk_icon_view_selected_foreach, vFppp)
GO(gtk_icon_view_select_path, vFpp)
GO(gtk_icon_view_set_activate_on_single_click, vFpi)
GO(gtk_icon_view_set_columns, vFpi)
GO(gtk_icon_view_set_column_spacing, vFpi)
GO(gtk_icon_view_set_cursor, vFpppi)
GO(gtk_icon_view_set_drag_dest_item, vFppu)
GO(gtk_icon_view_set_item_orientation, vFpu)
GO(gtk_icon_view_set_item_padding, vFpi)
GO(gtk_icon_view_set_item_width, vFpi)
GO(gtk_icon_view_set_margin, vFpi)
GO(gtk_icon_view_set_markup_column, vFpi)
GO(gtk_icon_view_set_model, vFpp)
GO(gtk_icon_view_set_pixbuf_column, vFpi)
GO(gtk_icon_view_set_reorderable, vFpi)
GO(gtk_icon_view_set_row_spacing, vFpi)
GO(gtk_icon_view_set_selection_mode, vFpu)
GO(gtk_icon_view_set_spacing, vFpi)
GO(gtk_icon_view_set_text_column, vFpi)
GO(gtk_icon_view_set_tooltip_cell, vFpppp)
GO(gtk_icon_view_set_tooltip_column, vFpi)
GO(gtk_icon_view_set_tooltip_item, vFppp)
GO(gtk_icon_view_unselect_all, vFp)
GO(gtk_icon_view_unselect_path, vFpp)
GO(gtk_icon_view_unset_model_drag_dest, vFp)
GO(gtk_icon_view_unset_model_drag_source, vFp)
//GO(gtk_identifier_get_type, 
GO(gtk_image_accessible_get_type, LFv)
GO(gtk_image_cell_accessible_get_type, LFv)
GO(gtk_image_clear, vFp)
GO(gtk_image_get_animation, pFp)
GO(gtk_image_get_gicon, vFppp)
GO(gtk_image_get_icon_name, vFppp)
GO(gtk_image_get_icon_set, vFppp)
GO(gtk_image_get_pixbuf, pFp)
GO(gtk_image_get_pixel_size, iFp)
GO(gtk_image_get_stock, vFppp)
GO(gtk_image_get_storage_type, uFp)
GO(gtk_image_get_type, LFv)
GO(gtk_image_menu_item_get_always_show_image, iFp)
GO(gtk_image_menu_item_get_image, pFp)
GO(gtk_image_menu_item_get_type, LFv)
GO(gtk_image_menu_item_get_use_stock, iFp)
GO(gtk_image_menu_item_new, pFv)
GO(gtk_image_menu_item_new_from_stock, pFpp)
GO(gtk_image_menu_item_new_with_label, pFp)
GO(gtk_image_menu_item_new_with_mnemonic, pFp)
GO(gtk_image_menu_item_set_accel_group, vFpp)
GO(gtk_image_menu_item_set_always_show_image, vFpi)
GO(gtk_image_menu_item_set_image, vFpp)
GO(gtk_image_menu_item_set_use_stock, vFpi)
GO(gtk_image_new, pFv)
GO(gtk_image_new_from_animation, pFp)
GO(gtk_image_new_from_file, pFp)
GO(gtk_image_new_from_gicon, pFpu)
GO(gtk_image_new_from_icon_name, pFpu)
GO(gtk_image_new_from_icon_set, pFpu)
GO(gtk_image_new_from_pixbuf, pFp)
GO(gtk_image_new_from_resource, pFp)
GO(gtk_image_new_from_stock, pFpu)
GO(gtk_image_new_from_surface, pFp)
GO(gtk_image_set_from_animation, vFpp)
GO(gtk_image_set_from_file, vFpp)
GO(gtk_image_set_from_gicon, vFppu)
GO(gtk_image_set_from_icon_name, vFppu)
GO(gtk_image_set_from_icon_set, vFppu)
GO(gtk_image_set_from_pixbuf, vFpp)
GO(gtk_image_set_from_resource, vFpp)
GO(gtk_image_set_from_stock, vFppu)
GO(gtk_image_set_from_surface, vFpp)
GO(gtk_image_set_pixel_size, vFpi)
GO(gtk_image_type_get_type, LFv)
GO(gtk_im_context_delete_surrounding, iFpii)
GO(gtk_im_context_filter_key, iFpippuuui)
GO(gtk_im_context_filter_keypress, iFpp)
GO(gtk_im_context_focus_in, vFp)
GO(gtk_im_context_focus_out, vFp)
GO(gtk_im_context_get_preedit_string, vFpppp)
GO(gtk_im_context_get_surrounding, iFppp)
GO(gtk_im_context_get_type, LFv)
GO(gtk_im_context_reset, vFp)
GO(gtk_im_context_set_client_widget, vFpp)
GO(gtk_im_context_set_client_window, vFpp)
GO(gtk_im_context_set_cursor_location, vFpp)
GO(gtk_im_context_set_surrounding, vFppii)
GO(gtk_im_context_set_use_preedit, vFpi)
GO(gtk_im_context_simple_add_compose_file, vFpp)
GO(gtk_im_context_simple_add_table, vFppii)
GO(gtk_im_context_simple_get_type, LFv)
GO(gtk_im_context_simple_new, pFv)
GO(gtk_im_multicontext_append_menuitems, vFpp)
GO(gtk_im_multicontext_get_context_id, pFp)
GO(gtk_im_multicontext_get_type, LFv)
GO(gtk_im_multicontext_new, pFv)
GO(gtk_im_multicontext_set_context_id, vFpp)
GO(gtk_im_preedit_style_get_type, LFv)
GO(gtk_im_status_style_get_type, LFv)
GO(gtk_info_bar_add_action_widget, vFppi)
GO(gtk_info_bar_add_button, pFppi)
//GOM(gtk_info_bar_add_buttons, vFppV)
GO(gtk_info_bar_get_action_area, pFp)
GO(gtk_info_bar_get_content_area, pFp)
GO(gtk_info_bar_get_message_type, uFp)
GO(gtk_info_bar_get_revealed, iFp)
GO(gtk_info_bar_get_show_close_button, iFp)
GO(gtk_info_bar_get_type, LFv)
GO(gtk_info_bar_new, pFv)
//GOM(gtk_info_bar_new_with_buttons, pFpV)
GO(gtk_info_bar_response, vFpi)
GO(gtk_info_bar_set_default_response, vFpi)
GO(gtk_info_bar_set_message_type, vFpu)
GO(gtk_info_bar_set_response_sensitive, vFpii)
GO(gtk_info_bar_set_revealed, vFpi)
GO(gtk_info_bar_set_show_close_button, vFpi)
GOM(gtk_init, vFEpp)
GOM(gtk_init_check, iFEpp)
GOM(gtk_init_with_args, iFEpppppp)
GO(gtk_input_hints_get_type, LFv)
GO(gtk_input_purpose_get_type, LFv)
GO(gtk_invisible_get_screen, pFp)
GO(gtk_invisible_get_type, LFv)
GO(gtk_invisible_new, pFv)
GO(gtk_invisible_new_for_screen, pFp)
GO(gtk_invisible_set_screen, vFpp)
GO(gtk_junction_sides_get_type, LFv)
GO(gtk_justification_get_type, LFv)
//GOM(gtk_key_snooper_install, uFpp)
GO(gtk_key_snooper_remove, vFu)
GO(gtk_label_accessible_get_type, LFv)
GO(gtk_label_get_angle, dFp)
GO(gtk_label_get_attributes, pFp)
GO(gtk_label_get_current_uri, pFp)
GO(gtk_label_get_ellipsize, uFp)
GO(gtk_label_get_justify, uFp)
GO(gtk_label_get_label, pFp)
GO(gtk_label_get_layout, pFp)
GO(gtk_label_get_layout_offsets, vFppp)
GO(gtk_label_get_lines, iFp)
GO(gtk_label_get_line_wrap, iFp)
GO(gtk_label_get_line_wrap_mode, uFp)
GO(gtk_label_get_max_width_chars, iFp)
GO(gtk_label_get_mnemonic_keyval, uFp)
GO(gtk_label_get_mnemonic_widget, pFp)
GO(gtk_label_get_selectable, iFp)
GO(gtk_label_get_selection_bounds, iFppp)
GO(gtk_label_get_single_line_mode, iFp)
GO(gtk_label_get_text, pFp)
GO(gtk_label_get_track_visited_links, iFp)
GO(gtk_label_get_type, LFv)
GO(gtk_label_get_use_markup, iFp)
GO(gtk_label_get_use_underline, iFp)
GO(gtk_label_get_width_chars, iFp)
GO(gtk_label_get_xalign, fFp)
GO(gtk_label_get_yalign, fFp)
GO(gtk_label_new, pFp)
GO(gtk_label_new_with_mnemonic, pFp)
GO(gtk_label_select_region, vFpii)
GO(gtk_label_set_angle, vFpd)
GO(gtk_label_set_attributes, vFpp)
GO(gtk_label_set_ellipsize, vFpu)
GO(gtk_label_set_justify, vFpu)
GO(gtk_label_set_label, vFpp)
GO(gtk_label_set_lines, vFpi)
GO(gtk_label_set_line_wrap, vFpi)
GO(gtk_label_set_line_wrap_mode, vFpu)
GO(gtk_label_set_markup, vFpp)
GO(gtk_label_set_markup_with_mnemonic, vFpp)
GO(gtk_label_set_max_width_chars, vFpi)
GO(gtk_label_set_mnemonic_widget, vFpp)
GO(gtk_label_set_pattern, vFpp)
GO(gtk_label_set_selectable, vFpi)
GO(gtk_label_set_single_line_mode, vFpi)
GO(gtk_label_set_text, vFpp)
GO(gtk_label_set_text_with_mnemonic, vFpp)
GO(gtk_label_set_track_visited_links, vFpi)
GO(gtk_label_set_use_markup, vFpi)
GO(gtk_label_set_use_underline, vFpi)
GO(gtk_label_set_width_chars, vFpi)
GO(gtk_label_set_xalign, vFpf)
GO(gtk_label_set_yalign, vFpf)
GO(gtk_layout_get_bin_window, pFp)
GO(gtk_layout_get_hadjustment, pFp)
GO(gtk_layout_get_size, vFppp)
GO(gtk_layout_get_type, LFv)
GO(gtk_layout_get_vadjustment, pFp)
GO(gtk_layout_move, vFppii)
GO(gtk_layout_new, pFpp)
GO(gtk_layout_put, vFppii)
GO(gtk_layout_set_hadjustment, vFpp)
GO(gtk_layout_set_size, vFpuu)
GO(gtk_layout_set_vadjustment, vFpp)
GO(gtk_level_bar_accessible_get_type, LFv)
GO(gtk_level_bar_add_offset_value, vFppd)
GO(gtk_level_bar_get_inverted, iFp)
GO(gtk_level_bar_get_max_value, dFp)
GO(gtk_level_bar_get_min_value, dFp)
GO(gtk_level_bar_get_mode, uFp)
GO(gtk_level_bar_get_offset_value, iFppp)
GO(gtk_level_bar_get_type, LFv)
GO(gtk_level_bar_get_value, dFp)
GO(gtk_level_bar_mode_get_type, LFv)
GO(gtk_level_bar_new, pFv)
GO(gtk_level_bar_new_for_interval, pFdd)
GO(gtk_level_bar_remove_offset_value, vFpp)
GO(gtk_level_bar_set_inverted, vFpi)
GO(gtk_level_bar_set_max_value, vFpd)
GO(gtk_level_bar_set_min_value, vFpd)
GO(gtk_level_bar_set_mode, vFpu)
GO(gtk_level_bar_set_value, vFpd)
GO(gtk_license_get_type, LFv)
GO(gtk_link_button_accessible_get_type, LFv)
GO(gtk_link_button_get_type, LFv)
GO(gtk_link_button_get_uri, pFp)
GO(gtk_link_button_get_visited, iFp)
GO(gtk_link_button_new, pFp)
GO(gtk_link_button_new_with_label, pFpp)
GO(gtk_link_button_set_uri, vFpp)
GO(gtk_link_button_set_visited, vFpi)
GO(gtk_list_box_accessible_get_type, LFv)
//GOM(gtk_list_box_bind_model, vFppppp)
GO(gtk_list_box_drag_highlight_row, vFpp)
GO(gtk_list_box_drag_unhighlight_row, vFp)
GO(gtk_list_box_get_activate_on_single_click, iFp)
GO(gtk_list_box_get_adjustment, pFp)
GO(gtk_list_box_get_row_at_index, pFpi)
GO(gtk_list_box_get_row_at_y, pFpi)
GO(gtk_list_box_get_selected_row, pFp)
GO(gtk_list_box_get_selected_rows, pFp)
GO(gtk_list_box_get_selection_mode, uFp)
GO(gtk_list_box_get_type, LFv)
GO(gtk_list_box_insert, vFppi)
GO(gtk_list_box_invalidate_filter, vFp)
GO(gtk_list_box_invalidate_headers, vFp)
GO(gtk_list_box_invalidate_sort, vFp)
GO(gtk_list_box_new, pFv)
GO(gtk_list_box_prepend, vFpp)
GO(gtk_list_box_row_accessible_get_type, LFv)
GO(gtk_list_box_row_changed, vFp)
GO(gtk_list_box_row_get_activatable, iFp)
GO(gtk_list_box_row_get_header, pFp)
GO(gtk_list_box_row_get_index, iFp)
GO(gtk_list_box_row_get_selectable, iFp)
GO(gtk_list_box_row_get_type, LFv)
GO(gtk_list_box_row_is_selected, iFp)
GO(gtk_list_box_row_new, pFv)
GO(gtk_list_box_row_set_activatable, vFpi)
GO(gtk_list_box_row_set_header, vFpp)
GO(gtk_list_box_row_set_selectable, vFpi)
GO(gtk_list_box_select_all, vFp)
//GOM(gtk_list_box_selected_foreach, vFppp)
GO(gtk_list_box_select_row, vFpp)
GO(gtk_list_box_set_activate_on_single_click, vFpi)
GO(gtk_list_box_set_adjustment, vFpp)
//GOM(gtk_list_box_set_filter_func, vFpppp)
GOM(gtk_list_box_set_header_func, vFEpppp)
GO(gtk_list_box_set_placeholder, vFpp)
GO(gtk_list_box_set_selection_mode, vFpu)
//GOM(gtk_list_box_set_sort_func, vFpppp)
GO(gtk_list_box_unselect_all, vFp)
GO(gtk_list_box_unselect_row, vFpp)
GO(gtk_list_store_append, vFpp)
GO(gtk_list_store_clear, vFp)
GO(gtk_list_store_get_type, LFv)
GO(gtk_list_store_insert, vFppi)
GO(gtk_list_store_insert_after, vFppp)
GO(gtk_list_store_insert_before, vFppp)
GOM(gtk_list_store_insert_with_values, vFEppiV)
GO(gtk_list_store_insert_with_valuesv, vFppippi)
GO(gtk_list_store_iter_is_valid, iFpp)
GO(gtk_list_store_move_after, vFppp)
GO(gtk_list_store_move_before, vFppp)
GO2(gtk_list_store_new, pFiV, gtk_list_store_newv)
GO(gtk_list_store_newv, pFip)
GO(gtk_list_store_prepend, vFpp)
GO(gtk_list_store_remove, iFpp)
GO(gtk_list_store_reorder, vFpp)
GOM(gtk_list_store_set, vFEppV)
GO(gtk_list_store_set_column_types, vFpip)
GOM(gtk_list_store_set_valist, vFEppA)
GO(gtk_list_store_set_value, vFppip)
GO(gtk_list_store_set_valuesv, vFppppi)
GO(gtk_list_store_swap, vFppp)
GO(gtk_lock_button_accessible_get_type, LFv)
GO(gtk_lock_button_get_permission, pFp)
GO(gtk_lock_button_get_type, LFv)
GO(gtk_lock_button_new, pFp)
GO(gtk_lock_button_set_permission, vFpp)
GO(gtk_main, vFv)
GO(gtk_main_do_event, vFp)
GO(gtk_main_iteration, iFv)
GO(gtk_main_iteration_do, iFi)
GO(gtk_main_level, uFv)
GO(gtk_main_quit, vFv)
GO(gtk_menu_accessible_get_type, LFv)
GO(gtk_menu_attach, vFppuuuu)
GOM(gtk_menu_attach_to_widget, vFEppp)
GO(gtk_menu_bar_get_child_pack_direction, uFp)
GO(gtk_menu_bar_get_pack_direction, uFp)
GO(gtk_menu_bar_get_type, LFv)
GO(gtk_menu_bar_new, pFv)
GO(gtk_menu_bar_new_from_model, pFp)
GO(gtk_menu_bar_set_child_pack_direction, vFpu)
GO(gtk_menu_bar_set_pack_direction, vFpu)
GO(gtk_menu_button_accessible_get_type, LFv)
GO(gtk_menu_button_get_align_widget, pFp)
GO(gtk_menu_button_get_direction, uFp)
GO(gtk_menu_button_get_menu_model, pFp)
GO(gtk_menu_button_get_popover, pFp)
GO(gtk_menu_button_get_popup, pFp)
GO(gtk_menu_button_get_type, LFv)
GO(gtk_menu_button_get_use_popover, iFp)
GO(gtk_menu_button_new, pFv)
GO(gtk_menu_button_set_align_widget, vFpp)
GO(gtk_menu_button_set_direction, vFpu)
GO(gtk_menu_button_set_menu_model, vFpp)
GO(gtk_menu_button_set_popover, vFpp)
GO(gtk_menu_button_set_popup, vFpp)
GO(gtk_menu_button_set_use_popover, vFpi)
GO(gtk_menu_detach, vFp)
GO(gtk_menu_direction_type_get_type, LFv)
GO(gtk_menu_get_accel_group, pFp)
GO(gtk_menu_get_accel_path, pFp)
GO(gtk_menu_get_active, pFp)
GO(gtk_menu_get_attach_widget, pFp)
GO(gtk_menu_get_for_attach_widget, pFp)
GO(gtk_menu_get_monitor, iFp)
GO(gtk_menu_get_reserve_toggle_size, iFp)
GO(gtk_menu_get_tearoff_state, iFp)
GO(gtk_menu_get_title, pFp)
GO(gtk_menu_get_type, LFv)
GO(gtk_menu_item_accessible_get_type, LFv)
GO(gtk_menu_item_activate, vFp)
GO(gtk_menu_item_deselect, vFp)
GO(gtk_menu_item_get_accel_path, pFp)
GO(gtk_menu_item_get_label, pFp)
GO(gtk_menu_item_get_reserve_indicator, iFp)
GO(gtk_menu_item_get_right_justified, iFp)
GO(gtk_menu_item_get_submenu, pFp)
GO(gtk_menu_item_get_type, LFv)
GO(gtk_menu_item_get_use_underline, iFp)
GO(gtk_menu_item_new, pFv)
GO(gtk_menu_item_new_with_label, pFp)
GO(gtk_menu_item_new_with_mnemonic, pFp)
GO(gtk_menu_item_select, vFp)
GO(gtk_menu_item_set_accel_path, vFpp)
GO(gtk_menu_item_set_label, vFpp)
GO(gtk_menu_item_set_reserve_indicator, vFpi)
GO(gtk_menu_item_set_right_justified, vFpi)
GO(gtk_menu_item_set_submenu, vFpp)
GO(gtk_menu_item_set_use_underline, vFpi)
GO(gtk_menu_item_toggle_size_allocate, vFpi)
GO(gtk_menu_item_toggle_size_request, vFpp)
GO(gtk_menu_new, pFv)
GO(gtk_menu_new_from_model, pFp)
GO(gtk_menu_place_on_monitor, vFpp)
GO(gtk_menu_popdown, vFp)
GOM(gtk_menu_popup, vFEpppppuu)
GO(gtk_menu_popup_at_pointer, vFpp)
GO(gtk_menu_popup_at_rect, vFpppuup)
GO(gtk_menu_popup_at_widget, vFppuup)
//GOM(gtk_menu_popup_for_device, vFpppppppuu)
GO(gtk_menu_reorder_child, vFppi)
GO(gtk_menu_reposition, vFp)
GO(gtk_menu_set_accel_group, vFpp)
GO(gtk_menu_set_accel_path, vFpp)
GO(gtk_menu_set_active, vFpu)
GO(gtk_menu_set_monitor, vFpi)
GO(gtk_menu_set_reserve_toggle_size, vFpi)
GO(gtk_menu_set_screen, vFpp)
GO(gtk_menu_set_tearoff_state, vFpi)
GO(gtk_menu_set_title, vFpp)
GO(gtk_menu_shell_accessible_get_type, LFv)
GO(gtk_menu_shell_activate_item, vFppi)
GO(gtk_menu_shell_append, vFpp)
GO(gtk_menu_shell_bind_model, vFpppi)
GO(gtk_menu_shell_cancel, vFp)
GO(gtk_menu_shell_deactivate, vFp)
GO(gtk_menu_shell_deselect, vFp)
GO(gtk_menu_shell_get_parent_shell, pFp)
GO(gtk_menu_shell_get_selected_item, pFp)
GO(gtk_menu_shell_get_take_focus, iFp)
GO(gtk_menu_shell_get_type, LFv)
GO(gtk_menu_shell_insert, vFppi)
GO(gtk_menu_shell_prepend, vFpp)
GO(gtk_menu_shell_select_first, vFpi)
GO(gtk_menu_shell_select_item, vFpp)
GO(gtk_menu_shell_set_take_focus, vFpi)
GO(gtk_menu_tool_button_get_menu, pFp)
GO(gtk_menu_tool_button_get_type, LFv)
GO(gtk_menu_tool_button_new, pFpp)
GO(gtk_menu_tool_button_new_from_stock, pFp)
GO(gtk_menu_tool_button_set_arrow_tooltip_markup, vFpp)
GO(gtk_menu_tool_button_set_arrow_tooltip_text, vFpp)
GO(gtk_menu_tool_button_set_menu, vFpp)
GOM(gtk_message_dialog_format_secondary_markup, vFEppV)
GOM(gtk_message_dialog_format_secondary_text, vFEppV)
GO(gtk_message_dialog_get_image, pFp)
GO(gtk_message_dialog_get_message_area, pFp)
GO(gtk_message_dialog_get_type, LFv)
GO(gtk_message_dialog_new, pFpuiippppppppppp)   // vaarg :(
GO(gtk_message_dialog_new_with_markup, pFpuiippppppppppp)   // vaarg
GO(gtk_message_dialog_set_image, vFpp)
GO(gtk_message_dialog_set_markup, vFpp)
GO(gtk_message_type_get_type, LFv)
GO(gtk_misc_get_alignment, vFppp)
GO(gtk_misc_get_padding, vFppp)
GO(gtk_misc_get_type, LFv)
GO(gtk_misc_set_alignment, vFpff)
GO(gtk_misc_set_padding, vFpii)
GO(gtk_model_button_get_type, LFv)
GO(gtk_model_button_new, pFv)
GO(gtk_mount_operation_get_parent, pFp)
GO(gtk_mount_operation_get_screen, pFp)
GO(gtk_mount_operation_get_type, LFv)
GO(gtk_mount_operation_is_showing, iFp)
GO(gtk_mount_operation_new, pFp)
GO(gtk_mount_operation_set_parent, vFpp)
GO(gtk_mount_operation_set_screen, vFpp)
GO(gtk_movement_step_get_type, LFv)
GO(gtk_native_dialog_destroy, vFp)
GO(gtk_native_dialog_get_modal, iFp)
GO(gtk_native_dialog_get_title, pFp)
GO(gtk_native_dialog_get_transient_for, pFp)
GO(gtk_native_dialog_get_type, LFv)
GO(gtk_native_dialog_get_visible, iFp)
GO(gtk_native_dialog_hide, vFp)
GO(gtk_native_dialog_run, iFp)
GO(gtk_native_dialog_set_modal, vFpi)
GO(gtk_native_dialog_set_title, vFpp)
GO(gtk_native_dialog_set_transient_for, vFpp)
GO(gtk_native_dialog_show, vFp)
GO(gtk_native_get_surface, pFp)
GO(gtk_notebook_accessible_get_type, LFv)
GO(gtk_notebook_append_page, iFppp)
GO(gtk_notebook_append_page_menu, iFpppp)
GO(gtk_notebook_detach_tab, vFpp)
GO(gtk_notebook_get_action_widget, pFpu)
GO(gtk_notebook_get_current_page, iFp)
GO(gtk_notebook_get_group_name, pFp)
GO(gtk_notebook_get_menu_label, pFpp)
GO(gtk_notebook_get_menu_label_text, pFpp)
GO(gtk_notebook_get_n_pages, iFp)
GO(gtk_notebook_get_nth_page, pFpi)
GO(gtk_notebook_get_scrollable, iFp)
GO(gtk_notebook_get_show_border, iFp)
GO(gtk_notebook_get_show_tabs, iFp)
GO(gtk_notebook_get_tab_detachable, iFpp)
GO(gtk_notebook_get_tab_hborder, WFp)
GO(gtk_notebook_get_tab_label, pFpp)
GO(gtk_notebook_get_tab_label_text, pFpp)
GO(gtk_notebook_get_tab_pos, uFp)
GO(gtk_notebook_get_tab_reorderable, iFpp)
GO(gtk_notebook_get_tab_vborder, WFp)
GO(gtk_notebook_get_type, LFv)
GO(gtk_notebook_insert_page, iFpppi)
GO(gtk_notebook_insert_page_menu, iFppppi)
GO(gtk_notebook_new, pFv)
GO(gtk_notebook_next_page, vFp)
GO(gtk_notebook_page_accessible_get_type, LFv)
GO(gtk_notebook_page_accessible_invalidate, vFp)
GO(gtk_notebook_page_accessible_new, pFpp)
GO(gtk_notebook_page_num, iFpp)
GO(gtk_notebook_popup_disable, vFp)
GO(gtk_notebook_popup_enable, vFp)
GO(gtk_notebook_prepend_page, iFppp)
GO(gtk_notebook_prepend_page_menu, iFpppp)
GO(gtk_notebook_prev_page, vFp)
GO(gtk_notebook_remove_page, vFpi)
GO(gtk_notebook_reorder_child, vFppi)
GO(gtk_notebook_set_action_widget, vFppu)
GO(gtk_notebook_set_current_page, vFpi)
GO(gtk_notebook_set_group_name, vFpp)
GO(gtk_notebook_set_menu_label, vFppp)
GO(gtk_notebook_set_menu_label_text, vFppp)
GO(gtk_notebook_set_scrollable, vFpi)
GO(gtk_notebook_set_show_border, vFpi)
GO(gtk_notebook_set_show_tabs, vFpi)
GO(gtk_notebook_set_tab_detachable, vFppi)
GO(gtk_notebook_set_tab_label, vFppp)
GO(gtk_notebook_set_tab_label_text, vFppp)
GO(gtk_notebook_set_tab_pos, vFpu)
GO(gtk_notebook_set_tab_reorderable, vFppi)
GO(gtk_notebook_tab_get_type, LFv)
GO(gtk_number_up_layout_get_type, LFv)
GO(gtk_numerable_icon_get_background_gicon, pFp)
GO(gtk_numerable_icon_get_background_icon_name, pFp)
GO(gtk_numerable_icon_get_count, iFp)
GO(gtk_numerable_icon_get_label, pFp)
GO(gtk_numerable_icon_get_style_context, pFp)
GO(gtk_numerable_icon_get_type, LFv)
GO(gtk_numerable_icon_new, pFp)
GO(gtk_numerable_icon_new_with_style_context, pFpp)
GO(gtk_numerable_icon_set_background_gicon, vFpp)
GO(gtk_numerable_icon_set_background_icon_name, vFpp)
GO(gtk_numerable_icon_set_count, vFpi)
GO(gtk_numerable_icon_set_label, vFpp)
GO(gtk_numerable_icon_set_style_context, vFpp)
GO(gtk_offscreen_window_get_pixbuf, pFp)
GO(gtk_offscreen_window_get_surface, pFp)
GO(gtk_offscreen_window_get_type, LFv)
GO(gtk_offscreen_window_new, pFv)
GO(gtk_orientable_get_orientation, uFp)
GO(gtk_orientable_get_type, LFv)
GO(gtk_orientable_set_orientation, vFpu)
GO(gtk_orientation_get_type, LFv)
GO(gtk_overlay_add_overlay, vFpp)
GO(gtk_overlay_get_overlay_pass_through, iFpp)
GO(gtk_overlay_get_type, LFv)
GO(gtk_overlay_new, pFv)
GO(gtk_overlay_reorder_overlay, vFppi)
GO(gtk_overlay_set_overlay_pass_through, vFppi)
GO(gtk_pack_direction_get_type, LFv)
GO(gtk_pack_type_get_type, LFv)
GO(gtk_pad_action_type_get_type, LFv)
GO(gtk_pad_controller_get_type, LFv)
GO(gtk_pad_controller_new, pFppp)
GO(gtk_pad_controller_set_action, vFpuiipp)
GO(gtk_pad_controller_set_action_entries, vFppi)
GO(gtk_page_orientation_get_type, LFv)
GO(gtk_page_set_get_type, LFv)
GO(gtk_page_setup_copy, pFp)
GO(gtk_page_setup_get_bottom_margin, dFpu)
GO(gtk_page_setup_get_left_margin, dFpu)
GO(gtk_page_setup_get_orientation, uFp)
GO(gtk_page_setup_get_page_height, dFpu)
GO(gtk_page_setup_get_page_width, dFpu)
GO(gtk_page_setup_get_paper_height, dFpu)
GO(gtk_page_setup_get_paper_size, pFp)
GO(gtk_page_setup_get_paper_width, dFpu)
GO(gtk_page_setup_get_right_margin, dFpu)
GO(gtk_page_setup_get_top_margin, dFpu)
GO(gtk_page_setup_get_type, LFv)
GO(gtk_page_setup_load_file, iFppp)
GO(gtk_page_setup_load_key_file, iFpppp)
GO(gtk_page_setup_new, pFv)
GO(gtk_page_setup_new_from_file, pFpp)
GO(gtk_page_setup_new_from_gvariant, pFp)
GO(gtk_page_setup_new_from_key_file, pFppp)
GO(gtk_page_setup_set_bottom_margin, vFpdu)
GO(gtk_page_setup_set_left_margin, vFpdu)
GO(gtk_page_setup_set_orientation, vFpu)
GO(gtk_page_setup_set_paper_size, vFpp)
GO(gtk_page_setup_set_paper_size_and_default_margins, vFpp)
GO(gtk_page_setup_set_right_margin, vFpdu)
GO(gtk_page_setup_set_top_margin, vFpdu)
GO(gtk_page_setup_to_file, iFppp)
GO(gtk_page_setup_to_gvariant, pFp)
GO(gtk_page_setup_to_key_file, vFppp)
GO(gtk_page_setup_unix_dialog_get_page_setup, pFp)
GO(gtk_page_setup_unix_dialog_get_print_settings, pFp)
GO(gtk_page_setup_unix_dialog_get_type, LFv)
GO(gtk_page_setup_unix_dialog_new, pFpp)
GO(gtk_page_setup_unix_dialog_set_page_setup, vFpp)
GO(gtk_page_setup_unix_dialog_set_print_settings, vFpp)
GO(gtk_paint_arrow, vFppuuppuiiiii)
GO(gtk_paint_box, vFppuuppiiii)
GO(gtk_paint_box_gap, vFppuuppiiiiuii)
GO(gtk_paint_check, vFppuuppiiii)
GO(gtk_paint_diamond, vFppuuppiiii)
GO(gtk_paint_expander, vFppuppiiu)
GO(gtk_paint_extension, vFppuuppiiiiu)
GO(gtk_paint_flat_box, vFppuuppiiii)
GO(gtk_paint_focus, vFppuppiiii)
GO(gtk_paint_handle, vFppuuppiiiiu)
GO(gtk_paint_hline, vFppuppiii)
GO(gtk_paint_layout, vFppuippiip)
GO(gtk_paint_option, vFppuuppiiii)
GO(gtk_paint_resize_grip, vFppuppuiiii)
GO(gtk_paint_shadow, vFppuuppiiii)
GO(gtk_paint_shadow_gap, vFppuuppiiiiuii)
GO(gtk_paint_slider, vFppuuppiiiiu)
GO(gtk_paint_spinner, vFppuppuiiii)
GO(gtk_paint_tab, vFppuuppiiii)
GO(gtk_paint_vline, vFppuppiii)
GO(gtk_pan_direction_get_type, LFv)
GO(gtk_paned_accessible_get_type, LFv)
GO(gtk_paned_add1, vFpp)
GO(gtk_paned_add2, vFpp)
GO(gtk_paned_get_child1, pFp)
GO(gtk_paned_get_child2, pFp)
GO(gtk_paned_get_handle_window, pFp)
GO(gtk_paned_get_position, iFp)
GO(gtk_paned_get_type, LFv)
GO(gtk_paned_get_wide_handle, iFp)
GO(gtk_paned_new, pFu)
GO(gtk_paned_pack1, vFppii)
GO(gtk_paned_pack2, vFppii)
GO(gtk_paned_set_position, vFpi)
GO(gtk_paned_set_wide_handle, vFpi)
GO(gtk_paper_size_copy, pFp)
GO(gtk_paper_size_free, vFp)
GO(gtk_paper_size_get_default, pFv)
GO(gtk_paper_size_get_default_bottom_margin, dFpu)
GO(gtk_paper_size_get_default_left_margin, dFpu)
GO(gtk_paper_size_get_default_right_margin, dFpu)
GO(gtk_paper_size_get_default_top_margin, dFpu)
GO(gtk_paper_size_get_display_name, pFp)
GO(gtk_paper_size_get_height, dFpu)
GO(gtk_paper_size_get_name, pFp)
GO(gtk_paper_size_get_paper_sizes, pFi)
GO(gtk_paper_size_get_ppd_name, pFp)
GO(gtk_paper_size_get_type, LFv)
GO(gtk_paper_size_get_width, dFpu)
GO(gtk_paper_size_is_custom, iFp)
GO(gtk_paper_size_is_equal, iFpp)
GO(gtk_paper_size_is_ipp, iFp)
GO(gtk_paper_size_new, pFp)
GO(gtk_paper_size_new_custom, pFppddu)
GO(gtk_paper_size_new_from_gvariant, pFp)
GO(gtk_paper_size_new_from_ipp, pFpdd)
GO(gtk_paper_size_new_from_key_file, pFppp)
GO(gtk_paper_size_new_from_ppd, pFppdd)
GO(gtk_paper_size_set_size, vFpddu)
GO(gtk_paper_size_to_gvariant, pFp)
GO(gtk_paper_size_to_key_file, vFppp)
GO(gtk_parse_args, iFpp)
GO(gtk_path_bar_get_type, LFv)
GO(gtk_path_priority_type_get_type, LFv)
GO(gtk_path_type_get_type, LFv)
GO(gtk_places_open_flags_get_type, LFv)
GO(gtk_places_sidebar_add_shortcut, vFpp)
GO(gtk_places_sidebar_get_local_only, iFp)
GO(gtk_places_sidebar_get_location, pFp)
GO(gtk_places_sidebar_get_nth_bookmark, pFpi)
GO(gtk_places_sidebar_get_open_flags, uFp)
GO(gtk_places_sidebar_get_show_connect_to_server, iFp)
GO(gtk_places_sidebar_get_show_desktop, iFp)
GO(gtk_places_sidebar_get_show_enter_location, iFp)
GO(gtk_places_sidebar_get_show_other_locations, iFp)
GO(gtk_places_sidebar_get_show_recent, iFp)
GO(gtk_places_sidebar_get_show_starred_location, iFp)
GO(gtk_places_sidebar_get_show_trash, iFp)
GO(gtk_places_sidebar_get_type, LFv)
GO(gtk_places_sidebar_list_shortcuts, pFp)
GO(gtk_places_sidebar_new, pFv)
GO(gtk_places_sidebar_remove_shortcut, vFpp)
GO(gtk_places_sidebar_set_drop_targets_visible, vFpip)
GO(gtk_places_sidebar_set_local_only, vFpi)
GO(gtk_places_sidebar_set_location, vFpp)
GO(gtk_places_sidebar_set_open_flags, vFpu)
GO(gtk_places_sidebar_set_show_connect_to_server, vFpi)
GO(gtk_places_sidebar_set_show_desktop, vFpi)
GO(gtk_places_sidebar_set_show_enter_location, vFpi)
GO(gtk_places_sidebar_set_show_other_locations, vFpi)
GO(gtk_places_sidebar_set_show_recent, vFpi)
GO(gtk_places_sidebar_set_show_starred_location, vFpi)
GO(gtk_places_sidebar_set_show_trash, vFpi)
GO(gtk_plug_accessible_get_id, pFp)
GO(gtk_plug_accessible_get_type, LFv)
GO(gtk_plug_construct, vFpp)
GO(gtk_plug_construct_for_display, vFppp)
GO(gtk_plug_get_embedded, iFp)
GO(gtk_plug_get_id, pFp)
GO(gtk_plug_get_socket_window, pFp)
GO(gtk_plug_get_type, LFv)
GO(gtk_plug_new, pFp)
GO(gtk_plug_new_for_display, pFpp)
GO(gtk_policy_type_get_type, LFv)
GO(gtk_popover_accessible_get_type, LFv)
GO(gtk_popover_bind_model, vFppp)
GO(gtk_popover_constraint_get_type, LFv)
GO(gtk_popover_get_constrain_to, uFp)
GO(gtk_popover_get_default_widget, pFp)
GO(gtk_popover_get_modal, iFp)
GO(gtk_popover_get_pointing_to, iFpp)
GO(gtk_popover_get_position, uFp)
GO(gtk_popover_get_relative_to, pFp)
GO(gtk_popover_get_transitions_enabled, iFp)
GO(gtk_popover_get_type, LFv)
GO(gtk_popover_menu_get_type, LFv)
GO(gtk_popover_menu_new, pFv)
GO(gtk_popover_menu_open_submenu, vFpp)
GO(gtk_popover_new, pFp)
GO(gtk_popover_new_from_model, pFpp)
GO(gtk_popover_popdown, vFp)
GO(gtk_popover_popup, vFp)
GO(gtk_popover_set_constrain_to, vFpu)
GO(gtk_popover_set_default_widget, vFpp)
GO(gtk_popover_set_modal, vFpi)
GO(gtk_popover_set_pointing_to, vFpp)
GO(gtk_popover_set_position, vFpu)
GO(gtk_popover_set_relative_to, vFpp)
GO(gtk_popover_set_transitions_enabled, vFpi)
GO(gtk_position_type_get_type, LFv)
//GO(gtk_print_backend_add_printer, 
//GO(gtk_print_backend_destroy, 
//GO(gtk_print_backend_error_quark, 
//GO(gtk_print_backend_find_printer, 
//GO(gtk_print_backend_get_printer_list, 
GO(gtk_print_backend_get_type, LFv)
//GO(gtk_print_backend_load_modules, 
//GO(gtk_print_backend_printer_list_is_done, 
//GO(gtk_print_backend_print_stream, 
//GO(gtk_print_backend_remove_printer, 
//GO(gtk_print_backend_set_list_done, 
//GO(gtk_print_backend_set_password, 
GO(gtk_print_capabilities_get_type, LFv)
GO(gtk_print_context_create_pango_context, pFp)
GO(gtk_print_context_create_pango_layout, pFp)
GO(gtk_print_context_get_cairo_context, pFp)
GO(gtk_print_context_get_dpi_x, dFp)
GO(gtk_print_context_get_dpi_y, dFp)
GO(gtk_print_context_get_hard_margins, iFppppp)
GO(gtk_print_context_get_height, dFp)
GO(gtk_print_context_get_page_setup, pFp)
GO(gtk_print_context_get_pango_fontmap, pFp)
GO(gtk_print_context_get_type, LFv)
GO(gtk_print_context_get_width, dFp)
GO(gtk_print_context_set_cairo_context, vFppdd)
GO(gtk_print_duplex_get_type, LFv)
GO(gtk_printer_accepts_pdf, iFp)
GO(gtk_printer_accepts_ps, iFp)
GO(gtk_printer_compare, iFpp)
GO(gtk_printer_get_backend, pFp)
GO(gtk_printer_get_capabilities, uFp)
GO(gtk_printer_get_default_page_size, pFp)
GO(gtk_printer_get_description, pFp)
GO(gtk_printer_get_hard_margins, iFppppp)
GO(gtk_printer_get_icon_name, pFp)
GO(gtk_printer_get_job_count, iFp)
GO(gtk_printer_get_location, pFp)
GO(gtk_printer_get_name, pFp)
GO(gtk_printer_get_state_message, pFp)
GO(gtk_printer_get_type, LFv)
GO(gtk_printer_has_details, iFp)
GO(gtk_printer_is_accepting_jobs, iFp)
GO(gtk_printer_is_active, iFp)
GO(gtk_printer_is_default, iFp)
//GO(gtk_printer_is_new, 
GO(gtk_printer_is_paused, iFp)
GO(gtk_printer_is_virtual, iFp)
GO(gtk_printer_list_papers, pFp)
GO(gtk_printer_new, pFppi)
//GO(gtk_printer_option_allocate_choices, 
//GO(gtk_printer_option_choices_from_array, 
//GO(gtk_printer_option_clear_has_conflict, 
//GO(gtk_printer_option_get_activates_default, 
GO(gtk_printer_option_get_type, LFv)
//GO(gtk_printer_option_has_choice, 
//GO(gtk_printer_option_new, 
//GO(gtk_printer_option_set, 
//GO(gtk_printer_option_set_activates_default, 
//GO(gtk_printer_option_set_add, 
//GO(gtk_printer_option_set_boolean, 
//GO(gtk_printer_option_set_clear_conflicts, 
//GO(gtk_printer_option_set_foreach, 
//GO(gtk_printer_option_set_foreach_in_group, 
//GO(gtk_printer_option_set_get_groups, 
GO(gtk_printer_option_set_get_type, LFv)
//GO(gtk_printer_option_set_has_conflict, 
//GO(gtk_printer_option_set_lookup, 
//GO(gtk_printer_option_set_new, 
//GO(gtk_printer_option_set_remove, 
//GO(gtk_printer_option_widget_get_external_label, 
GO(gtk_printer_option_widget_get_type, LFv)
//GO(gtk_printer_option_widget_get_value, 
//GO(gtk_printer_option_widget_has_external_label, 
//GO(gtk_printer_option_widget_new, 
//GO(gtk_printer_option_widget_set_source, 
GO(gtk_printer_request_details, vFp)
GO(gtk_print_error_get_type, LFv)
GO(gtk_print_error_quark, uFv)
//GO(gtk_printer_set_accepts_pdf, 
//GO(gtk_printer_set_accepts_ps, 
//GO(gtk_printer_set_description, 
//GO(gtk_printer_set_has_details, 
//GO(gtk_printer_set_icon_name, 
//GO(gtk_printer_set_is_accepting_jobs, 
//GO(gtk_printer_set_is_active, 
//GO(gtk_printer_set_is_default, 
//GO(gtk_printer_set_is_new, 
//GO(gtk_printer_set_is_paused, 
//GO(gtk_printer_set_job_count, 
//GO(gtk_printer_set_location, 
//GO(gtk_printer_set_state_message, 
GO(gtk_print_job_get_collate, iFp)
GO(gtk_print_job_get_num_copies, iFp)
GO(gtk_print_job_get_n_up, uFp)
GO(gtk_print_job_get_n_up_layout, uFp)
GO(gtk_print_job_get_page_ranges, pFpp)
GO(gtk_print_job_get_pages, uFp)
GO(gtk_print_job_get_page_set, uFp)
GO(gtk_print_job_get_printer, pFp)
GO(gtk_print_job_get_reverse, iFp)
GO(gtk_print_job_get_rotate, iFp)
GO(gtk_print_job_get_scale, dFp)
GO(gtk_print_job_get_settings, pFp)
GO(gtk_print_job_get_status, uFp)
GO(gtk_print_job_get_surface, pFpp)
GO(gtk_print_job_get_title, pFp)
GO(gtk_print_job_get_track_print_status, iFp)
GO(gtk_print_job_get_type, LFv)
GO(gtk_print_job_new, pFpppp)
GOM(gtk_print_job_send, vFEpppp)
GO(gtk_print_job_set_collate, vFpi)
GO(gtk_print_job_set_num_copies, vFpi)
GO(gtk_print_job_set_n_up, vFpu)
GO(gtk_print_job_set_n_up_layout, vFpu)
GO(gtk_print_job_set_page_ranges, vFppi)
GO(gtk_print_job_set_pages, vFpu)
GO(gtk_print_job_set_page_set, vFpu)
GO(gtk_print_job_set_reverse, vFpi)
GO(gtk_print_job_set_rotate, vFpi)
GO(gtk_print_job_set_scale, vFpd)
GO(gtk_print_job_set_source_fd, iFpip)
GO(gtk_print_job_set_source_file, iFppp)
//GO(gtk_print_job_set_status, 
GO(gtk_print_job_set_track_print_status, vFpi)
GO(gtk_print_operation_action_get_type, LFv)
GO(gtk_print_operation_cancel, vFp)
GO(gtk_print_operation_draw_page_finish, vFp)
GO(gtk_print_operation_get_default_page_setup, pFp)
GO(gtk_print_operation_get_embed_page_setup, iFp)
GO(gtk_print_operation_get_error, vFpp)
GO(gtk_print_operation_get_has_selection, iFp)
GO(gtk_print_operation_get_n_pages_to_print, iFp)
GO(gtk_print_operation_get_print_settings, pFp)
GO(gtk_print_operation_get_status, uFp)
GO(gtk_print_operation_get_status_string, pFp)
GO(gtk_print_operation_get_support_selection, iFp)
GO(gtk_print_operation_get_type, LFv)
GO(gtk_print_operation_is_finished, iFp)
GO(gtk_print_operation_new, pFv)
GO(gtk_print_operation_preview_end_preview, vFp)
GO(gtk_print_operation_preview_get_type, LFv)
GO(gtk_print_operation_preview_is_selected, iFpi)
GO(gtk_print_operation_preview_render_page, vFpi)
GO(gtk_print_operation_result_get_type, LFv)
GO(gtk_print_operation_run, uFpupp)
GO(gtk_print_operation_set_allow_async, vFpi)
GO(gtk_print_operation_set_current_page, vFpi)
GO(gtk_print_operation_set_custom_tab_label, vFpp)
GO(gtk_print_operation_set_default_page_setup, vFpp)
GO(gtk_print_operation_set_defer_drawing, vFp)
GO(gtk_print_operation_set_embed_page_setup, vFpi)
GO(gtk_print_operation_set_export_filename, vFpp)
GO(gtk_print_operation_set_has_selection, vFpi)
GO(gtk_print_operation_set_job_name, vFpp)
GO(gtk_print_operation_set_n_pages, vFpi)
GO(gtk_print_operation_set_print_settings, vFpp)
GO(gtk_print_operation_set_show_progress, vFpi)
GO(gtk_print_operation_set_support_selection, vFpi)
GO(gtk_print_operation_set_track_print_status, vFpi)
GO(gtk_print_operation_set_unit, vFpu)
GO(gtk_print_operation_set_use_full_page, vFpi)
GO(gtk_print_pages_get_type, LFv)
GO(gtk_print_quality_get_type, LFv)
GO(gtk_print_run_page_setup_dialog, pFppp)
//GOM(gtk_print_run_page_setup_dialog_async, vFppppp)
GO(gtk_print_settings_copy, pFp)
//GOM(gtk_print_settings_foreach, vFppp)
GO(gtk_print_settings_get, pFpp)
GO(gtk_print_settings_get_bool, iFpp)
GO(gtk_print_settings_get_collate, iFp)
GO(gtk_print_settings_get_default_source, pFp)
GO(gtk_print_settings_get_dither, pFp)
GO(gtk_print_settings_get_double, dFpp)
GO(gtk_print_settings_get_double_with_default, dFppd)
GO(gtk_print_settings_get_duplex, uFp)
GO(gtk_print_settings_get_finishings, pFp)
GO(gtk_print_settings_get_int, iFpp)
GO(gtk_print_settings_get_int_with_default, iFppi)
GO(gtk_print_settings_get_length, dFppu)
GO(gtk_print_settings_get_media_type, pFp)
GO(gtk_print_settings_get_n_copies, iFp)
GO(gtk_print_settings_get_number_up, iFp)
GO(gtk_print_settings_get_number_up_layout, uFp)
GO(gtk_print_settings_get_orientation, uFp)
GO(gtk_print_settings_get_output_bin, pFp)
GO(gtk_print_settings_get_page_ranges, pFpp)
GO(gtk_print_settings_get_page_set, uFp)
GO(gtk_print_settings_get_paper_height, dFpu)
GO(gtk_print_settings_get_paper_size, pFp)
GO(gtk_print_settings_get_paper_width, dFpu)
GO(gtk_print_settings_get_printer, pFp)
GO(gtk_print_settings_get_printer_lpi, dFp)
GO(gtk_print_settings_get_print_pages, uFp)
GO(gtk_print_settings_get_quality, uFp)
GO(gtk_print_settings_get_resolution, iFp)
GO(gtk_print_settings_get_resolution_x, iFp)
GO(gtk_print_settings_get_resolution_y, iFp)
GO(gtk_print_settings_get_reverse, iFp)
GO(gtk_print_settings_get_scale, dFp)
GO(gtk_print_settings_get_type, LFv)
GO(gtk_print_settings_get_use_color, iFp)
GO(gtk_print_settings_has_key, iFpp)
GO(gtk_print_settings_load_file, iFppp)
GO(gtk_print_settings_load_key_file, iFpppp)
GO(gtk_print_settings_new, pFv)
GO(gtk_print_settings_new_from_file, pFpp)
GO(gtk_print_settings_new_from_gvariant, pFp)
GO(gtk_print_settings_new_from_key_file, pFppp)
GO(gtk_print_settings_set, vFppp)
GO(gtk_print_settings_set_bool, vFppi)
GO(gtk_print_settings_set_collate, vFpi)
GO(gtk_print_settings_set_default_source, vFpp)
GO(gtk_print_settings_set_dither, vFpp)
GO(gtk_print_settings_set_double, vFppd)
GO(gtk_print_settings_set_duplex, vFpu)
GO(gtk_print_settings_set_finishings, vFpp)
GO(gtk_print_settings_set_int, vFppi)
GO(gtk_print_settings_set_length, vFppdu)
GO(gtk_print_settings_set_media_type, vFpp)
GO(gtk_print_settings_set_n_copies, vFpi)
GO(gtk_print_settings_set_number_up, vFpi)
GO(gtk_print_settings_set_number_up_layout, vFpu)
GO(gtk_print_settings_set_orientation, vFpu)
GO(gtk_print_settings_set_output_bin, vFpp)
GO(gtk_print_settings_set_page_ranges, vFppi)
GO(gtk_print_settings_set_page_set, vFpu)
GO(gtk_print_settings_set_paper_height, vFpdu)
GO(gtk_print_settings_set_paper_size, vFpp)
GO(gtk_print_settings_set_paper_width, vFpdu)
GO(gtk_print_settings_set_printer, vFpp)
GO(gtk_print_settings_set_printer_lpi, vFpd)
GO(gtk_print_settings_set_print_pages, vFpu)
GO(gtk_print_settings_set_quality, vFpu)
GO(gtk_print_settings_set_resolution, vFpi)
GO(gtk_print_settings_set_resolution_xy, vFpii)
GO(gtk_print_settings_set_reverse, vFpi)
GO(gtk_print_settings_set_scale, vFpd)
GO(gtk_print_settings_set_use_color, vFpi)
GO(gtk_print_settings_to_file, iFppp)
GO(gtk_print_settings_to_gvariant, pFp)
GO(gtk_print_settings_to_key_file, vFppp)
GO(gtk_print_settings_unset, vFpp)
GO(gtk_print_status_get_type, LFv)
GO(gtk_print_unix_dialog_add_custom_tab, vFppp)
GO(gtk_print_unix_dialog_get_current_page, iFp)
GO(gtk_print_unix_dialog_get_embed_page_setup, iFp)
GO(gtk_print_unix_dialog_get_has_selection, iFp)
GO(gtk_print_unix_dialog_get_manual_capabilities, uFp)
GO(gtk_print_unix_dialog_get_page_setup, pFp)
GO(gtk_print_unix_dialog_get_page_setup_set, iFp)
GO(gtk_print_unix_dialog_get_selected_printer, pFp)
GO(gtk_print_unix_dialog_get_settings, pFp)
GO(gtk_print_unix_dialog_get_support_selection, iFp)
GO(gtk_print_unix_dialog_get_type, LFv)
GO(gtk_print_unix_dialog_new, pFpp)
GO(gtk_print_unix_dialog_set_current_page, vFpi)
GO(gtk_print_unix_dialog_set_embed_page_setup, vFpi)
GO(gtk_print_unix_dialog_set_has_selection, vFpi)
GO(gtk_print_unix_dialog_set_manual_capabilities, vFpu)
GO(gtk_print_unix_dialog_set_page_setup, vFpp)
GO(gtk_print_unix_dialog_set_settings, vFpp)
GO(gtk_print_unix_dialog_set_support_selection, vFpi)
GO(gtk_progress_bar_accessible_get_type, LFv)
GO(gtk_progress_bar_get_ellipsize, uFp)
GO(gtk_progress_bar_get_fraction, dFp)
GO(gtk_progress_bar_get_inverted, iFp)
GO(gtk_progress_bar_get_pulse_step, dFp)
GO(gtk_progress_bar_get_show_text, iFp)
GO(gtk_progress_bar_get_text, pFp)
GO(gtk_progress_bar_get_type, LFv)
GO(gtk_progress_bar_new, pFv)
GO(gtk_progress_bar_pulse, vFp)
GO(gtk_progress_bar_set_ellipsize, vFpu)
GO(gtk_progress_bar_set_fraction, vFpd)
GO(gtk_progress_bar_set_inverted, vFpi)
GO(gtk_progress_bar_set_pulse_step, vFpd)
GO(gtk_progress_bar_set_show_text, vFpi)
GO(gtk_progress_bar_set_text, vFpp)
GO(gtk_propagate_event, vFpp)
GO(gtk_propagation_phase_get_type, LFv)
GO(gtk_radio_action_get_current_value, iFp)
GO(gtk_radio_action_get_group, pFp)
GO(gtk_radio_action_get_type, LFv)
GO(gtk_radio_action_join_group, vFpp)
GO(gtk_radio_action_new, pFppppi)
GO(gtk_radio_action_set_current_value, vFpi)
GO(gtk_radio_action_set_group, vFpp)
GO(gtk_radio_button_accessible_get_type, LFv)
GO(gtk_radio_button_get_group, pFp)
GO(gtk_radio_button_get_type, LFv)
GO(gtk_radio_button_join_group, vFpp)
GO(gtk_radio_button_new, pFp)
GO(gtk_radio_button_new_from_widget, pFp)
GO(gtk_radio_button_new_with_label, pFpp)
GO(gtk_radio_button_new_with_label_from_widget, pFpp)
GO(gtk_radio_button_new_with_mnemonic, pFpp)
GO(gtk_radio_button_new_with_mnemonic_from_widget, pFpp)
GO(gtk_radio_button_set_group, vFpp)
GO(gtk_radio_menu_item_accessible_get_type, LFv)
GO(gtk_radio_menu_item_get_group, pFp)
GO(gtk_radio_menu_item_get_type, LFv)
GO(gtk_radio_menu_item_join_group, vFpp)
GO(gtk_radio_menu_item_new, pFp)
GO(gtk_radio_menu_item_new_from_widget, pFp)
GO(gtk_radio_menu_item_new_with_label, pFpp)
GO(gtk_radio_menu_item_new_with_label_from_widget, pFpp)
GO(gtk_radio_menu_item_new_with_mnemonic, pFpp)
GO(gtk_radio_menu_item_new_with_mnemonic_from_widget, pFpp)
GO(gtk_radio_menu_item_set_group, vFpp)
GO(gtk_radio_tool_button_get_group, pFp)
GO(gtk_radio_tool_button_get_type, LFv)
GO(gtk_radio_tool_button_new, pFp)
GO(gtk_radio_tool_button_new_from_stock, pFpp)
GO(gtk_radio_tool_button_new_from_widget, pFp)
GO(gtk_radio_tool_button_new_with_stock_from_widget, pFpp)
GO(gtk_radio_tool_button_set_group, vFpp)
GO(gtk_range_accessible_get_type, LFv)
GO(gtk_range_get_adjustment, pFp)
GO(gtk_range_get_fill_level, dFp)
GO(gtk_range_get_flippable, iFp)
GO(gtk_range_get_inverted, iFp)
GO(gtk_range_get_lower_stepper_sensitivity, uFp)
GO(gtk_range_get_min_slider_size, iFp)
GO(gtk_range_get_range_rect, vFpp)
GO(gtk_range_get_restrict_to_fill_level, iFp)
GO(gtk_range_get_round_digits, iFp)
GO(gtk_range_get_show_fill_level, iFp)
GO(gtk_range_get_slider_range, vFppp)
GO(gtk_range_get_slider_size_fixed, iFp)
GO(gtk_range_get_type, LFv)
GO(gtk_range_get_upper_stepper_sensitivity, uFp)
GO(gtk_range_get_value, dFp)
GO(gtk_range_set_adjustment, vFpp)
GO(gtk_range_set_fill_level, vFpd)
GO(gtk_range_set_flippable, vFpi)
GO(gtk_range_set_increments, vFpdd)
GO(gtk_range_set_inverted, vFpi)
GO(gtk_range_set_lower_stepper_sensitivity, vFpu)
GO(gtk_range_set_min_slider_size, vFpi)
GO(gtk_range_set_range, vFpdd)
GO(gtk_range_set_restrict_to_fill_level, vFpi)
GO(gtk_range_set_round_digits, vFpi)
GO(gtk_range_set_show_fill_level, vFpi)
GO(gtk_range_set_slider_size_fixed, vFpi)
GO(gtk_range_set_upper_stepper_sensitivity, vFpu)
GO(gtk_range_set_value, vFpd)
GO(gtk_rc_add_default_file, vFp)
GO(gtk_rc_find_module_in_path, pFp)
GO(gtk_rc_find_pixmap_in_path, pFppp)   //need wraping?
GO(gtk_rc_flags_get_type, LFv)
GO(gtk_rc_get_default_files, pFv)
GO(gtk_rc_get_im_module_file, pFv)
GO(gtk_rc_get_im_module_path, pFv)
GO(gtk_rc_get_module_dir, pFv)
GO(gtk_rc_get_style, pFp)
GO(gtk_rc_get_style_by_paths, pFpppL)
GO(gtk_rc_get_theme_dir, pFv)
GO(gtk_rc_parse, vFp)
//GOM(gtk_rc_parse_color, uFpp)
//GOM(gtk_rc_parse_color_full, uFppp)
//GOM(gtk_rc_parse_priority, uFpp)
//GOM(gtk_rc_parse_state, uFpp)
GO(gtk_rc_parse_string, vFp)
GO(gtk_rc_property_parse_border, iFppp)
GO(gtk_rc_property_parse_color, iFppp)
GO(gtk_rc_property_parse_enum, iFppp)
GO(gtk_rc_property_parse_flags, iFppp)
GO(gtk_rc_property_parse_requisition, iFppp)
GO(gtk_rc_reparse_all, iFv)
GO(gtk_rc_reparse_all_for_settings, iFpi)
GO(gtk_rc_reset_styles, vFp)
GO(gtk_rc_scanner_new, pFv)
GO(gtk_rc_set_default_files, vFp)
GO(gtk_rc_style_copy, pFp)
GO(gtk_rc_style_get_type, LFv)
GO(gtk_rc_style_new, pFv)
GO(gtk_rc_token_type_get_type, LFv)
GO(gtk_recent_action_get_show_numbers, iFp)
GO(gtk_recent_action_get_type, LFv)
GO(gtk_recent_action_new, pFpppp)
GO(gtk_recent_action_new_for_manager, pFppppp)
GO(gtk_recent_action_set_show_numbers, vFpi)
GO(gtk_recent_chooser_add_filter, vFpp)
GO(gtk_recent_chooser_dialog_get_type, LFv)
//GOM(gtk_recent_chooser_dialog_new, pFpppV)
//GOM(gtk_recent_chooser_dialog_new_for_manager, pFppppV)
GO(gtk_recent_chooser_error_get_type, LFv)
GO(gtk_recent_chooser_error_quark, uFv)
GO(gtk_recent_chooser_get_current_item, pFp)
GO(gtk_recent_chooser_get_current_uri, pFp)
GO(gtk_recent_chooser_get_filter, pFp)
GO(gtk_recent_chooser_get_items, pFp)
GO(gtk_recent_chooser_get_limit, iFp)
GO(gtk_recent_chooser_get_local_only, iFp)
GO(gtk_recent_chooser_get_select_multiple, iFp)
GO(gtk_recent_chooser_get_show_icons, iFp)
GO(gtk_recent_chooser_get_show_not_found, iFp)
GO(gtk_recent_chooser_get_show_private, iFp)
GO(gtk_recent_chooser_get_show_tips, iFp)
GO(gtk_recent_chooser_get_sort_type, uFp)
GO(gtk_recent_chooser_get_type, LFv)
GO(gtk_recent_chooser_get_uris, pFpp)
GO(gtk_recent_chooser_list_filters, pFp)
GO(gtk_recent_chooser_menu_get_show_numbers, iFp)
GO(gtk_recent_chooser_menu_get_type, LFv)
GO(gtk_recent_chooser_menu_new, pFv)
GO(gtk_recent_chooser_menu_new_for_manager, pFp)
GO(gtk_recent_chooser_menu_set_show_numbers, vFpi)
GO(gtk_recent_chooser_remove_filter, vFpp)
GO(gtk_recent_chooser_select_all, vFp)
GO(gtk_recent_chooser_select_uri, iFppp)
GO(gtk_recent_chooser_set_current_uri, iFppp)
GO(gtk_recent_chooser_set_filter, vFpp)
GO(gtk_recent_chooser_set_limit, vFpi)
GO(gtk_recent_chooser_set_local_only, vFpi)
GO(gtk_recent_chooser_set_select_multiple, vFpi)
GO(gtk_recent_chooser_set_show_icons, vFpi)
GO(gtk_recent_chooser_set_show_not_found, vFpi)
GO(gtk_recent_chooser_set_show_private, vFpi)
GO(gtk_recent_chooser_set_show_tips, vFpi)
//GOM(gtk_recent_chooser_set_sort_func, vFpppp)
GO(gtk_recent_chooser_set_sort_type, vFpu)
GO(gtk_recent_chooser_unselect_all, vFp)
GO(gtk_recent_chooser_unselect_uri, vFpp)
GO(gtk_recent_chooser_widget_get_type, LFv)
GO(gtk_recent_chooser_widget_new, pFv)
GO(gtk_recent_chooser_widget_new_for_manager, pFp)
GO(gtk_recent_filter_add_age, vFpi)
GO(gtk_recent_filter_add_application, vFpp)
//GOM(gtk_recent_filter_add_custom, vFpuppp)
GO(gtk_recent_filter_add_group, vFpp)
GO(gtk_recent_filter_add_mime_type, vFpp)
GO(gtk_recent_filter_add_pattern, vFpp)
GO(gtk_recent_filter_add_pixbuf_formats, vFp)
GO(gtk_recent_filter_filter, iFpp)
GO(gtk_recent_filter_flags_get_type, LFv)
GO(gtk_recent_filter_get_name, pFp)
GO(gtk_recent_filter_get_needed, uFp)
GO(gtk_recent_filter_get_type, LFv)
GO(gtk_recent_filter_new, pFv)
GO(gtk_recent_filter_set_name, vFpp)
GO(gtk_recent_info_create_app_info, pFppp)
GO(gtk_recent_info_exists, iFp)
GO(gtk_recent_info_get_added, lFp)
GO(gtk_recent_info_get_age, iFp)
GO(gtk_recent_info_get_application_info, iFppppp)
GO(gtk_recent_info_get_applications, pFpp)
GO(gtk_recent_info_get_description, pFp)
GO(gtk_recent_info_get_display_name, pFp)
GO(gtk_recent_info_get_gicon, pFp)
GO(gtk_recent_info_get_groups, pFpp)
GO(gtk_recent_info_get_icon, pFpi)
GO(gtk_recent_info_get_mime_type, pFp)
GO(gtk_recent_info_get_modified, lFp)
GO(gtk_recent_info_get_private_hint, iFp)
GO(gtk_recent_info_get_short_name, pFp)
GO(gtk_recent_info_get_type, LFv)
GO(gtk_recent_info_get_uri, pFp)
GO(gtk_recent_info_get_uri_display, pFp)
GO(gtk_recent_info_get_visited, lFp)
GO(gtk_recent_info_has_application, iFpp)
GO(gtk_recent_info_has_group, iFpp)
GO(gtk_recent_info_is_local, iFp)
GO(gtk_recent_info_last_application, pFp)
GO(gtk_recent_info_match, iFpp)
GO(gtk_recent_info_ref, pFp)
GO(gtk_recent_info_unref, vFp)
GO(gtk_recent_manager_add_full, iFppp)
GO(gtk_recent_manager_add_item, iFpp)
GO(gtk_recent_manager_error_get_type, LFv)
GO(gtk_recent_manager_error_quark, uFv)
GO(gtk_recent_manager_get_default, pFv)
GO(gtk_recent_manager_get_items, pFp)
GO(gtk_recent_manager_get_type, LFv)
GO(gtk_recent_manager_has_item, iFpp)
GO(gtk_recent_manager_lookup_item, pFppp)
GO(gtk_recent_manager_move_item, iFpppp)
GO(gtk_recent_manager_new, pFv)
GO(gtk_recent_manager_purge_items, iFpp)
GO(gtk_recent_manager_remove_item, iFppp)
GO(gtk_recent_sort_type_get_type, LFv)
GO(gtk_region_flags_get_type, LFv)
GO(gtk_relief_style_get_type, LFv)
GO(gtk_render_activity, vFppdddd)
GO(gtk_render_arrow, vFppdddd)
GO(gtk_render_background, vFppdddd)
GO(gtk_render_background_get_clip, vFpddddp)
GO(gtk_render_check, vFppdddd)
GO(gtk_renderer_cell_accessible_get_type, LFv)
GO(gtk_renderer_cell_accessible_new, pFp)
GO(gtk_render_expander, vFppdddd)
GO(gtk_render_extension, vFppddddu)
GO(gtk_render_focus, vFppdddd)
GO(gtk_render_frame, vFppdddd)
GO(gtk_render_frame_gap, vFppddddudd)
GO(gtk_render_handle, vFppdddd)
GO(gtk_render_icon, vFpppdd)
GO(gtk_render_icon_pixbuf, pFppu)
GO(gtk_render_icon_surface, vFpppdd)
GO(gtk_render_insertion_cursor, vFppddpiu)
GO(gtk_render_layout, vFppddp)
GO(gtk_render_line, vFppdddd)
GO(gtk_render_option, vFppdddd)
GO(gtk_render_slider, vFppddddu)
GO(gtk_requisition_copy, pFp)
GO(gtk_requisition_free, vFp)
GO(gtk_requisition_get_type, LFv)
GO(gtk_requisition_new, pFv)
GO(gtk_resize_mode_get_type, LFv)
GO(gtk_response_type_get_type, LFv)
GO(gtk_revealer_get_child_revealed, iFp)
GO(gtk_revealer_get_reveal_child, iFp)
GO(gtk_revealer_get_transition_duration, uFp)
GO(gtk_revealer_get_transition_type, uFp)
GO(gtk_revealer_get_type, LFv)
GO(gtk_revealer_new, pFv)
GO(gtk_revealer_set_reveal_child, vFpi)
GO(gtk_revealer_set_transition_duration, vFpu)
GO(gtk_revealer_set_transition_type, vFpu)
GO(gtk_revealer_transition_type_get_type, LFv)
GO(gtk_rgb_to_hsv, vFdddppp)
GO(gtk_scale_accessible_get_type, LFv)
GO(gtk_scale_add_mark, vFpdup)
GO(gtk_scale_button_accessible_get_type, LFv)
GO(gtk_scale_button_get_adjustment, pFp)
GO(gtk_scale_button_get_minus_button, pFp)
GO(gtk_scale_button_get_plus_button, pFp)
GO(gtk_scale_button_get_popup, pFp)
GO(gtk_scale_button_get_type, LFv)
GO(gtk_scale_button_get_value, dFp)
GO(gtk_scale_button_new, pFudddp)
GO(gtk_scale_button_set_adjustment, vFpp)
GO(gtk_scale_button_set_icons, vFpp)
GO(gtk_scale_button_set_value, vFpd)
GO(gtk_scale_clear_marks, vFp)
GO(gtk_scale_get_digits, iFp)
GO(gtk_scale_get_draw_value, iFp)
GO(gtk_scale_get_has_origin, iFp)
GO(gtk_scale_get_layout, pFp)
GO(gtk_scale_get_layout_offsets, vFppp)
GO(gtk_scale_get_type, LFv)
GO(gtk_scale_get_value_pos, uFp)
GO(gtk_scale_new, pFup)
GO(gtk_scale_new_with_range, pFuddd)
GO(gtk_scale_set_digits, vFpi)
GO(gtk_scale_set_draw_value, vFpi)
GO(gtk_scale_set_has_origin, vFpi)
GO(gtk_scale_set_value_pos, vFpu)
GO(gtk_scrollable_get_border, iFpp)
GO(gtk_scrollable_get_hadjustment, pFp)
GO(gtk_scrollable_get_hscroll_policy, uFp)
GO(gtk_scrollable_get_type, LFv)
GO(gtk_scrollable_get_vadjustment, pFp)
GO(gtk_scrollable_get_vscroll_policy, uFp)
GO(gtk_scrollable_policy_get_type, LFv)
GO(gtk_scrollable_set_hadjustment, vFpp)
GO(gtk_scrollable_set_hscroll_policy, vFpu)
GO(gtk_scrollable_set_vadjustment, vFpp)
GO(gtk_scrollable_set_vscroll_policy, vFpu)
GO(gtk_scrollbar_get_type, LFv)
GO(gtk_scrollbar_new, pFup)
GO(gtk_scrolled_window_accessible_get_type, LFv)
GO(gtk_scrolled_window_add_with_viewport, vFpp)
GO(gtk_scrolled_window_get_capture_button_press, iFp)
GO(gtk_scrolled_window_get_hadjustment, pFp)
GO(gtk_scrolled_window_get_hscrollbar, pFp)
GO(gtk_scrolled_window_get_kinetic_scrolling, iFp)
GO(gtk_scrolled_window_get_max_content_height, iFp)
GO(gtk_scrolled_window_get_max_content_width, iFp)
GO(gtk_scrolled_window_get_min_content_height, iFp)
GO(gtk_scrolled_window_get_min_content_width, iFp)
GO(gtk_scrolled_window_get_overlay_scrolling, iFp)
GO(gtk_scrolled_window_get_placement, uFp)
GO(gtk_scrolled_window_get_policy, vFppp)
GO(gtk_scrolled_window_get_propagate_natural_height, iFp)
GO(gtk_scrolled_window_get_propagate_natural_width, iFp)
GO(gtk_scrolled_window_get_shadow_type, uFp)
GO(gtk_scrolled_window_get_type, LFv)
GO(gtk_scrolled_window_get_vadjustment, pFp)
GO(gtk_scrolled_window_get_vscrollbar, pFp)
GO(gtk_scrolled_window_new, pFpp)
GO(gtk_scrolled_window_set_capture_button_press, vFpi)
GO(gtk_scrolled_window_set_hadjustment, vFpp)
GO(gtk_scrolled_window_set_kinetic_scrolling, vFpi)
GO(gtk_scrolled_window_set_max_content_height, vFpi)
GO(gtk_scrolled_window_set_max_content_width, vFpi)
GO(gtk_scrolled_window_set_min_content_height, vFpi)
GO(gtk_scrolled_window_set_min_content_width, vFpi)
GO(gtk_scrolled_window_set_overlay_scrolling, vFpi)
GO(gtk_scrolled_window_set_placement, vFpu)
GO(gtk_scrolled_window_set_policy, vFpuu)
GO(gtk_scrolled_window_set_propagate_natural_height, vFpi)
GO(gtk_scrolled_window_set_propagate_natural_width, vFpi)
GO(gtk_scrolled_window_set_shadow_type, vFpu)
GO(gtk_scrolled_window_set_vadjustment, vFpp)
GO(gtk_scrolled_window_unset_placement, vFp)
GO(gtk_scroll_step_get_type, LFv)
GO(gtk_scroll_type_get_type, LFv)
GO(gtk_search_bar_connect_entry, vFpp)
GO(gtk_search_bar_get_search_mode, iFp)
GO(gtk_search_bar_get_show_close_button, iFp)
GO(gtk_search_bar_get_type, LFv)
GO(gtk_search_bar_handle_event, iFpp)
GO(gtk_search_bar_new, pFv)
GO(gtk_search_bar_set_search_mode, vFpi)
GO(gtk_search_bar_set_show_close_button, vFpi)
GO(gtk_search_entry_get_type, LFv)
GO(gtk_search_entry_handle_event, iFpp)
GO(gtk_search_entry_new, pFv)
GO(gtk_selection_add_target, vFpppu)
GO(gtk_selection_add_targets, vFpppu)
GO(gtk_selection_clear_targets, vFpp)
GO(gtk_selection_convert, iFpppu)
GO(gtk_selection_data_copy, pFp)
GO(gtk_selection_data_free, vFp)
GO(gtk_selection_data_get_data, pFp)
GO(gtk_selection_data_get_data_type, pFp)
GO(gtk_selection_data_get_data_with_length, pFpp)
GO(gtk_selection_data_get_display, pFp)
GO(gtk_selection_data_get_format, iFp)
GO(gtk_selection_data_get_length, iFp)
GO(gtk_selection_data_get_pixbuf, pFp)
GO(gtk_selection_data_get_selection, pFp)
GO(gtk_selection_data_get_target, pFp)
GO(gtk_selection_data_get_targets, iFppp)
GO(gtk_selection_data_get_text, pFp)
GO(gtk_selection_data_get_type, LFv)
GO(gtk_selection_data_get_uris, pFp)
GO(gtk_selection_data_set, vFppipi)
GO(gtk_selection_data_set_pixbuf, iFpp)
GO(gtk_selection_data_set_text, iFppi)
GO(gtk_selection_data_set_uris, iFpp)
GO(gtk_selection_data_targets_include_image, iFpi)
GO(gtk_selection_data_targets_include_rich_text, iFpp)
GO(gtk_selection_data_targets_include_text, iFp)
GO(gtk_selection_data_targets_include_uri, iFp)
GO(gtk_selection_mode_get_type, LFv)
GO(gtk_selection_owner_set, iFppu)
GO(gtk_selection_owner_set_for_display, iFpppu)
GO(gtk_selection_remove_all, vFp)
GO(gtk_sensitivity_type_get_type, LFv)
GO(gtk_separator_get_type, LFv)
GO(gtk_separator_menu_item_get_type, LFv)
GO(gtk_separator_menu_item_new, pFv)
GO(gtk_separator_new, pFu)
GO(gtk_separator_tool_item_get_draw, iFp)
GO(gtk_separator_tool_item_get_type, LFv)
GO(gtk_separator_tool_item_new, pFv)
GO(gtk_separator_tool_item_set_draw, vFpi)
GO(gtk_set_debug_flags, vFu)
GO(gtk_settings_get_default, pFv)
GO(gtk_settings_get_for_screen, pFp)
GO(gtk_settings_get_type, LFv)
GO(gtk_settings_install_property, vFp)
//GOM(gtk_settings_install_property_parser, vFEpp)
GO(gtk_settings_reset_property, vFpp)
GO(gtk_settings_set_double_property, vFppdp)
GO(gtk_settings_set_long_property, vFpplp)
GO(gtk_settings_set_property_value, vFppp)
GO(gtk_settings_set_string_property, vFpppp)
GO(gtk_shadow_type_get_type, LFv)
GO(gtk_shortcut_label_get_accelerator, pFp)
GO(gtk_shortcut_label_get_disabled_text, pFp)
GO(gtk_shortcut_label_get_type, LFv)
GO(gtk_shortcut_label_new, pFp)
GO(gtk_shortcut_label_set_accelerator, vFpp)
GO(gtk_shortcut_label_set_disabled_text, vFpp)
GO(gtk_shortcuts_group_get_type, LFv)
GO(gtk_shortcuts_section_get_type, LFv)
GO(gtk_shortcuts_shortcut_get_type, LFv)
GO(gtk_shortcuts_window_get_type, LFv)
GO(gtk_shortcut_type_get_type, LFv)
GO(gtk_show_about_dialog, vFpppppppppppppppppppppppp)   //vaarg
GO(gtk_show_uri, iFppup)
GO(gtk_show_uri_on_window, iFppup)
GO(gtk_size_group_add_widget, vFpp)
GO(gtk_size_group_get_ignore_hidden, iFp)
GO(gtk_size_group_get_mode, uFp)
GO(gtk_size_group_get_type, LFv)
GO(gtk_size_group_get_widgets, pFp)
GO(gtk_size_group_mode_get_type, LFv)
GO(gtk_size_group_new, pFu)
GO(gtk_size_group_remove_widget, vFpp)
GO(gtk_size_group_set_ignore_hidden, vFpi)
GO(gtk_size_group_set_mode, vFpu)
GO(gtk_size_request_mode_get_type, LFv)
GO(gtk_snapshot_free_to_node, pFp)
GO(gtk_snapshot_new, pFv)
GO(gtk_snapshot_render_background, vFppdddd)
GO(gtk_socket_accessible_embed, vFpp)
GO(gtk_socket_accessible_get_type, LFv)
GO(gtk_socket_add_id, vFpp)
GO(gtk_socket_get_id, pFp)
GO(gtk_socket_get_plug_window, pFp)
GO(gtk_socket_get_type, LFv)
GO(gtk_socket_new, pFv)
GO(gtk_sort_type_get_type, LFv)
GO(gtk_spin_button_accessible_get_type, LFv)
GO(gtk_spin_button_configure, vFppdu)
GO(gtk_spin_button_get_adjustment, pFp)
GO(gtk_spin_button_get_digits, uFp)
GO(gtk_spin_button_get_increments, vFppp)
GO(gtk_spin_button_get_numeric, iFp)
GO(gtk_spin_button_get_range, vFppp)
GO(gtk_spin_button_get_snap_to_ticks, iFp)
GO(gtk_spin_button_get_type, LFv)
GO(gtk_spin_button_get_update_policy, uFp)
GO(gtk_spin_button_get_value, dFp)
GO(gtk_spin_button_get_value_as_int, iFp)
GO(gtk_spin_button_get_wrap, iFp)
GO(gtk_spin_button_new, pFpdu)
GO(gtk_spin_button_new_with_range, pFddd)
GO(gtk_spin_button_set_adjustment, vFpp)
GO(gtk_spin_button_set_digits, vFpu)
GO(gtk_spin_button_set_increments, vFpdd)
GO(gtk_spin_button_set_numeric, vFpi)
GO(gtk_spin_button_set_range, vFpdd)
GO(gtk_spin_button_set_snap_to_ticks, vFpi)
GO(gtk_spin_button_set_update_policy, vFpu)
GO(gtk_spin_button_set_value, vFpd)
GO(gtk_spin_button_set_wrap, vFpi)
GO(gtk_spin_button_spin, vFpud)
GO(gtk_spin_button_update, vFp)
GO(gtk_spin_button_update_policy_get_type, LFv)
GO(gtk_spinner_accessible_get_type, LFv)
GO(gtk_spinner_get_type, LFv)
GO(gtk_spinner_new, pFv)
GO(gtk_spinner_start, vFp)
GO(gtk_spinner_stop, vFp)
GO(gtk_spin_type_get_type, LFv)
GO(gtk_stack_accessible_get_type, LFv)
GO(gtk_stack_add_named, vFppp)
GO(gtk_stack_add_titled, vFpppp)
GO(gtk_stack_get_child_by_name, pFpp)
GO(gtk_stack_get_hhomogeneous, iFp)
GO(gtk_stack_get_homogeneous, iFp)
GO(gtk_stack_get_interpolate_size, iFp)
GO(gtk_stack_get_transition_duration, uFp)
GO(gtk_stack_get_transition_running, iFp)
GO(gtk_stack_get_transition_type, uFp)
GO(gtk_stack_get_type, LFv)
GO(gtk_stack_get_vhomogeneous, iFp)
GO(gtk_stack_get_visible_child, pFp)
GO(gtk_stack_get_visible_child_name, pFp)
GO(gtk_stack_new, pFv)
GO(gtk_stack_set_hhomogeneous, vFpi)
GO(gtk_stack_set_homogeneous, vFpi)
GO(gtk_stack_set_interpolate_size, vFpi)
GO(gtk_stack_set_transition_duration, vFpu)
GO(gtk_stack_set_transition_type, vFpu)
GO(gtk_stack_set_vhomogeneous, vFpi)
GO(gtk_stack_set_visible_child, vFpp)
GO(gtk_stack_set_visible_child_full, vFppu)
GO(gtk_stack_set_visible_child_name, vFpp)
GO(gtk_stack_sidebar_get_stack, pFp)
GO(gtk_stack_sidebar_get_type, LFv)
GO(gtk_stack_sidebar_new, pFv)
GO(gtk_stack_sidebar_set_stack, vFpp)
GO(gtk_stack_switcher_get_stack, pFp)
GO(gtk_stack_switcher_get_type, LFv)
GO(gtk_stack_switcher_new, pFv)
GO(gtk_stack_switcher_set_stack, vFpp)
GO(gtk_stack_transition_type_get_type, LFv)
GO(gtk_state_flags_get_type, LFv)
GO(gtk_state_type_get_type, LFv)
GO(gtk_statusbar_accessible_get_type, LFv)
GO(gtk_statusbar_get_context_id, uFpp)
GO(gtk_statusbar_get_message_area, pFp)
GO(gtk_statusbar_get_type, LFv)
GO(gtk_statusbar_new, pFv)
GO(gtk_statusbar_pop, vFpu)
GO(gtk_statusbar_push, uFpup)
GO(gtk_statusbar_remove, vFpuu)
GO(gtk_statusbar_remove_all, vFpu)
GO(gtk_status_icon_get_geometry, iFpppp)
GO(gtk_status_icon_get_gicon, pFp)
GO(gtk_status_icon_get_has_tooltip, iFp)
GO(gtk_status_icon_get_icon_name, pFp)
GO(gtk_status_icon_get_pixbuf, pFp)
GO(gtk_status_icon_get_screen, pFp)
GO(gtk_status_icon_get_size, iFp)
GO(gtk_status_icon_get_stock, pFp)
GO(gtk_status_icon_get_storage_type, uFp)
GO(gtk_status_icon_get_title, pFp)
GO(gtk_status_icon_get_tooltip_markup, pFp)
GO(gtk_status_icon_get_tooltip_text, pFp)
GO(gtk_status_icon_get_type, LFv)
GO(gtk_status_icon_get_visible, iFp)
GO(gtk_status_icon_get_x11_window_id, uFp)
GO(gtk_status_icon_is_embedded, iFp)
GO(gtk_status_icon_new, pFv)
GO(gtk_status_icon_new_from_file, pFp)
GO(gtk_status_icon_new_from_gicon, pFp)
GO(gtk_status_icon_new_from_icon_name, pFp)
GO(gtk_status_icon_new_from_pixbuf, pFp)
GO(gtk_status_icon_new_from_stock, pFp)
GO(gtk_status_icon_position_menu, vFppppp)
GO(gtk_status_icon_set_from_file, vFpp)
GO(gtk_status_icon_set_from_gicon, vFpp)
GO(gtk_status_icon_set_from_icon_name, vFpp)
GO(gtk_status_icon_set_from_pixbuf, vFpp)
GO(gtk_status_icon_set_from_stock, vFpp)
GO(gtk_status_icon_set_has_tooltip, vFpi)
GO(gtk_status_icon_set_name, vFpp)
GO(gtk_status_icon_set_screen, vFpp)
GO(gtk_status_icon_set_title, vFpp)
GO(gtk_status_icon_set_tooltip_markup, vFpp)
GO(gtk_status_icon_set_tooltip_text, vFpp)
GO(gtk_status_icon_set_visible, vFpi)
GO(gtk_stock_add, vFpu)
GO(gtk_stock_add_static, vFpu)
GO(gtk_stock_item_copy, pFp)
GO(gtk_stock_item_free, vFp)
GO(gtk_stock_list_ids, pFv)
GO(gtk_stock_lookup, iFpp)
GOM(gtk_stock_set_translate_func, vFEpppp)
GO(gtk_style_apply_default_background, vFpppuiiii)
GO(gtk_style_attach, pFpp)
GO(gtk_style_context_add_class, vFpp)
GO(gtk_style_context_add_provider, vFppu)
GO(gtk_style_context_add_provider_for_display, vFppu)
GO(gtk_style_context_add_provider_for_screen, vFppu)
GO(gtk_style_context_add_region, vFppu)
GO(gtk_style_context_cancel_animations, vFpp)
GOM(gtk_style_context_get, vFEpuV)
GO(gtk_style_context_get_background_color, vFpup)
GO(gtk_style_context_get_border, vFpup)
GO(gtk_style_context_get_border_color, vFpup)
GO(gtk_style_context_get_color, vFpup)
GO(gtk_style_context_get_direction, uFp)
GO(gtk_style_context_get_font, pFpu)
GO(gtk_style_context_get_frame_clock, pFp)
GO(gtk_style_context_get_junction_sides, uFp)
GO(gtk_style_context_get_margin, vFpup)
GO(gtk_style_context_get_padding, vFpup)
GO(gtk_style_context_get_parent, pFp)
GO(gtk_style_context_get_path, pFp)
GO(gtk_style_context_get_property, vFppup)
GO(gtk_style_context_get_scale, iFp)
GO(gtk_style_context_get_screen, pFp)
GO(gtk_style_context_get_section, pFpp)
GO(gtk_style_context_get_state, uFp)
GOM(gtk_style_context_get_style, vFEpV)
GO(gtk_style_context_get_style_property, vFppp)
GOM(gtk_style_context_get_style_valist, vFEpA)
GO(gtk_style_context_get_type, LFv)
GOM(gtk_style_context_get_valist, vFEpuA)
GO(gtk_style_context_has_class, iFpp)
GO(gtk_style_context_has_region, iFppp)
GO(gtk_style_context_invalidate, vFp)
GO(gtk_style_context_list_classes, pFp)
GO(gtk_style_context_list_regions, pFp)
GO(gtk_style_context_lookup_color, iFppp)
GO(gtk_style_context_lookup_icon_set, pFpp)
GO(gtk_style_context_new, pFv)
GO(gtk_style_context_notify_state_change, vFpppui)
GO(gtk_style_context_pop_animatable_region, vFp)
GO(gtk_style_context_print_flags_get_type, LFv)
GO(gtk_style_context_push_animatable_region, vFpp)
GO(gtk_style_context_remove_class, vFpp)
GO(gtk_style_context_remove_provider, vFpp)
GO(gtk_style_context_remove_provider_for_display, vFpp)
GO(gtk_style_context_remove_provider_for_screen, vFpp)
GO(gtk_style_context_remove_region, vFpp)
GO(gtk_style_context_reset_widgets, vFp)
GO(gtk_style_context_restore, vFp)
GO(gtk_style_context_save, vFp)
GO(gtk_style_context_scroll_animations, vFppii)
GO(gtk_style_context_set_background, vFpp)
GO(gtk_style_context_set_direction, vFpu)
GO(gtk_style_context_set_frame_clock, vFpp)
GO(gtk_style_context_set_junction_sides, vFpu)
GO(gtk_style_context_set_parent, vFpp)
GO(gtk_style_context_set_path, vFpp)
GO(gtk_style_context_set_scale, vFpi)
GO(gtk_style_context_set_screen, vFpp)
GO(gtk_style_context_set_state, vFpu)
GO(gtk_style_context_state_is_running, iFpup)
GO(gtk_style_context_to_string, pFpu)
GO(gtk_style_copy, pFp)
GO(gtk_style_detach, vFp)
//GOM(gtk_style_get, vFpLpV)
GO(gtk_style_get_style_property, vFpLpp)
GO(gtk_style_get_type, LFv)
//GOM(gtk_style_get_valist, vFpLpA)
GO(gtk_style_has_context, iFp)
GO(gtk_style_lookup_color, iFppp)
GO(gtk_style_lookup_icon_set, pFpp)
GO(gtk_style_new, pFv)
GO(gtk_style_properties_clear, vFp)
//GOM(gtk_style_properties_get, vFpuV)
GO(gtk_style_properties_get_property, iFppup)
GO(gtk_style_properties_get_type, LFv)
//GOM(gtk_style_properties_get_valist, vFpuA)
GO(gtk_style_properties_lookup_color, pFpp)
//GOM(gtk_style_properties_lookup_property, iFppp)
GO(gtk_style_properties_map_color, vFppp)
GO(gtk_style_properties_merge, vFppi)
GO(gtk_style_properties_new, pFv)
//GOM(gtk_style_properties_register_property, vFpp)
//GOM(gtk_style_properties_set, vFpuV)
GO(gtk_style_properties_set_property, vFppup)
//GOM(gtk_style_properties_set_valist, vFpuA)
GO(gtk_style_properties_unset_property, vFppu)
GO(gtk_style_provider_get_icon_factory, pFpp)
GO(gtk_style_provider_get_style, pFpp)
GO(gtk_style_provider_get_style_property, iFppupp)
GO(gtk_style_provider_get_type, LFv)
GO(gtk_style_render_icon, pFppuuupp)
GO(gtk_style_set_background, vFppu)
GO(gtk_switch_accessible_get_type, LFv)
GO(gtk_switch_get_active, iFp)
GO(gtk_switch_get_state, iFp)
GO(gtk_switch_get_type, LFv)
GO(gtk_switch_new, pFv)
GO(gtk_switch_set_active, vFpi)
GO(gtk_switch_set_state, vFpi)
GO(gtk_symbolic_color_get_type, LFv)
GO(gtk_symbolic_color_new_alpha, pFpd)
GO(gtk_symbolic_color_new_literal, pFp)
GO(gtk_symbolic_color_new_mix, pFppd)
GO(gtk_symbolic_color_new_name, pFp)
GO(gtk_symbolic_color_new_shade, pFpd)
GO(gtk_symbolic_color_new_win32, pFpi)
GO(gtk_symbolic_color_ref, pFp)
GO(gtk_symbolic_color_resolve, iFppp)
GO(gtk_symbolic_color_to_string, pFp)
GO(gtk_symbolic_color_unref, vFp)
GO(gtk_table_attach, vFppuuuuuuuu)
GO(gtk_table_attach_defaults, vFppuuuu)
GO(gtk_table_get_col_spacing, uFpu)
GO(gtk_table_get_default_col_spacing, uFp)
GO(gtk_table_get_default_row_spacing, uFp)
GO(gtk_table_get_homogeneous, iFp)
GO(gtk_table_get_row_spacing, uFpu)
GO(gtk_table_get_size, vFppp)
GO(gtk_table_get_type, LFv)
GO(gtk_table_new, pFuui)
GO(gtk_table_resize, vFpuu)
GO(gtk_table_set_col_spacing, vFpuu)
GO(gtk_table_set_col_spacings, vFpu)
GO(gtk_table_set_homogeneous, vFpi)
GO(gtk_table_set_row_spacing, vFpuu)
GO(gtk_table_set_row_spacings, vFpu)
GO(gtk_target_entry_copy, pFp)
GO(gtk_target_entry_free, vFp)
GO(gtk_target_entry_get_type, LFv)
GO(gtk_target_entry_new, pFpuu)
GO(gtk_target_flags_get_type, LFv)
GO(gtk_target_list_add, vFppuu)
GO(gtk_target_list_add_image_targets, vFpui)
GO(gtk_target_list_add_rich_text_targets, vFpuip)
GO(gtk_target_list_add_table, vFppu)
GO(gtk_target_list_add_text_targets, vFpu)
GO(gtk_target_list_add_uri_targets, vFpu)
GO(gtk_target_list_find, iFppp)
GO(gtk_target_list_get_type, LFv)
GO(gtk_target_list_new, pFpu)
GO(gtk_target_list_ref, pFp)
GO(gtk_target_list_remove, vFpp)
GO(gtk_target_list_unref, vFp)
GO(gtk_targets_include_image, iFpii)
GO(gtk_targets_include_rich_text, iFpip)
GO(gtk_targets_include_text, iFpi)
GO(gtk_targets_include_uri, iFpi)
GO(gtk_target_table_free, vFpi)
GO(gtk_target_table_new_from_list, pFpp)
GO(gtk_tearoff_menu_item_get_type, LFv)
GO(gtk_tearoff_menu_item_new, pFv)
GO(gtk_test_create_simple_window, pFpp)
//GOM(gtk_test_create_widget, pFLpV)
//GOM(gtk_test_display_button_window, pFppV)
GO(gtk_test_find_label, pFpp)
GO(gtk_test_find_sibling, pFpL)
GO(gtk_test_find_widget, pFppL)
//GOM(gtk_test_init, vFppV)
GO(gtk_test_list_all_types, pFp)
GO(gtk_test_register_all_types, vFv)
GO(gtk_test_slider_get_value, dFp)
GO(gtk_test_slider_set_perc, vFpd)
GO(gtk_test_spin_button_click, iFpui)
GO(gtk_test_text_get, pFp)
GO(gtk_test_text_set, vFpp)
GO(gtk_test_widget_click, iFpuu)
GO(gtk_test_widget_send_key, iFpuu)
GO(gtk_test_widget_wait_for_draw, vFp)
//GO(gtk_text_anchored_child_set_layout, 
GO(gtk_text_attributes_copy, pFp)
GO(gtk_text_attributes_copy_values, vFpp)
GO(gtk_text_attributes_get_type, LFv)
GO(gtk_text_attributes_new, pFv)
GO(gtk_text_attributes_ref, pFp)
GO(gtk_text_attributes_unref, vFp)
GO(gtk_text_buffer_add_mark, vFppp)
GO(gtk_text_buffer_add_selection_clipboard, vFpp)
GO(gtk_text_buffer_apply_tag, vFpppp)
GO(gtk_text_buffer_apply_tag_by_name, vFpppp)
GO(gtk_text_buffer_backspace, iFppii)
GO(gtk_text_buffer_begin_user_action, vFp)
GO(gtk_text_buffer_copy_clipboard, vFpp)
GO(gtk_text_buffer_create_child_anchor, pFpp)
GO(gtk_text_buffer_create_mark, pFpppi)
GO(gtk_text_buffer_create_tag, pFppppppppppppppp) //vaarg after 3 p
GO(gtk_text_buffer_cut_clipboard, vFppi)
GO(gtk_text_buffer_delete, vFppp)
GO(gtk_text_buffer_delete_interactive, iFpppi)
GO(gtk_text_buffer_delete_mark, vFpp)
GO(gtk_text_buffer_delete_mark_by_name, vFpp)
GO(gtk_text_buffer_delete_selection, iFpii)
GO(gtk_text_buffer_deserialize, iFpppppLp)
GO(gtk_text_buffer_deserialize_get_can_create_tags, iFpp)
GO(gtk_text_buffer_deserialize_set_can_create_tags, vFppi)
GO(gtk_text_buffer_end_user_action, vFp)
GO(gtk_text_buffer_get_bounds, vFppp)
GO(gtk_text_buffer_get_char_count, iFp)
GO(gtk_text_buffer_get_copy_target_list, pFp)
GO(gtk_text_buffer_get_deserialize_formats, pFpp)
GO(gtk_text_buffer_get_end_iter, vFpp)
GO(gtk_text_buffer_get_has_selection, iFp)
GO(gtk_text_buffer_get_insert, pFp)
GO(gtk_text_buffer_get_iter_at_child_anchor, vFppp)
GO(gtk_text_buffer_get_iter_at_line, vFppi)
GO(gtk_text_buffer_get_iter_at_line_index, vFppii)
GO(gtk_text_buffer_get_iter_at_line_offset, vFppii)
GO(gtk_text_buffer_get_iter_at_mark, vFppp)
GO(gtk_text_buffer_get_iter_at_offset, vFppi)
GO(gtk_text_buffer_get_line_count, iFp)
GO(gtk_text_buffer_get_mark, pFpp)
GO(gtk_text_buffer_get_modified, iFp)
GO(gtk_text_buffer_get_paste_target_list, pFp)
GO(gtk_text_buffer_get_selection_bound, pFp)
GO(gtk_text_buffer_get_selection_bounds, iFppp)
GO(gtk_text_buffer_get_serialize_formats, pFpp)
GO(gtk_text_buffer_get_slice, pFpppi)
GO(gtk_text_buffer_get_start_iter, vFpp)
GO(gtk_text_buffer_get_tag_table, pFp)
GO(gtk_text_buffer_get_text, pFpppi)
GO(gtk_text_buffer_get_type, LFv)
GO(gtk_text_buffer_insert, vFpppi)
GO(gtk_text_buffer_insert_at_cursor, vFppi)
GO(gtk_text_buffer_insert_child_anchor, vFppp)
GO(gtk_text_buffer_insert_interactive, iFpppii)
GO(gtk_text_buffer_insert_interactive_at_cursor, iFppii)
GO(gtk_text_buffer_insert_markup, vFpppi)
GO(gtk_text_buffer_insert_pixbuf, vFppp)
GO(gtk_text_buffer_insert_range, vFpppp)
GO(gtk_text_buffer_insert_range_interactive, iFppppi)
GO(gtk_text_buffer_insert_with_tags, vFpppipppppppppppppp)
GO(gtk_text_buffer_insert_with_tags_by_name, vFpppippppppppppp)
GO(gtk_text_buffer_move_mark, vFppp)
GO(gtk_text_buffer_move_mark_by_name, vFppp)
GO(gtk_text_buffer_new, pFp)
GO(gtk_text_buffer_paste_clipboard, vFpppi)
GO(gtk_text_buffer_place_cursor, vFpp)
//GOM(gtk_text_buffer_register_deserialize_format, pFEppppp)
GO(gtk_text_buffer_register_deserialize_tagset, pFpp)
//GOM(gtk_text_buffer_register_serialize_format, pFppppp)
GO(gtk_text_buffer_register_serialize_tagset, pFpp)
GO(gtk_text_buffer_remove_all_tags, vFppp)
GO(gtk_text_buffer_remove_selection_clipboard, vFpp)
GO(gtk_text_buffer_remove_tag, vFpppp)
GO(gtk_text_buffer_remove_tag_by_name, vFpppp)
GO(gtk_text_buffer_select_range, vFppp)
GO(gtk_text_buffer_serialize, pFpppppp)
GO(gtk_text_buffer_set_modified, vFpi)
GO(gtk_text_buffer_set_text, vFppi)
GO(gtk_text_buffer_target_info_get_type, LFv)
GO(gtk_text_buffer_unregister_deserialize_format, vFpp)
GO(gtk_text_buffer_unregister_serialize_format, vFpp)
//GO(gtk_text_byte_begins_utf8_char, 
GO(gtk_text_cell_accessible_get_type, LFv)
GO(gtk_text_child_anchor_get_deleted, iFp)
GO(gtk_text_child_anchor_get_type, LFv)
GO(gtk_text_child_anchor_get_widgets, pFp)
GO(gtk_text_child_anchor_new, pFv)
GO(gtk_text_child_anchor_queue_resize, vFpp)
GO(gtk_text_child_anchor_register_child, vFppp)
GO(gtk_text_child_anchor_unregister_child, vFpp)
GO(gtk_text_direction_get_type, LFv)
GO(gtk_text_extend_selection_get_type, LFv)
GO(gtk_text_iter_assign, vFpp)
GO(gtk_text_iter_backward_char, iFp)
GO(gtk_text_iter_backward_chars, iFpi)
GO(gtk_text_iter_backward_cursor_position, iFp)
GO(gtk_text_iter_backward_cursor_positions, iFpi)
GOM(gtk_text_iter_backward_find_char, iFEpppp)
GO(gtk_text_iter_backward_line, iFp)
GO(gtk_text_iter_backward_lines, iFpi)
GO(gtk_text_iter_backward_search, iFppuppp)
GO(gtk_text_iter_backward_sentence_start, iFp)
GO(gtk_text_iter_backward_sentence_starts, iFpi)
GO(gtk_text_iter_backward_to_tag_toggle, iFpp)
GO(gtk_text_iter_backward_visible_cursor_position, iFp)
GO(gtk_text_iter_backward_visible_cursor_positions, iFpi)
GO(gtk_text_iter_backward_visible_line, iFp)
GO(gtk_text_iter_backward_visible_lines, iFpi)
GO(gtk_text_iter_backward_visible_word_start, iFp)
GO(gtk_text_iter_backward_visible_word_starts, iFpi)
GO(gtk_text_iter_backward_word_start, iFp)
GO(gtk_text_iter_backward_word_starts, iFpi)
GO(gtk_text_iter_begins_tag, iFpp)
GO(gtk_text_iter_can_insert, iFpi)
GO(gtk_text_iter_compare, iFpp)
GO(gtk_text_iter_copy, pFp)
GO(gtk_text_iter_editable, iFpi)
GO(gtk_text_iter_ends_line, iFp)
GO(gtk_text_iter_ends_sentence, iFp)
GO(gtk_text_iter_ends_tag, iFpp)
GO(gtk_text_iter_ends_word, iFp)
GO(gtk_text_iter_equal, iFpp)
GO(gtk_text_iter_forward_char, iFp)
GO(gtk_text_iter_forward_chars, iFpi)
GO(gtk_text_iter_forward_cursor_position, iFp)
GO(gtk_text_iter_forward_cursor_positions, iFpi)
GOM(gtk_text_iter_forward_find_char, iFEpppp)
GO(gtk_text_iter_forward_line, iFp)
GO(gtk_text_iter_forward_lines, iFpi)
GO(gtk_text_iter_forward_search, iFppuppp)
GO(gtk_text_iter_forward_sentence_end, iFp)
GO(gtk_text_iter_forward_sentence_ends, iFpi)
GO(gtk_text_iter_forward_to_end, vFp)
GO(gtk_text_iter_forward_to_line_end, iFp)
GO(gtk_text_iter_forward_to_tag_toggle, iFpp)
GO(gtk_text_iter_forward_visible_cursor_position, iFp)
GO(gtk_text_iter_forward_visible_cursor_positions, iFpi)
GO(gtk_text_iter_forward_visible_line, iFp)
GO(gtk_text_iter_forward_visible_lines, iFpi)
GO(gtk_text_iter_forward_visible_word_end, iFp)
GO(gtk_text_iter_forward_visible_word_ends, iFpi)
GO(gtk_text_iter_forward_word_end, iFp)
GO(gtk_text_iter_forward_word_ends, iFpi)
GO(gtk_text_iter_free, vFp)
GO(gtk_text_iter_get_attributes, iFpp)
GO(gtk_text_iter_get_buffer, pFp)
GO(gtk_text_iter_get_bytes_in_line, iFp)
GO(gtk_text_iter_get_char, uFp)
GO(gtk_text_iter_get_chars_in_line, iFp)
GO(gtk_text_iter_get_child_anchor, pFp)
GO(gtk_text_iter_get_language, pFp)
GO(gtk_text_iter_get_line, iFp)
GO(gtk_text_iter_get_line_index, iFp)
GO(gtk_text_iter_get_line_offset, iFp)
GO(gtk_text_iter_get_marks, pFp)
GO(gtk_text_iter_get_offset, iFp)
GO(gtk_text_iter_get_pixbuf, pFp)
GO(gtk_text_iter_get_slice, pFpp)
GO(gtk_text_iter_get_tags, pFp)
GO(gtk_text_iter_get_text, pFpp)
GO(gtk_text_iter_get_toggled_tags, pFpi)
GO(gtk_text_iter_get_type, LFv)
GO(gtk_text_iter_get_visible_line_index, iFp)
GO(gtk_text_iter_get_visible_line_offset, iFp)
GO(gtk_text_iter_get_visible_slice, pFpp)
GO(gtk_text_iter_get_visible_text, pFpp)
GO(gtk_text_iter_has_tag, iFpp)
GO(gtk_text_iter_in_range, iFppp)
GO(gtk_text_iter_inside_sentence, iFp)
GO(gtk_text_iter_inside_word, iFp)
GO(gtk_text_iter_is_cursor_position, iFp)
GO(gtk_text_iter_is_end, iFp)
GO(gtk_text_iter_is_start, iFp)
GO(gtk_text_iter_order, vFpp)
GO(gtk_text_iter_set_line, vFpi)
GO(gtk_text_iter_set_line_index, vFpi)
GO(gtk_text_iter_set_line_offset, vFpi)
GO(gtk_text_iter_set_offset, vFpi)
GO(gtk_text_iter_set_visible_line_index, vFpi)
GO(gtk_text_iter_set_visible_line_offset, vFpi)
GO(gtk_text_iter_starts_line, iFp)
GO(gtk_text_iter_starts_sentence, iFp)
GO(gtk_text_iter_starts_tag, iFpp)
GO(gtk_text_iter_starts_word, iFp)
GO(gtk_text_iter_toggles_tag, iFpp)
//GO(gtk_text_layout_changed, 
//GO(gtk_text_layout_clamp_iter_to_vrange, 
//GO(gtk_text_layout_cursors_changed, 
//GO(gtk_text_layout_default_style_changed, 
//GO(gtk_text_layout_draw, 
//GO(gtk_text_layout_free_line_data, 
//GO(gtk_text_layout_free_line_display, 
//GO(gtk_text_layout_get_buffer, 
//GO(gtk_text_layout_get_cursor_locations, 
//GO(gtk_text_layout_get_cursor_visible, 
//GO(gtk_text_layout_get_iter_at_line, 
//GO(gtk_text_layout_get_iter_at_pixel, 
//GO(gtk_text_layout_get_iter_at_position, 
//GO(gtk_text_layout_get_iter_location, 
//GO(gtk_text_layout_get_line_at_y, 
//GO(gtk_text_layout_get_line_display, 
//GO(gtk_text_layout_get_lines, 
//GO(gtk_text_layout_get_line_yrange, 
//GO(gtk_text_layout_get_size, 
//GO(gtk_text_layout_get_type, 
//GO(gtk_text_layout_invalidate, 
//GO(gtk_text_layout_invalidate_cursors, 
//GO(gtk_text_layout_is_valid, 
//GO(gtk_text_layout_iter_starts_line, 
//GO(gtk_text_layout_move_iter_to_line_end, 
//GO(gtk_text_layout_move_iter_to_next_line, 
//GO(gtk_text_layout_move_iter_to_previous_line, 
//GO(gtk_text_layout_move_iter_to_x, 
//GO(gtk_text_layout_move_iter_visually, 
//GO(gtk_text_layout_new, 
//GO(gtk_text_layout_set_buffer, 
//GO(gtk_text_layout_set_contexts, 
//GO(gtk_text_layout_set_cursor_direction, 
//GO(gtk_text_layout_set_cursor_visible, 
//GO(gtk_text_layout_set_default_style, 
//GO(gtk_text_layout_set_keyboard_direction, 
//GO(gtk_text_layout_set_overwrite_mode, 
//GO(gtk_text_layout_set_preedit_string, 
//GO(gtk_text_layout_set_screen_width, 
//GO(gtk_text_layout_spew, 
//GO(gtk_text_layout_validate, 
//GO(gtk_text_layout_validate_yrange, 
//GO(gtk_text_layout_wrap, 
//GO(gtk_text_layout_wrap_loop_end, 
//GO(gtk_text_layout_wrap_loop_start, 
//GO(gtk_text_line_segment_split, 
GO(gtk_text_mark_get_buffer, pFp)
GO(gtk_text_mark_get_deleted, iFp)
GO(gtk_text_mark_get_left_gravity, iFp)
GO(gtk_text_mark_get_name, pFp)
GO(gtk_text_mark_get_type, LFv)
GO(gtk_text_mark_get_visible, iFp)
GO(gtk_text_mark_new, pFpi)
GO(gtk_text_mark_set_visible, vFpi)
GO(gtk_text_search_flags_get_type, LFv)
GO(gtk_text_tag_changed, vFpi)
GO(gtk_text_tag_event, iFpppp)
GO(gtk_text_tag_get_priority, iFp)
GO(gtk_text_tag_get_type, LFv)
GO(gtk_text_tag_new, pFp)
GO(gtk_text_tag_set_priority, vFpi)
GO(gtk_text_tag_table_add, iFpp)
//GOM(gtk_text_tag_table_foreach, vFEppp)
GO(gtk_text_tag_table_get_size, iFp)
GO(gtk_text_tag_table_get_type, LFv)
GO(gtk_text_tag_table_lookup, pFpp)
GO(gtk_text_tag_table_new, pFv)
GO(gtk_text_tag_table_remove, vFpp)
//GO(gtk_text_unknown_char_utf8_gtk_tests_only, 
GO(gtk_text_view_accessible_get_type, LFv)
GO(gtk_text_view_add_child_at_anchor, vFppp)
GO(gtk_text_view_add_child_in_window, vFppuii)
GO(gtk_text_view_backward_display_line, iFpp)
GO(gtk_text_view_backward_display_line_start, iFpp)
GO(gtk_text_view_buffer_to_window_coords, vFpuiipp)
GO(gtk_text_view_forward_display_line, iFpp)
GO(gtk_text_view_forward_display_line_end, iFpp)
GO(gtk_text_view_get_accepts_tab, iFp)
GO(gtk_text_view_get_border_window_size, iFpu)
GO(gtk_text_view_get_bottom_margin, iFp)
GO(gtk_text_view_get_buffer, pFp)
GO(gtk_text_view_get_cursor_locations, vFpppp)
GO(gtk_text_view_get_cursor_visible, iFp)
GO(gtk_text_view_get_default_attributes, pFp)
GO(gtk_text_view_get_editable, iFp)
GO(gtk_text_view_get_hadjustment, pFp)
GO(gtk_text_view_get_indent, iFp)
GO(gtk_text_view_get_input_hints, uFp)
GO(gtk_text_view_get_input_purpose, uFp)
GO(gtk_text_view_get_iter_at_location, iFppii)
GO(gtk_text_view_get_iter_at_position, iFpppii)
GO(gtk_text_view_get_iter_location, vFppp)
GO(gtk_text_view_get_justification, uFp)
GO(gtk_text_view_get_left_margin, iFp)
GO(gtk_text_view_get_line_at_y, vFppip)
GO(gtk_text_view_get_line_yrange, vFpppp)
GO(gtk_text_view_get_monospace, iFp)
GO(gtk_text_view_get_overwrite, iFp)
GO(gtk_text_view_get_pixels_above_lines, iFp)
GO(gtk_text_view_get_pixels_below_lines, iFp)
GO(gtk_text_view_get_pixels_inside_wrap, iFp)
GO(gtk_text_view_get_right_margin, iFp)
GO(gtk_text_view_get_tabs, pFp)
GO(gtk_text_view_get_top_margin, iFp)
GO(gtk_text_view_get_type, LFv)
GO(gtk_text_view_get_vadjustment, pFp)
GO(gtk_text_view_get_visible_rect, vFpp)
GO(gtk_text_view_get_window, pFpu)
GO(gtk_text_view_get_window_type, uFpp)
GO(gtk_text_view_get_wrap_mode, uFp)
GO(gtk_text_view_im_context_filter_keypress, iFpp)
GO(gtk_text_view_layer_get_type, LFv)
GO(gtk_text_view_move_child, vFppii)
GO(gtk_text_view_move_mark_onscreen, iFpp)
GO(gtk_text_view_move_visually, iFppi)
GO(gtk_text_view_new, pFv)
GO(gtk_text_view_new_with_buffer, pFp)
GO(gtk_text_view_place_cursor_onscreen, iFp)
GO(gtk_text_view_reset_cursor_blink, vFp)
GO(gtk_text_view_reset_im_context, vFp)
GO(gtk_text_view_scroll_mark_onscreen, vFpp)
GO(gtk_text_view_scroll_to_iter, iFppdidd)
GO(gtk_text_view_scroll_to_mark, vFppdidd)
GO(gtk_text_view_set_accepts_tab, vFpi)
GO(gtk_text_view_set_border_window_size, vFpui)
GO(gtk_text_view_set_bottom_margin, vFpi)
GO(gtk_text_view_set_buffer, vFpp)
GO(gtk_text_view_set_cursor_visible, vFpi)
GO(gtk_text_view_set_editable, vFpi)
GO(gtk_text_view_set_indent, vFpi)
GO(gtk_text_view_set_input_hints, vFpu)
GO(gtk_text_view_set_input_purpose, vFpu)
GO(gtk_text_view_set_justification, vFpu)
GO(gtk_text_view_set_left_margin, vFpi)
GO(gtk_text_view_set_monospace, vFpi)
GO(gtk_text_view_set_overwrite, vFpi)
GO(gtk_text_view_set_pixels_above_lines, vFpi)
GO(gtk_text_view_set_pixels_below_lines, vFpi)
GO(gtk_text_view_set_pixels_inside_wrap, vFpi)
GO(gtk_text_view_set_right_margin, vFpi)
GO(gtk_text_view_set_tabs, vFpp)
GO(gtk_text_view_set_top_margin, vFpi)
GO(gtk_text_view_set_wrap_mode, vFpu)
GO(gtk_text_view_starts_display_line, iFpp)
GO(gtk_text_view_window_to_buffer_coords, vFpuiipp)
GO(gtk_text_window_type_get_type, LFv)
//GOM(gtk_theming_engine_get, vFpuV)
GO(gtk_theming_engine_get_background_color, vFpup)
GO(gtk_theming_engine_get_border, vFpup)
GO(gtk_theming_engine_get_border_color, vFpup)
GO(gtk_theming_engine_get_color, vFpup)
GO(gtk_theming_engine_get_direction, uFp)
GO(gtk_theming_engine_get_font, pFpu)
GO(gtk_theming_engine_get_junction_sides, uFp)
GO(gtk_theming_engine_get_margin, vFpup)
GO(gtk_theming_engine_get_padding, vFpup)
GO(gtk_theming_engine_get_path, pFp)
GO(gtk_theming_engine_get_property, vFppup)
GO(gtk_theming_engine_get_screen, pFp)
GO(gtk_theming_engine_get_state, uFp)
//GOM(gtk_theming_engine_get_style, vFpV)
GO(gtk_theming_engine_get_style_property, vFppp)
//GOM(gtk_theming_engine_get_style_valist, vFpA)
GO(gtk_theming_engine_get_type, LFv)
//GOM(gtk_theming_engine_get_valist, vFpuA)
GO(gtk_theming_engine_has_class, iFpp)
GO(gtk_theming_engine_has_region, iFppp)
GO(gtk_theming_engine_load, pFp)
GO(gtk_theming_engine_lookup_color, iFppp)
//GOM(gtk_theming_engine_register_property, vFppp)
GO(gtk_theming_engine_state_is_running, iFpup)
//GO(gtk_theming_module_get_type, 
GO(gtk_toggle_action_get_active, iFp)
GO(gtk_toggle_action_get_draw_as_radio, iFp)
GO(gtk_toggle_action_get_type, LFv)
GO(gtk_toggle_action_new, pFpppp)
GO(gtk_toggle_action_set_active, vFpi)
GO(gtk_toggle_action_set_draw_as_radio, vFpi)
GO(gtk_toggle_action_toggled, vFp)
GO(gtk_toggle_button_accessible_get_type, LFv)
GO(gtk_toggle_button_get_active, iFp)
GO(gtk_toggle_button_get_inconsistent, iFp)
GO(gtk_toggle_button_get_mode, iFp)
GO(gtk_toggle_button_get_type, LFv)
GO(gtk_toggle_button_new, pFv)
GO(gtk_toggle_button_new_with_label, pFp)
GO(gtk_toggle_button_new_with_mnemonic, pFp)
GO(gtk_toggle_button_set_active, vFpi)
GO(gtk_toggle_button_set_inconsistent, vFpi)
GO(gtk_toggle_button_set_mode, vFpi)
GO(gtk_toggle_button_toggled, vFp)
GO(gtk_toggle_tool_button_get_active, iFp)
GO(gtk_toggle_tool_button_get_type, LFv)
GO(gtk_toggle_tool_button_new, pFv)
GO(gtk_toggle_tool_button_new_from_stock, pFp)
GO(gtk_toggle_tool_button_set_active, vFpi)
GO(gtk_toolbar_get_drop_index, iFpii)
GO(gtk_toolbar_get_icon_size, uFp)
GO(gtk_toolbar_get_item_index, iFpp)
GO(gtk_toolbar_get_n_items, iFp)
GO(gtk_toolbar_get_nth_item, pFpi)
GO(gtk_toolbar_get_relief_style, uFp)
GO(gtk_toolbar_get_show_arrow, iFp)
GO(gtk_toolbar_get_style, uFp)
GO(gtk_toolbar_get_type, LFv)
GO(gtk_toolbar_insert, vFppi)
GO(gtk_toolbar_new, pFv)
GO(gtk_toolbar_set_drop_highlight_item, vFppi)
GO(gtk_toolbar_set_icon_size, vFpu)
GO(gtk_toolbar_set_show_arrow, vFpi)
GO(gtk_toolbar_set_style, vFpu)
GO(gtk_toolbar_space_style_get_type, LFv)
GO(gtk_toolbar_style_get_type, LFv)
GO(gtk_toolbar_unset_icon_size, vFp)
GO(gtk_toolbar_unset_style, vFp)
GO(gtk_tool_button_get_icon_name, pFp)
GO(gtk_tool_button_get_icon_widget, pFp)
GO(gtk_tool_button_get_label, pFp)
GO(gtk_tool_button_get_label_widget, pFp)
GO(gtk_tool_button_get_stock_id, pFp)
GO(gtk_tool_button_get_type, LFv)
GO(gtk_tool_button_get_use_underline, iFp)
GO(gtk_tool_button_new, pFpp)
GO(gtk_tool_button_new_from_stock, pFp)
GO(gtk_tool_button_set_icon_name, vFpp)
GO(gtk_tool_button_set_icon_widget, vFpp)
GO(gtk_tool_button_set_label, vFpp)
GO(gtk_tool_button_set_label_widget, vFpp)
GO(gtk_tool_button_set_stock_id, vFpp)
GO(gtk_tool_button_set_use_underline, vFpi)
GO(gtk_tool_item_get_ellipsize_mode, uFp)
GO(gtk_tool_item_get_expand, iFp)
GO(gtk_tool_item_get_homogeneous, iFp)
GO(gtk_tool_item_get_icon_size, uFp)
GO(gtk_tool_item_get_is_important, iFp)
GO(gtk_tool_item_get_orientation, uFp)
GO(gtk_tool_item_get_proxy_menu_item, pFpp)
GO(gtk_tool_item_get_relief_style, uFp)
GO(gtk_tool_item_get_text_alignment, fFp)
GO(gtk_tool_item_get_text_orientation, uFp)
GO(gtk_tool_item_get_text_size_group, pFp)
GO(gtk_tool_item_get_toolbar_style, uFp)
GO(gtk_tool_item_get_type, LFv)
GO(gtk_tool_item_get_use_drag_window, iFp)
GO(gtk_tool_item_get_visible_horizontal, iFp)
GO(gtk_tool_item_get_visible_vertical, iFp)
GO(gtk_tool_item_group_get_collapsed, iFp)
GO(gtk_tool_item_group_get_drop_item, pFpii)
GO(gtk_tool_item_group_get_ellipsize, uFp)
GO(gtk_tool_item_group_get_header_relief, uFp)
GO(gtk_tool_item_group_get_item_position, iFpp)
GO(gtk_tool_item_group_get_label, pFp)
GO(gtk_tool_item_group_get_label_widget, pFp)
GO(gtk_tool_item_group_get_n_items, uFp)
GO(gtk_tool_item_group_get_nth_item, pFpu)
GO(gtk_tool_item_group_get_type, LFv)
GO(gtk_tool_item_group_insert, vFppi)
GO(gtk_tool_item_group_new, pFp)
GO(gtk_tool_item_group_set_collapsed, vFpi)
GO(gtk_tool_item_group_set_ellipsize, vFpu)
GO(gtk_tool_item_group_set_header_relief, vFpu)
GO(gtk_tool_item_group_set_item_position, vFppi)
GO(gtk_tool_item_group_set_label, vFpp)
GO(gtk_tool_item_group_set_label_widget, vFpp)
GO(gtk_tool_item_new, pFv)
GO(gtk_tool_item_rebuild_menu, vFp)
GO(gtk_tool_item_retrieve_proxy_menu_item, pFp)
GO(gtk_tool_item_set_expand, vFpi)
GO(gtk_tool_item_set_homogeneous, vFpi)
GO(gtk_tool_item_set_is_important, vFpi)
GO(gtk_tool_item_set_proxy_menu_item, vFppp)
GO(gtk_tool_item_set_tooltip_markup, vFpp)
GO(gtk_tool_item_set_tooltip_text, vFpp)
GO(gtk_tool_item_set_use_drag_window, vFpi)
GO(gtk_tool_item_set_visible_horizontal, vFpi)
GO(gtk_tool_item_set_visible_vertical, vFpi)
GO(gtk_tool_item_toolbar_reconfigured, vFp)
GO(gtk_tool_palette_add_drag_dest, vFppuuu)
GO(gtk_tool_palette_drag_targets_get_type, LFv)
GO(gtk_tool_palette_get_drag_item, pFpp)
GO(gtk_tool_palette_get_drag_target_group, pFv)
GO(gtk_tool_palette_get_drag_target_item, pFv)
GO(gtk_tool_palette_get_drop_group, pFpii)
GO(gtk_tool_palette_get_drop_item, pFpii)
GO(gtk_tool_palette_get_exclusive, iFpp)
GO(gtk_tool_palette_get_expand, iFpp)
GO(gtk_tool_palette_get_group_position, iFpp)
GO(gtk_tool_palette_get_hadjustment, pFp)
GO(gtk_tool_palette_get_icon_size, uFp)
GO(gtk_tool_palette_get_style, uFp)
GO(gtk_tool_palette_get_type, LFv)
GO(gtk_tool_palette_get_vadjustment, pFp)
GO(gtk_tool_palette_new, pFv)
GO(gtk_tool_palette_set_drag_source, vFpu)
GO(gtk_tool_palette_set_exclusive, vFppi)
GO(gtk_tool_palette_set_expand, vFppi)
GO(gtk_tool_palette_set_group_position, vFppi)
GO(gtk_tool_palette_set_icon_size, vFpu)
GO(gtk_tool_palette_set_style, vFpu)
GO(gtk_tool_palette_unset_icon_size, vFp)
GO(gtk_tool_palette_unset_style, vFp)
GO(gtk_tool_shell_get_ellipsize_mode, uFp)
GO(gtk_tool_shell_get_icon_size, uFp)
GO(gtk_tool_shell_get_orientation, uFp)
GO(gtk_tool_shell_get_relief_style, uFp)
GO(gtk_tool_shell_get_style, uFp)
GO(gtk_tool_shell_get_text_alignment, fFp)
GO(gtk_tool_shell_get_text_orientation, uFp)
GO(gtk_tool_shell_get_text_size_group, pFp)
GO(gtk_tool_shell_get_type, LFv)
GO(gtk_tool_shell_rebuild_menu, vFp)
GO(gtk_tooltip_get_type, LFv)
GO(gtk_tooltip_set_custom, vFpp)
GO(gtk_tooltip_set_icon, vFpp)
GO(gtk_tooltip_set_icon_from_gicon, vFppu)
GO(gtk_tooltip_set_icon_from_icon_name, vFppu)
GO(gtk_tooltip_set_icon_from_stock, vFppu)
GO(gtk_tooltip_set_markup, vFpp)
GO(gtk_tooltip_set_text, vFpp)
GO(gtk_tooltip_set_tip_area, vFpp)
GO(gtk_tooltip_trigger_tooltip_query, vFp)
GO(gtk_toplevel_accessible_get_children, pFp)
GO(gtk_toplevel_accessible_get_type, LFv)
//GO(gtk_tray_icon_get_type, 
GO(gtk_tree_drag_dest_drag_data_received, iFppp)
GO(gtk_tree_drag_dest_get_type, LFv)
GO(gtk_tree_drag_dest_row_drop_possible, iFppp)
GO(gtk_tree_drag_source_drag_data_delete, iFpp)
GO(gtk_tree_drag_source_drag_data_get, iFppp)
GO(gtk_tree_drag_source_get_type, LFv)
GO(gtk_tree_drag_source_row_draggable, iFpp)
GO(gtk_tree_get_row_drag_data, iFppp)
GO(gtk_tree_iter_copy, pFp)
GO(gtk_tree_iter_free, vFp)
GO(gtk_tree_iter_get_type, LFv)
GO(gtk_tree_model_filter_clear_cache, vFp)
GO(gtk_tree_model_filter_convert_child_iter_to_iter, iFppp)
GO(gtk_tree_model_filter_convert_child_path_to_path, pFpp)
GO(gtk_tree_model_filter_convert_iter_to_child_iter, vFppp)
GO(gtk_tree_model_filter_convert_path_to_child_path, pFpp)
GO(gtk_tree_model_filter_get_model, pFp)
GO(gtk_tree_model_filter_get_type, LFv)
GO(gtk_tree_model_filter_new, pFpp)
GO(gtk_tree_model_filter_refilter, vFp)
//GOM(gtk_tree_model_filter_set_modify_func, vFpipppp)
GO(gtk_tree_model_filter_set_visible_column, vFpi)
//GOM(gtk_tree_model_filter_set_visible_func, vFpppp)
GO(gtk_tree_model_flags_get_type, LFv)
//GOM(gtk_tree_model_foreach, vFEppp)
GOM(gtk_tree_model_get, vFppV)
GO(gtk_tree_model_get_column_type, LFpi)
GO(gtk_tree_model_get_flags, uFp)
GO(gtk_tree_model_get_iter, iFppp)
GO(gtk_tree_model_get_iter_first, iFpp)
GO(gtk_tree_model_get_iter_from_string, iFppp)
GO(gtk_tree_model_get_n_columns, iFp)
GO(gtk_tree_model_get_path, pFpp)
GO(gtk_tree_model_get_string_from_iter, pFpp)
GO(gtk_tree_model_get_type, LFv)
GOM(gtk_tree_model_get_valist, vFppA)
GO(gtk_tree_model_get_value, vFppip)
GO(gtk_tree_model_iter_children, iFppp)
GO(gtk_tree_model_iter_has_child, iFpp)
GO(gtk_tree_model_iter_n_children, iFpp)
GO(gtk_tree_model_iter_next, iFpp)
GO(gtk_tree_model_iter_nth_child, iFpppi)
GO(gtk_tree_model_iter_parent, iFppp)
GO(gtk_tree_model_iter_previous, iFpp)
GO(gtk_tree_model_ref_node, vFpp)
GO(gtk_tree_model_row_changed, vFppp)
GO(gtk_tree_model_row_deleted, vFpp)
GO(gtk_tree_model_row_has_child_toggled, vFppp)
GO(gtk_tree_model_row_inserted, vFppp)
GO(gtk_tree_model_rows_reordered, vFpppp)
GO(gtk_tree_model_rows_reordered_with_length, vFppppi)
GO(gtk_tree_model_sort_clear_cache, vFp)
GO(gtk_tree_model_sort_convert_child_iter_to_iter, iFppp)
GO(gtk_tree_model_sort_convert_child_path_to_path, pFpp)
GO(gtk_tree_model_sort_convert_iter_to_child_iter, vFppp)
GO(gtk_tree_model_sort_convert_path_to_child_path, pFpp)
GO(gtk_tree_model_sort_get_model, pFp)
GO(gtk_tree_model_sort_get_type, LFv)
GO(gtk_tree_model_sort_iter_is_valid, iFpp)
GO(gtk_tree_model_sort_new_with_model, pFp)
GO(gtk_tree_model_sort_reset_default_sort_func, vFp)
GO(gtk_tree_model_unref_node, vFpp)
GO(gtk_tree_path_append_index, vFpi)
GO(gtk_tree_path_compare, iFpp)
GO(gtk_tree_path_copy, pFp)
GO(gtk_tree_path_down, vFp)
GO(gtk_tree_path_free, vFp)
GO(gtk_tree_path_get_depth, iFp)
GO(gtk_tree_path_get_indices, pFp)
GO(gtk_tree_path_get_indices_with_depth, pFpp)
GO(gtk_tree_path_get_type, LFv)
GO(gtk_tree_path_is_ancestor, iFpp)
GO(gtk_tree_path_is_descendant, iFpp)
GO(gtk_tree_path_new, pFv)
GO(gtk_tree_path_new_first, pFv)
GO(gtk_tree_path_new_from_indices, pFippppppppppppppppp)  // vaarg
GO(gtk_tree_path_new_from_indicesv, pFpL)
GO(gtk_tree_path_new_from_string, pFp)
GO(gtk_tree_path_next, vFp)
GO(gtk_tree_path_prepend_index, vFpi)
GO(gtk_tree_path_prev, iFp)
GO(gtk_tree_path_to_string, pFp)
GO(gtk_tree_path_up, iFp)
GO(gtk_tree_row_reference_copy, pFp)
GO(gtk_tree_row_reference_deleted, vFpp)
GO(gtk_tree_row_reference_free, vFp)
GO(gtk_tree_row_reference_get_model, pFp)
GO(gtk_tree_row_reference_get_path, pFp)
GO(gtk_tree_row_reference_get_type, LFv)
GO(gtk_tree_row_reference_inserted, vFpp)
GO(gtk_tree_row_reference_new, pFpp)
GO(gtk_tree_row_reference_new_proxy, pFppp)
GO(gtk_tree_row_reference_reordered, vFpppp)
GO(gtk_tree_row_reference_valid, iFp)
GO(gtk_tree_selection_count_selected_rows, iFp)
GO(gtk_tree_selection_get_mode, uFp)
GO(gtk_tree_selection_get_selected, iFppp)
GO(gtk_tree_selection_get_selected_rows, pFpp)
//GOM(gtk_tree_selection_get_select_function, pFEp)
GO(gtk_tree_selection_get_tree_view, pFp)
GO(gtk_tree_selection_get_type, LFv)
GO(gtk_tree_selection_get_user_data, pFp)
GO(gtk_tree_selection_iter_is_selected, iFpp)
GO(gtk_tree_selection_path_is_selected, iFpp)
GO(gtk_tree_selection_select_all, vFp)
//GOM(gtk_tree_selection_selected_foreach, vFEppp)
GO(gtk_tree_selection_select_iter, vFpp)
GO(gtk_tree_selection_select_path, vFpp)
GO(gtk_tree_selection_select_range, vFppp)
GO(gtk_tree_selection_set_mode, vFpu)
//GOM(gtk_tree_selection_set_select_function, vFEpppp)
GO(gtk_tree_selection_unselect_all, vFp)
GO(gtk_tree_selection_unselect_iter, vFpp)
GO(gtk_tree_selection_unselect_path, vFpp)
GO(gtk_tree_selection_unselect_range, vFppp)
GO(gtk_tree_set_row_drag_data, iFppp)
GO(gtk_tree_sortable_get_sort_column_id, iFppp)
GO(gtk_tree_sortable_get_type, LFv)
GO(gtk_tree_sortable_has_default_sort_func, iFp)
GOM(gtk_tree_sortable_set_default_sort_func, vFEpppp)
GO(gtk_tree_sortable_set_sort_column_id, vFpiu)
GOM(gtk_tree_sortable_set_sort_func, vFEpippp)
GO(gtk_tree_sortable_sort_column_changed, vFp)
GO(gtk_tree_store_append, vFppp)
GO(gtk_tree_store_clear, vFp)
GO(gtk_tree_store_get_type, LFv)
GO(gtk_tree_store_insert, vFpppi)
GO(gtk_tree_store_insert_after, vFpppp)
GO(gtk_tree_store_insert_before, vFpppp)
//GOM(gtk_tree_store_insert_with_values, vFpppiV)
GO(gtk_tree_store_insert_with_valuesv, vFpppippi)
GO(gtk_tree_store_is_ancestor, iFppp)
GO(gtk_tree_store_iter_depth, iFpp)
GO(gtk_tree_store_iter_is_valid, iFpp)
GO(gtk_tree_store_move_after, vFppp)
GO(gtk_tree_store_move_before, vFppp)
GOM(gtk_tree_store_new, pFEiV)
GO(gtk_tree_store_newv, pFip)
GO(gtk_tree_store_prepend, vFppp)
GO(gtk_tree_store_remove, iFpp)
GO(gtk_tree_store_reorder, vFppp)
GOM(gtk_tree_store_set, vFEppV)
GO(gtk_tree_store_set_column_types, vFpip)
GOM(gtk_tree_store_set_valist, vFEppA)
GO(gtk_tree_store_set_value, vFppip)
GO(gtk_tree_store_set_valuesv, vFppppi)
GO(gtk_tree_store_swap, vFppp)
GO(gtk_tree_view_accessible_get_type, LFv)
GO(gtk_tree_view_append_column, iFpp)
GO(gtk_tree_view_collapse_all, vFp)
GO(gtk_tree_view_collapse_row, iFpp)
GO(gtk_tree_view_column_add_attribute, vFpppi)
GO(gtk_tree_view_column_cell_get_position, iFpppp)
GO(gtk_tree_view_column_cell_get_size, vFpppppp)
GO(gtk_tree_view_column_cell_is_visible, iFp)
GO(gtk_tree_view_column_cell_set_cell_data, vFpppii)
GO(gtk_tree_view_column_clear, vFp)
GO(gtk_tree_view_column_clear_attributes, vFpp)
GO(gtk_tree_view_column_clicked, vFp)
GO(gtk_tree_view_column_focus_cell, vFpp)
GO(gtk_tree_view_column_get_alignment, fFp)
GO(gtk_tree_view_column_get_button, pFp)
GO(gtk_tree_view_column_get_clickable, iFp)
GO(gtk_tree_view_column_get_expand, iFp)
GO(gtk_tree_view_column_get_fixed_width, iFp)
GO(gtk_tree_view_column_get_max_width, iFp)
GO(gtk_tree_view_column_get_min_width, iFp)
GO(gtk_tree_view_column_get_reorderable, iFp)
GO(gtk_tree_view_column_get_resizable, iFp)
GO(gtk_tree_view_column_get_sizing, uFp)
GO(gtk_tree_view_column_get_sort_column_id, iFp)
GO(gtk_tree_view_column_get_sort_indicator, iFp)
GO(gtk_tree_view_column_get_sort_order, uFp)
GO(gtk_tree_view_column_get_spacing, iFp)
GO(gtk_tree_view_column_get_title, pFp)
GO(gtk_tree_view_column_get_tree_view, pFp)
GO(gtk_tree_view_column_get_type, LFv)
GO(gtk_tree_view_column_get_visible, iFp)
GO(gtk_tree_view_column_get_widget, pFp)
GO(gtk_tree_view_column_get_width, iFp)
GO(gtk_tree_view_column_get_x_offset, iFp)
GO(gtk_tree_view_column_new, pFv)
GO(gtk_tree_view_column_new_with_area, pFp)
GO(gtk_tree_view_column_new_with_attributes, pFppppppppppppp)   //vaarg
GO(gtk_tree_view_column_pack_end, vFppi)
GO(gtk_tree_view_column_pack_start, vFppi)
GO(gtk_tree_view_column_queue_resize, vFp)
GO(gtk_tree_view_columns_autosize, vFp)
GO(gtk_tree_view_column_set_alignment, vFpf)
//GOM(gtk_tree_view_column_set_attributes, vFppV)
GOM(gtk_tree_view_column_set_cell_data_func, vFEppppp)
GO(gtk_tree_view_column_set_clickable, vFpi)
GO(gtk_tree_view_column_set_expand, vFpi)
GO(gtk_tree_view_column_set_fixed_width, vFpi)
GO(gtk_tree_view_column_set_max_width, vFpi)
GO(gtk_tree_view_column_set_min_width, vFpi)
GO(gtk_tree_view_column_set_reorderable, vFpi)
GO(gtk_tree_view_column_set_resizable, vFpi)
GO(gtk_tree_view_column_set_sizing, vFpu)
GO(gtk_tree_view_column_set_sort_column_id, vFpi)
GO(gtk_tree_view_column_set_sort_indicator, vFpi)
GO(gtk_tree_view_column_set_sort_order, vFpu)
GO(gtk_tree_view_column_set_spacing, vFpi)
GO(gtk_tree_view_column_set_title, vFpp)
GO(gtk_tree_view_column_set_visible, vFpi)
GO(gtk_tree_view_column_set_widget, vFpp)
GO(gtk_tree_view_column_sizing_get_type, LFv)
GO(gtk_tree_view_convert_bin_window_to_tree_coords, vFpiipp)
GO(gtk_tree_view_convert_bin_window_to_widget_coords, vFpiipp)
GO(gtk_tree_view_convert_tree_to_bin_window_coords, vFpiipp)
GO(gtk_tree_view_convert_tree_to_widget_coords, vFpiipp)
GO(gtk_tree_view_convert_widget_to_bin_window_coords, vFpiipp)
GO(gtk_tree_view_convert_widget_to_tree_coords, vFpiipp)
GO(gtk_tree_view_create_row_drag_icon, pFpp)
GO(gtk_tree_view_drop_position_get_type, LFv)
GO(gtk_tree_view_enable_model_drag_dest, vFppiu)
GO(gtk_tree_view_enable_model_drag_source, vFpupiu)
GO(gtk_tree_view_expand_all, vFp)
GO(gtk_tree_view_expand_row, iFppi)
GO(gtk_tree_view_expand_to_path, vFpp)
GO(gtk_tree_view_get_activate_on_single_click, iFp)
GO(gtk_tree_view_get_background_area, vFpppp)
GO(gtk_tree_view_get_bin_window, pFp)
GO(gtk_tree_view_get_cell_area, vFpppp)
GO(gtk_tree_view_get_column, pFpi)
GO(gtk_tree_view_get_columns, pFp)
GO(gtk_tree_view_get_cursor, vFppp)
GO(gtk_tree_view_get_dest_row_at_pos, iFpiipp)
GO(gtk_tree_view_get_drag_dest_row, vFppp)
GO(gtk_tree_view_get_enable_search, iFp)
GO(gtk_tree_view_get_enable_tree_lines, iFp)
GO(gtk_tree_view_get_expander_column, pFp)
GO(gtk_tree_view_get_fixed_height_mode, iFp)
GO(gtk_tree_view_get_grid_lines, uFp)
GO(gtk_tree_view_get_hadjustment, pFp)
GO(gtk_tree_view_get_headers_clickable, iFp)
GO(gtk_tree_view_get_headers_visible, iFp)
GO(gtk_tree_view_get_hover_expand, iFp)
GO(gtk_tree_view_get_hover_selection, iFp)
GO(gtk_tree_view_get_level_indentation, iFp)
GO(gtk_tree_view_get_model, pFp)
GO(gtk_tree_view_get_n_columns, uFp)
GO(gtk_tree_view_get_path_at_pos, iFpiipppp)
GO(gtk_tree_view_get_reorderable, iFp)
//GOM(gtk_tree_view_get_row_separator_func, pFEp)
GO(gtk_tree_view_get_rubber_banding, iFp)
GO(gtk_tree_view_get_rules_hint, iFp)
GO(gtk_tree_view_get_search_column, iFp)
GO(gtk_tree_view_get_search_entry, pFp)
//GOM(gtk_tree_view_get_search_equal_func, pFEp)
//GOM(gtk_tree_view_get_search_position_func, pFEp)
GO(gtk_tree_view_get_selection, pFp)
GO(gtk_tree_view_get_show_expanders, iFp)
GO(gtk_tree_view_get_tooltip_column, iFp)
GO(gtk_tree_view_get_tooltip_context, iFpppippp)
GO(gtk_tree_view_get_type, LFv)
GO(gtk_tree_view_get_vadjustment, pFp)
GO(gtk_tree_view_get_visible_range, iFppp)
GO(gtk_tree_view_get_visible_rect, vFpp)
GO(gtk_tree_view_grid_lines_get_type, LFv)
GO(gtk_tree_view_insert_column, iFppi)
GO(gtk_tree_view_insert_column_with_attributes, iFpipppppppppppp) //vaarg
//GOM(gtk_tree_view_insert_column_with_data_func, iFpippppp)
GO(gtk_tree_view_is_blank_at_pos, iFpiipppp)
GO(gtk_tree_view_is_rubber_banding_active, iFp)
//GOM(gtk_tree_view_map_expanded_rows, vFEppp)
GO(gtk_tree_view_move_column_after, vFppp)
GO(gtk_tree_view_new, pFv)
GO(gtk_tree_view_new_with_model, pFp)
GO(gtk_tree_view_remove_column, iFpp)
GO(gtk_tree_view_row_activated, vFppp)
GO(gtk_tree_view_row_expanded, iFpp)
GO(gtk_tree_view_scroll_to_cell, vFpppiff)
GO(gtk_tree_view_scroll_to_point, vFpii)
GO(gtk_tree_view_set_activate_on_single_click, vFpi)
//GOM(gtk_tree_view_set_column_drag_function, vFEpppp)
GO(gtk_tree_view_set_cursor, vFpppi)
GO(gtk_tree_view_set_cursor_on_cell, vFppppi)
//GOM(gtk_tree_view_set_destroy_count_func, vFEpppp)
GO(gtk_tree_view_set_drag_dest_row, vFppu)
GO(gtk_tree_view_set_enable_search, vFpi)
GO(gtk_tree_view_set_enable_tree_lines, vFpi)
GO(gtk_tree_view_set_expander_column, vFpp)
GO(gtk_tree_view_set_fixed_height_mode, vFpi)
GO(gtk_tree_view_set_grid_lines, vFpu)
GO(gtk_tree_view_set_hadjustment, vFpp)
GO(gtk_tree_view_set_headers_clickable, vFpi)
GO(gtk_tree_view_set_headers_visible, vFpi)
GO(gtk_tree_view_set_hover_expand, vFpi)
GO(gtk_tree_view_set_hover_selection, vFpi)
GO(gtk_tree_view_set_level_indentation, vFpi)
GO(gtk_tree_view_set_model, vFpp)
GO(gtk_tree_view_set_reorderable, vFpi)
//GOM(gtk_tree_view_set_row_separator_func, vFEpppp)
GO(gtk_tree_view_set_rubber_banding, vFpi)
GO(gtk_tree_view_set_rules_hint, vFpi)
GO(gtk_tree_view_set_search_column, vFpi)
GO(gtk_tree_view_set_search_entry, vFpp)
GOM(gtk_tree_view_set_search_equal_func, vFEpppp)
//GOM(gtk_tree_view_set_search_position_func, vFEpppp)
GO(gtk_tree_view_set_show_expanders, vFpi)
GO(gtk_tree_view_set_tooltip_cell, vFppppp)
GO(gtk_tree_view_set_tooltip_column, vFpi)
GO(gtk_tree_view_set_tooltip_row, vFppp)
GO(gtk_tree_view_set_vadjustment, vFpp)
GO(gtk_tree_view_unset_rows_drag_dest, vFp)
GO(gtk_tree_view_unset_rows_drag_source, vFp)
GO(gtk_true, iFv)
GO(gtk_ui_manager_add_ui, vFpupppui)
GO(gtk_ui_manager_add_ui_from_file, uFppp)
GO(gtk_ui_manager_add_ui_from_resource, uFppp)
GO(gtk_ui_manager_add_ui_from_string, uFpplp)
GO(gtk_ui_manager_ensure_update, vFp)
GO(gtk_ui_manager_get_accel_group, pFp)
GO(gtk_ui_manager_get_action, pFpp)
GO(gtk_ui_manager_get_action_groups, pFp)
GO(gtk_ui_manager_get_add_tearoffs, iFp)
GO(gtk_ui_manager_get_toplevels, pFpu)
GO(gtk_ui_manager_get_type, LFv)
GO(gtk_ui_manager_get_ui, pFp)
GO(gtk_ui_manager_get_widget, pFpp)
GO(gtk_ui_manager_insert_action_group, vFppi)
GO(gtk_ui_manager_item_type_get_type, LFv)
GO(gtk_ui_manager_new, pFv)
GO(gtk_ui_manager_new_merge_id, uFp)
GO(gtk_ui_manager_remove_action_group, vFpp)
GO(gtk_ui_manager_remove_ui, vFpu)
GO(gtk_ui_manager_set_add_tearoffs, vFpi)
GO(gtk_unit_get_type, LFv)
GO(gtk_vbox_get_type, LFv)
GO(gtk_vbox_new, pFii)
GO(gtk_vbutton_box_get_type, LFv)
GO(gtk_vbutton_box_new, pFv)
GO(gtk_viewport_get_bin_window, pFp)
GO(gtk_viewport_get_hadjustment, pFp)
GO(gtk_viewport_get_shadow_type, uFp)
GO(gtk_viewport_get_type, LFv)
GO(gtk_viewport_get_vadjustment, pFp)
GO(gtk_viewport_get_view_window, pFp)
GO(gtk_viewport_new, pFpp)
GO(gtk_viewport_set_hadjustment, vFpp)
GO(gtk_viewport_set_shadow_type, vFpu)
GO(gtk_viewport_set_vadjustment, vFpp)
GO(gtk_volume_button_get_type, LFv)
GO(gtk_volume_button_new, pFv)
GO(gtk_vpaned_get_type, LFv)
GO(gtk_vpaned_new, pFv)
GO(gtk_vscale_get_type, LFv)
GO(gtk_vscale_new, pFp)
GO(gtk_vscale_new_with_range, pFddd)
GO(gtk_vscrollbar_get_type, LFv)
GO(gtk_vscrollbar_new, pFp)
GO(gtk_vseparator_get_type, LFv)
GO(gtk_vseparator_new, pFv)
GO(gtk_widget_accessible_get_type, LFv)
GO(gtk_widget_activate, iFp)
GO(gtk_widget_add_accelerator, vFpppuuu)
GO(gtk_widget_add_device_events, vFppu)
GO(gtk_widget_add_events, vFpi)
GO(gtk_widget_add_mnemonic_label, vFpp)
GOM(gtk_widget_add_tick_callback, uFEpppp)
GO(gtk_widget_can_activate_accel, iFpu)
GO(gtk_widget_child_focus, iFpu)
GO(gtk_widget_child_notify, vFpp)
GOM(gtk_widget_class_bind_template_callback_full, vFEppp)
GO(gtk_widget_class_bind_template_child_full, vFppil)   // need wrapping?
GO(gtk_widget_class_find_style_property, pFpp)
//GOM(gtk_widget_class_get_css_name, pFp)
GO(gtk_widget_class_install_style_property, vFpp)
//GOM(gtk_widget_class_install_style_property_parser, vFEppp)
GO(gtk_widget_class_list_style_properties, pFpp)
GO(gtk_widget_class_path, vFpppp)
GO(gtk_widget_class_set_accessible_role, vFpu)
GO(gtk_widget_class_set_accessible_type, vFpL)
//GOM(gtk_widget_class_set_connect_func, vFEpppp)
//GOM(gtk_widget_class_set_css_name, vFpp)
GO(gtk_widget_class_set_template, vFpp)
GO(gtk_widget_class_set_template_from_resource, vFpp)
GO(gtk_widget_compute_expand, iFpu)
GO(gtk_widget_create_pango_context, pFp)
GO(gtk_widget_create_pango_layout, pFpp)
GO(gtk_widget_destroy, vFp)
GO(gtk_widget_destroyed, vFpp)
GO(gtk_widget_device_is_shadowed, iFpp)
GO(gtk_widget_draw, vFpp)
GO(gtk_widget_ensure_style, vFp)
GO(gtk_widget_error_bell, vFp)
GO(gtk_widget_event, iFpp)
GO(gtk_widget_freeze_child_notify, vFp)
GO(gtk_widget_get_accessible, pFp)
GO(gtk_widget_get_action_group, pFpp)
GO(gtk_widget_get_allocated_baseline, iFp)
GO(gtk_widget_get_allocated_height, iFp)
GO(gtk_widget_get_allocated_size, vFppp)
GO(gtk_widget_get_allocated_width, iFp)
GO(gtk_widget_get_allocation, vFpp)
GO(gtk_widget_get_ancestor, pFpL)
GO(gtk_widget_get_app_paintable, iFp)
GO(gtk_widget_get_can_default, iFp)
GO(gtk_widget_get_can_focus, iFp)
GO(gtk_widget_get_child_requisition, vFpp)
GO(gtk_widget_get_child_visible, iFp)
GO(gtk_widget_get_clip, vFpp)
GO(gtk_widget_get_clipboard, pFpp)
GO(gtk_widget_get_composite_name, pFp)
GO(gtk_widget_get_default_direction, uFv)
GO(gtk_widget_get_default_style, pFv)
GO(gtk_widget_get_device_enabled, iFpp)
GO(gtk_widget_get_device_events, uFpp)
GO(gtk_widget_get_direction, uFp)
GO(gtk_widget_get_display, pFp)
GO(gtk_widget_get_double_buffered, iFp)
GO(gtk_widget_get_events, iFp)
GO(gtk_widget_get_focus_on_click, iFp)
GO(gtk_widget_get_font_map, pFp)
GO(gtk_widget_get_font_options, pFp)
GO(gtk_widget_get_frame_clock, pFp)
GO(gtk_widget_get_halign, uFp)
GO(gtk_widget_get_has_tooltip, iFp)
GO(gtk_widget_get_has_window, iFp)
GO(gtk_widget_get_hexpand, iFp)
GO(gtk_widget_get_hexpand_set, iFp)
GO(gtk_widget_get_mapped, iFp)
GO(gtk_widget_get_margin_bottom, iFp)
GO(gtk_widget_get_margin_end, iFp)
GO(gtk_widget_get_margin_left, iFp)
GO(gtk_widget_get_margin_right, iFp)
GO(gtk_widget_get_margin_start, iFp)
GO(gtk_widget_get_margin_top, iFp)
GO(gtk_widget_get_modifier_mask, uFpu)
GO(gtk_widget_get_modifier_style, pFp)
GO(gtk_widget_get_name, pFp)
GO(gtk_widget_get_native, pFp)
GO(gtk_widget_get_no_show_all, iFp)
GO(gtk_widget_get_opacity, dFp)
GO(gtk_widget_get_pango_context, pFp)
GO(gtk_widget_get_parent, pFp)
GO(gtk_widget_get_parent_window, pFp)
GO(gtk_widget_get_path, pFp)
GO(gtk_widget_get_pointer, vFppp)
GO(gtk_widget_get_preferred_height, vFppp)
GO(gtk_widget_get_preferred_height_and_baseline_for_width, vFpipppp)
GO(gtk_widget_get_preferred_height_for_width, vFpipp)
GO(gtk_widget_get_preferred_size, vFppp)
GO(gtk_widget_get_preferred_width, vFppp)
GO(gtk_widget_get_preferred_width_for_height, vFpipp)
GO(gtk_widget_get_realized, iFp)
GO(gtk_widget_get_receives_default, iFp)
GO(gtk_widget_get_request_mode, uFp)
GO(gtk_widget_get_requisition, vFpp)
GO(gtk_widget_get_root_window, pFp)
GO(gtk_widget_get_scale_factor, iFp)
GO(gtk_widget_get_screen, pFp)
GO(gtk_widget_get_sensitive, iFp)
GO(gtk_widget_get_settings, pFp)
GO(gtk_widget_get_size_request, vFppp)
GO(gtk_widget_get_state, uFp)
GO(gtk_widget_get_state_flags, uFp)
GO(gtk_widget_get_style, pFp)
GO(gtk_widget_get_style_context, pFp)
GO(gtk_widget_get_support_multidevice, iFp)
GO(gtk_widget_get_template_child, pFpLp)
GO(gtk_widget_get_tooltip_markup, pFp)
GO(gtk_widget_get_tooltip_text, pFp)
GO(gtk_widget_get_tooltip_window, pFp)
GO(gtk_widget_get_toplevel, pFp)
GO(gtk_widget_get_type, LFv)
GO(gtk_widget_get_valign, uFp)
GO(gtk_widget_get_valign_with_baseline, uFp)
GO(gtk_widget_get_vexpand, iFp)
GO(gtk_widget_get_vexpand_set, iFp)
GO(gtk_widget_get_visible, iFp)
GO(gtk_widget_get_visual, pFp)
GO(gtk_widget_get_window, pFp)
GO(gtk_widget_grab_default, vFp)
GO(gtk_widget_grab_focus, vFp)
GO(gtk_widget_has_default, iFp)
GO(gtk_widget_has_focus, iFp)
GO(gtk_widget_has_grab, iFp)
GO(gtk_widget_has_rc_style, iFp)
GO(gtk_widget_has_screen, iFp)
GO(gtk_widget_has_visible_focus, iFp)
GO(gtk_widget_help_type_get_type, LFv)
GO(gtk_widget_hide, vFp)
GO(gtk_widget_hide_on_delete, iFp)
GO(gtk_widget_in_destruction, iFp)
GO(gtk_widget_init_template, vFp)
GO(gtk_widget_input_shape_combine_region, vFpp)
GO(gtk_widget_insert_action_group, vFppp)
GO(gtk_widget_intersect, iFppp)
GO(gtk_widget_is_ancestor, iFpp)
GO(gtk_widget_is_composited, iFp)
GO(gtk_widget_is_drawable, iFp)
GO(gtk_widget_is_focus, iFp)
GO(gtk_widget_is_sensitive, iFp)
GO(gtk_widget_is_toplevel, iFp)
GO(gtk_widget_is_visible, iFp)
GO(gtk_widget_keynav_failed, iFpu)
GO(gtk_widget_list_accel_closures, pFp)
GO(gtk_widget_list_action_prefixes, pFp)
GO(gtk_widget_list_mnemonic_labels, pFp)
GO(gtk_widget_measure, vFpuipppp)
GO(gtk_widget_map, vFp)
GO(gtk_widget_mnemonic_activate, iFpi)
GO(gtk_widget_modify_base, vFpup)
GO(gtk_widget_modify_bg, vFpup)
GO(gtk_widget_modify_cursor, vFppp)
GO(gtk_widget_modify_fg, vFpup)
GO(gtk_widget_modify_font, vFpp)
GO(gtk_widget_modify_style, vFpp)
GO(gtk_widget_modify_text, vFpup)
GO(gtk_widget_new, pFppppppppppppp) //vaarg
GO(gtk_widget_override_background_color, vFpup)
GO(gtk_widget_override_color, vFpup)
GO(gtk_widget_override_cursor, vFppp)
GO(gtk_widget_override_font, vFpp)
GO(gtk_widget_override_symbolic_color, vFppp)
GO(gtk_widget_path, vFpppp)
GO(gtk_widget_path_append_for_widget, iFpp)
GO(gtk_widget_path_append_type, iFpL)
GO(gtk_widget_path_append_with_siblings, iFppu)
GO(gtk_widget_path_copy, pFp)
GO(gtk_widget_path_free, vFp)
GO(gtk_widget_path_get_object_type, LFp)
GO(gtk_widget_path_get_type, LFv)
GO(gtk_widget_path_has_parent, iFpL)
GO(gtk_widget_path_is_type, iFpL)
GO(gtk_widget_path_iter_add_class, vFpip)
GO(gtk_widget_path_iter_add_region, vFpipu)
GO(gtk_widget_path_iter_clear_classes, vFpi)
GO(gtk_widget_path_iter_clear_regions, vFpi)
GO(gtk_widget_path_iter_get_name, pFpi)
GO(gtk_widget_path_iter_get_object_name, pFpi)
GO(gtk_widget_path_iter_get_object_type, LFpi)
GO(gtk_widget_path_iter_get_sibling_index, uFpi)
GO(gtk_widget_path_iter_get_siblings, pFpi)
GO(gtk_widget_path_iter_get_state, uFpi)
GO(gtk_widget_path_iter_has_class, iFpip)
GO(gtk_widget_path_iter_has_name, iFpip)
GO(gtk_widget_path_iter_has_qclass, iFpiu)
GO(gtk_widget_path_iter_has_qname, iFpiu)
GO(gtk_widget_path_iter_has_qregion, iFpiup)
GO(gtk_widget_path_iter_has_region, iFpipp)
GO(gtk_widget_path_iter_list_classes, pFpi)
GO(gtk_widget_path_iter_list_regions, pFpi)
GO(gtk_widget_path_iter_remove_class, vFpip)
GO(gtk_widget_path_iter_remove_region, vFpip)
GO(gtk_widget_path_iter_set_name, vFpip)
GO(gtk_widget_path_iter_set_object_name, vFpip)
GO(gtk_widget_path_iter_set_object_type, vFpiL)
GO(gtk_widget_path_iter_set_state, vFpiu)
GO(gtk_widget_path_length, iFp)
GO(gtk_widget_path_new, pFv)
GO(gtk_widget_path_prepend_type, vFpL)
GO(gtk_widget_path_ref, pFp)
GO(gtk_widget_path_to_string, pFp)
GO(gtk_widget_path_unref, vFp)
GO(gtk_widget_pop_composite_child, vFv)
GO(gtk_widget_push_composite_child, vFv)
GO(gtk_widget_queue_allocate, vFp)
GO(gtk_widget_queue_compute_expand, vFp)
GO(gtk_widget_queue_draw, vFp)
GO(gtk_widget_queue_draw_area, vFpiiii)
GO(gtk_widget_queue_draw_region, vFpp)
GO(gtk_widget_queue_resize, vFp)
GO(gtk_widget_queue_resize_no_redraw, vFp)
GO(gtk_widget_realize, vFp)
GO(gtk_widget_region_intersect, pFpp)
GO(gtk_widget_register_window, vFpp)
GO(gtk_widget_remove_accelerator, iFppuu)
GO(gtk_widget_remove_mnemonic_label, vFpp)
GO(gtk_widget_remove_tick_callback, vFpu)
GO(gtk_widget_render_icon, pFppup)
GO(gtk_widget_render_icon_pixbuf, pFppu)
GO(gtk_widget_reparent, vFpp)
GO(gtk_widget_reset_rc_styles, vFp)
GO(gtk_widget_reset_style, vFp)
GO(gtk_widget_send_expose, iFpp)
GO(gtk_widget_send_focus_change, iFpp)
GO(gtk_widget_set_accel_path, vFppp)
GO(gtk_widget_set_allocation, vFpp)
GO(gtk_widget_set_app_paintable, vFpi)
GO(gtk_widget_set_can_default, vFpi)
GO(gtk_widget_set_can_focus, vFpi)
GO(gtk_widget_set_child_visible, vFpi)
GO(gtk_widget_set_clip, vFpp)
GO(gtk_widget_set_composite_name, vFpp)
GO(gtk_widget_set_css_classes, vFpp)
GO(gtk_widget_set_default_direction, vFu)
GO(gtk_widget_set_device_enabled, vFppi)
GO(gtk_widget_set_device_events, vFppu)
GO(gtk_widget_set_direction, vFpu)
GO(gtk_widget_set_double_buffered, vFpi)
GO(gtk_widget_set_events, vFpi)
GO(gtk_widget_set_focus_on_click, vFpi)
GO(gtk_widget_set_font_map, vFpp)
GO(gtk_widget_set_font_options, vFpp)
GO(gtk_widget_set_halign, vFpu)
GO(gtk_widget_set_has_tooltip, vFpi)
GO(gtk_widget_set_has_window, vFpi)
GO(gtk_widget_set_hexpand, vFpi)
GO(gtk_widget_set_hexpand_set, vFpi)
GO(gtk_widget_set_mapped, vFpi)
GO(gtk_widget_set_margin_bottom, vFpi)
GO(gtk_widget_set_margin_end, vFpi)
GO(gtk_widget_set_margin_left, vFpi)
GO(gtk_widget_set_margin_right, vFpi)
GO(gtk_widget_set_margin_start, vFpi)
GO(gtk_widget_set_margin_top, vFpi)
GO(gtk_widget_set_name, vFpp)
GO(gtk_widget_set_no_show_all, vFpi)
GO(gtk_widget_set_opacity, vFpd)
GO(gtk_widget_set_parent, vFpp)
GO(gtk_widget_set_parent_window, vFpp)
GO(gtk_widget_set_realized, vFpi)
GO(gtk_widget_set_receives_default, vFpi)
GO(gtk_widget_set_redraw_on_allocate, vFpi)
GO(gtk_widget_set_sensitive, vFpi)
GO(gtk_widget_set_size_request, vFpii)
GO(gtk_widget_set_state, vFpu)
GO(gtk_widget_set_state_flags, vFpui)
GO(gtk_widget_set_style, vFpp)
GO(gtk_widget_set_support_multidevice, vFpi)
GO(gtk_widget_set_tooltip_markup, vFpp)
GO(gtk_widget_set_tooltip_text, vFpp)
GO(gtk_widget_set_tooltip_window, vFpp)
GO(gtk_widget_set_valign, vFpu)
GO(gtk_widget_set_vexpand, vFpi)
GO(gtk_widget_set_vexpand_set, vFpi)
GO(gtk_widget_set_visible, vFpi)
GO(gtk_widget_set_visual, vFpp)
GO(gtk_widget_set_window, vFpp)
GO(gtk_widget_shape_combine_region, vFpp)
GO(gtk_widget_show, vFp)
GO(gtk_widget_show_all, vFp)
GO(gtk_widget_show_now, vFp)
GO(gtk_widget_size_allocate, vFpp)
GO(gtk_widget_size_allocate_with_baseline, vFppi)
GO(gtk_widget_size_request, vFpp)
GO(gtk_widget_style_attach, vFp)
GOM(gtk_widget_style_get, vFEppV)
GO(gtk_widget_style_get_property, vFppp)
//GOM(gtk_widget_style_get_valist, vFppA)
GO(gtk_widget_thaw_child_notify, vFp)
GO(gtk_widget_translate_coordinates, iFppiipp)
GO(gtk_widget_trigger_tooltip_query, vFp)
GO(gtk_widget_unmap, vFp)
GO(gtk_widget_unparent, vFp)
GO(gtk_widget_unrealize, vFp)
GO(gtk_widget_unregister_window, vFpp)
GO(gtk_widget_unset_state_flags, vFpu)
GO(gtk_window_accessible_get_type, LFv)
GO(gtk_window_activate_default, iFp)
GO(gtk_window_activate_focus, iFp)
GO(gtk_window_activate_key, iFpp)
GO(gtk_window_add_accel_group, vFpp)
GO(gtk_window_add_mnemonic, vFpup)
GO(gtk_window_begin_move_drag, vFpiiiu)
GO(gtk_window_begin_resize_drag, vFpuiiiu)
GO(gtk_window_close, vFp)
GO(gtk_window_deiconify, vFp)
GO(gtk_window_destroy, vFp)
GO(gtk_window_fullscreen, vFp)
GO(gtk_window_fullscreen_on_monitor, vFppi)
GO(gtk_window_get_accept_focus, iFp)
GO(gtk_window_get_application, pFp)
GO(gtk_window_get_attached_to, pFp)
GO(gtk_window_get_decorated, iFp)
GO(gtk_window_get_default_icon_list, pFv)
GO(gtk_window_get_default_icon_name, pFv)
GO(gtk_window_get_default_size, vFppp)
GO(gtk_window_get_default_widget, pFp)
GO(gtk_window_get_deletable, iFp)
GO(gtk_window_get_destroy_with_parent, iFp)
GO(gtk_window_get_focus, pFp)
GO(gtk_window_get_focus_on_map, iFp)
GO(gtk_window_get_focus_visible, iFp)
GO(gtk_window_get_gravity, uFp)
GO(gtk_window_get_group, pFp)
GO(gtk_window_get_has_resize_grip, iFp)
GO(gtk_window_get_hide_titlebar_when_maximized, iFp)
GO(gtk_window_get_icon, pFp)
GO(gtk_window_get_icon_list, pFp)
GO(gtk_window_get_icon_name, pFp)
GO(gtk_window_get_mnemonic_modifier, uFp)
GO(gtk_window_get_mnemonics_visible, iFp)
GO(gtk_window_get_modal, iFp)
GO(gtk_window_get_opacity, dFp)
GO(gtk_window_get_position, vFppp)
GO(gtk_window_get_resizable, iFp)
GO(gtk_window_get_resize_grip_area, iFpp)
GO(gtk_window_get_role, pFp)
GO(gtk_window_get_screen, pFp)
GO(gtk_window_get_size, vFppp)
GO(gtk_window_get_skip_pager_hint, iFp)
GO(gtk_window_get_skip_taskbar_hint, iFp)
GO(gtk_window_get_title, pFp)
GO(gtk_window_get_titlebar, pFp)
GO(gtk_window_get_transient_for, pFp)
GO(gtk_window_get_type, LFv)
GO(gtk_window_get_type_hint, uFp)
GO(gtk_window_get_urgency_hint, iFp)
GO(gtk_window_get_window_type, uFp)
GO(gtk_window_group_add_window, vFpp)
GO(gtk_window_group_get_current_device_grab, pFpp)
GO(gtk_window_group_get_current_grab, pFp)
GO(gtk_window_group_get_type, LFv)
GO(gtk_window_group_list_windows, pFp)
GO(gtk_window_group_new, pFv)
GO(gtk_window_group_remove_window, vFpp)
GO(gtk_window_has_group, iFp)
GO(gtk_window_has_toplevel_focus, iFp)
GO(gtk_window_iconify, vFp)
GO(gtk_window_is_active, iFp)
GO(gtk_window_is_maximized, iFp)
GO(gtk_window_list_toplevels, pFv)
GO(gtk_window_maximize, vFp)
GO(gtk_window_mnemonic_activate, iFpuu)
GO(gtk_window_move, vFpii)
GO(gtk_window_new, pFu)
GO(gtk_window_parse_geometry, iFpp)
GO(gtk_window_position_get_type, LFv)
GO(gtk_window_present, vFp)
GO(gtk_window_present_with_time, vFpu)
GO(gtk_window_propagate_key_event, iFpp)
GO(gtk_window_remove_accel_group, vFpp)
GO(gtk_window_remove_mnemonic, vFpup)
GO(gtk_window_reshow_with_initial_size, vFp)
GO(gtk_window_resize, vFpii)
GO(gtk_window_resize_grip_is_visible, iFp)
GO(gtk_window_resize_to_geometry, vFpii)
GO(gtk_window_set_accept_focus, vFpi)
GO(gtk_window_set_application, vFpp)
GO(gtk_window_set_attached_to, vFpp)
GO(gtk_window_set_auto_startup_notification, vFi)
GO(gtk_window_set_decorated, vFpi)
GO(gtk_window_set_default, vFpp)
GO(gtk_window_set_default_geometry, vFpii)
GO(gtk_window_set_default_icon, vFp)
GO(gtk_window_set_default_icon_from_file, iFpp)
GO(gtk_window_set_default_icon_list, vFp)
GO(gtk_window_set_default_icon_name, vFp)
GO(gtk_window_set_default_size, vFpii)
GO(gtk_window_set_deletable, vFpi)
GO(gtk_window_set_destroy_with_parent, vFpi)
GO(gtk_window_set_focus, vFpp)
GO(gtk_window_set_focus_on_map, vFpi)
GO(gtk_window_set_focus_visible, vFpi)
GO(gtk_window_set_geometry_hints, vFpppu)
GO(gtk_window_set_gravity, vFpu)
GO(gtk_window_set_has_resize_grip, vFpi)
GO(gtk_window_set_has_user_ref_count, vFpi)
GO(gtk_window_set_hide_on_close, vFpi)
GO(gtk_window_set_hide_titlebar_when_maximized, vFpi)
GO(gtk_window_set_icon, vFpp)
GO(gtk_window_set_icon_from_file, iFppp)
GO(gtk_window_set_icon_list, vFpp)
GO(gtk_window_set_icon_name, vFpp)
GO(gtk_window_set_interactive_debugging, vFi)
GO(gtk_window_set_keep_above, vFpi)
GO(gtk_window_set_keep_below, vFpi)
GO(gtk_window_set_mnemonic_modifier, vFpu)
GO(gtk_window_set_mnemonics_visible, vFpi)
GO(gtk_window_set_modal, vFpi)
GO(gtk_window_set_opacity, vFpd)
GO(gtk_window_set_position, vFpu)
GO(gtk_window_set_resizable, vFpi)
GO(gtk_window_set_role, vFpp)
GO(gtk_window_set_screen, vFpp)
GO(gtk_window_set_skip_pager_hint, vFpi)
GO(gtk_window_set_skip_taskbar_hint, vFpi)
GO(gtk_window_set_startup_id, vFpp)
GO(gtk_window_set_title, vFpp)
GO(gtk_window_set_titlebar, vFpp)
GO(gtk_window_set_transient_for, vFpp)
GO(gtk_window_set_type_hint, vFpu)
GO(gtk_window_set_urgency_hint, vFpi)
GO(gtk_window_set_wmclass, vFppp)
GO(gtk_window_stick, vFp)
GO(gtk_window_type_get_type, LFv)
GO(gtk_window_unfullscreen, vFp)
GO(gtk_window_unmaximize, vFp)
GO(gtk_window_unstick, vFp)
GO(gtk_wrap_mode_get_type, LFv)

GO(dummy_iFppdd, iFppdd)    // for GtkEventController wrapping
GO(dummy_iFppUup, iFppUup)
GO(dummy_iFpUup, iFpUup)
GO(dummy_pFpLi, pFpLi)